import {Component, Input, OnInit, ViewEncapsulation} from '@angular/core';
import {NavigationEnd, Router} from "@angular/router";
import {Observable} from "rxjs";
import {filter, map} from "rxjs/operators";

@Component({
  selector: 'app-dynamic-breadcrumb',
  templateUrl: './dynamic-breadcrumb.component.html',
  encapsulation: ViewEncapsulation.None,
})
export class DynamicBreadcrumbComponent implements OnInit {
  @Input() hideUrls: string[] = ['/'];

  canShowBreadcrumb$: Observable<boolean>;
  navigationEvents$: Observable<NavigationEnd>;

  constructor(private router: Router) {
  }

  ngOnInit() {
    this.navigationEvents$ = this.router.events.pipe(
      filter(event => event instanceof NavigationEnd),
      // This one is not really needed but we're giving some hints to the typescript compiler
      map(event => event as NavigationEnd)
    );
    // Here we define the stream of booleans that determine whether to show the component or not on your template.
    this.canShowBreadcrumb$ = this.navigationEvents$.pipe(
      map(event => this.shouldShowBreadcrumb(event.url))
    );
  }

  shouldShowBreadcrumb(url: string): boolean {
    const conditions = this.hideUrls.map(hUrl => !(hUrl === url));
    return conditions.some(isTrue => isTrue);
  }
}
