import {Component, OnInit, ViewEncapsulation} from '@angular/core';
import {BaseRouteComponent} from "../../base-route.component";
import {NavigationEnd, Router} from "@angular/router";
import {Observable} from "rxjs";
import {filter, map} from "rxjs/operators";

@Component({
  selector: 'app-home-banner',
  templateUrl: './home-banner.component.html',
  styleUrls: ['./home-banner.component.scss'],
  encapsulation: ViewEncapsulation.None,
})
export class HomeBannerComponent extends BaseRouteComponent implements OnInit {
  banner;
  canShowBanner$: Observable<boolean>;
  navigationEvents$: Observable<NavigationEnd>;

  constructor(private router: Router) {
    super();
  }

  ngOnInit() {
    this.banner = this.getBannerImage('composants_ban.png');

    this.navigationEvents$ = this.router.events.pipe(
      filter(event => event instanceof NavigationEnd),
      // This one is not really needed but we're giving some hints to the typescript compiler
      map(event => event as NavigationEnd)
    );
    // Here we define the stream of booleans that determine whether to show the component or not on your template.
    this.canShowBanner$ = this.navigationEvents$.pipe(
      map(event => this.shouldShowHomeBanner(event.url))
    );
  }

  shouldShowHomeBanner(url: string): boolean {
    const conditions = [
      url === '/',
      url === '/accueil',
    ];
    return conditions.some(isTrue => isTrue);
  }
}
