export type ParagraphType = 'raw' | 'list' | 'clickable' | undefined
export type PropertyType = 'input' | 'output'

export interface Paragraph {
  "type": ParagraphType
  "text"?: string,
  "texts"?: string[],
}

export interface Property {
  "name": string,
  "inOut"?: PropertyType,
  "type"?: string,
  "required"?: boolean,
  "default"?: string | string[],
  "description"?: string
}

export interface Description {
  "main": string,
  "paragraphs"?: Paragraph[]
}

interface GenericFields {
  title?: string,
  subtitle?: string,
  description?: Description,
  template_id?: string
}

export interface Main extends GenericFields {}

export interface Integration extends GenericFields {
  module: string,
  import?: string,
  services?: string[]
}

export interface Information extends GenericFields {}

export interface Help {
  title: string,
  simple_description: string,
  information_dsfr: Paragraph[]
}

export interface SubjectData {
  main: Main,
  integration: Integration,
  properties?: Property[],
  informations?: Information[],
  help?: Help
}
