import {Injectable} from "@angular/core";
import {BehaviorSubject} from "rxjs";
import {ActivatedRouteSnapshot, NavigationEnd, Router, UrlSegment} from "@angular/router";
import {ComponentOrder} from "../../models/component-order.model";
import {composants, elementsInterface, forms, templates} from "./sidemenu";
import {filter} from "rxjs/operators";

export interface SideMenu {
  enabled?: boolean;
  title?: string;
  btnTitle?: string;
  template?: ComponentOrder[];
  subMenu?: SideMenu[];
}

export interface SideTemplate {
  accueil: SideMenu,
  composants: SideMenu,
  contact: SideMenu,
  forms: SideMenu,
  figma: SideMenu,
  templates: SideMenu,
  'get-start': SideMenu,
  'elements-d-interface': SideMenu,
}

@Injectable({
  providedIn: 'root'
})
export class SidemenuService {

  private templates;
  private field;

  private lists = {
    'composants': composants,
    'forms': forms,
    'templates': templates,
    'elements-d-interface': elementsInterface
  }

  // Subject emitting the sidemenu
  private readonly _sidemenu$ = new BehaviorSubject<SideMenu>({});

  // Observable exposing the sidemenu
  readonly sidemenu$ = this._sidemenu$.asObservable();

  // Subject emitting the sidemenu
  private readonly _isEnabled$ = new BehaviorSubject<boolean>(false);

  // Observable exposing the sidemenu
  readonly isEnabled$ = this._isEnabled$.asObservable();

  constructor(private router: Router) {
    this.router.events.pipe(
      // Filter the NavigationEnd events as the sidemenu is updated only when the route reaches its end
      filter((event) => event instanceof NavigationEnd)
    ).subscribe(event => {
      // Construct the sidemenu
      const root = this.router.routerState.snapshot.root;

      const sidemenu = this.buildSideMenu(root);

      // Emit the new hierarchy
      if(sidemenu) {
        this._isEnabled$.next(sidemenu.enabled || false)
        this._sidemenu$.next(sidemenu);
      }
    });
  }

  public initSideMenu(templates: SideTemplate): void {
    this.templates = templates;

    if (this.field) {
      const sidemenu = this.templates[this.field];
      this.updateSideMenu(sidemenu)
    }
  }

  public updateSideMenu(sidemenu: SideMenu): void {
    // Emit the new hierarchy
    this._sidemenu$.next(sidemenu);
  }

  private buildSideMenu(route: ActivatedRouteSnapshot): SideMenu | undefined {
    if (route) {
      // Add an element for the current route part
      if (route.url) {
        const urls = [...route.firstChild.url];
        const firstUrlSegment = urls.shift();
        return this.getSideMenu(firstUrlSegment);
      }
    }
  }

  private getSideMenu(segment: UrlSegment): SideMenu {
    this.field = segment?.path;
    const menu: SideMenu = this.templates[this.field];
    if ('template' in menu) {
      menu.template = this.lists[this.field];
    }
    return menu;
  }

}
