import {ComponentOrder} from "../../models/component-order.model";
import {BadgeCard, Img} from "@mjfr/ng-dsmj";

function getCardImage(filename: string): Img | undefined {
  return {src: '/assets/img/composants/' + filename, alt: ''};
}

const badgesNouveau: BadgeCard[] = [
  {label: 'Nouveau', color: 'green-emeraude', position: 'header'}
]

const badgesSoon: BadgeCard[] = [
  {label: 'En cours de développement', color: 'yellow-tournesol', position: 'header'}
]

const badgesSpec: BadgeCard[] = [
  {label: 'Composant spécifique', color: 'info', position: 'header'}
]
const badgesDeprecated: BadgeCard[] = [
  {label: 'Obsolète', color: 'error', position: 'header'}
]

const composants: ComponentOrder[] = [
  {
    urlMenu: '/elements-d-interface/composants/accordion',
    component: 'Accordéon - Accordion',
    key: 'accordionTemplate',
    title: 'Accordéon - Accordion',
    url: './accordion',
    description: "Les accordéons permettent aux utilisateurs d'afficher et de masquer des sections de contenu présentées dans une page.",
    img: getCardImage('composants_accordeon.png'),
    selected: false,
    //badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/alert',
    component: 'Alerte - Alert',
    key: 'alertTemplate',
    title: 'Alerte - Alert',
    url: './alert',
    description: "Les alertes permettent d’attirer l’attention de l’utilisateur sur une information sans interrompre sa tâche en cours.",
    img: getCardImage('composants_alertes.png'),
    selected: false,
    //badges: badgesNouveau
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/badge',
    component: 'Badge - Badge',
    key: 'badgeTemplate',
    title: 'Badge',
    url: './badge',
    description: "Le composant badge permet de mettre en avant une information de type “statut” ou “état” sur un élément du site.",
    img: getCardImage('composants_badge.png'),
    selected: false,
    //badges: badgesNouveau
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/banner',
    component: 'Bandeau d\'information - Notice',
    key: 'bannerTemplate',
    title: 'Bandeau d\'information',
    url: './banner',
    description: "Le bandeau d’information importante permet aux utilisateurs de voir ou d’accéder à une information importante et temporaire.",
    img: getCardImage('composants_bandeau_information_importante.png'),
    selected: false,
    //badges: badgesNouveau
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/logo',
    component: 'Bloc-marque - Blockmark',
    key: 'logoTemplate',
    title: 'Bloc-marque - Blockmark',
    url: './logo',
    description: "Précise le nom de l'entité (ministère, secrétariat d'Etat...), inscrit en majuscule sous la Marianne",
    img: getCardImage('composants_en_tete.png'),
    selected: false,
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/button',
    component: 'Bouton - Button',
    key: 'buttonTemplate',
    title: 'Boutons',
    url: './button',
    description: "Le bouton est un élément d’interaction avec l’interface permettant à l’utilisateur d’effectuer une action.",
    img: getCardImage('composants_boutons.png'),
    selected: false,
    //badges: badgesNouveau,
    disabled: false,
    isSpecific: null
  },
  {
    urlMenu: '/elements-d-interface/composants/fcButton',
    component: 'Bouton FranceConnect',
    key: 'fcButtonTemplate',
    title: 'Bouton FranceConnect',
    url: './fcButton', //
    description: "Le bouton FranceConnect permet à une administration (ou un fournisseur de logiciel agissant pour le compte d’une administration) de proposer une connexion ou une création de compte simplifiée.",
    img: getCardImage('composants_bouton_franceconnect.png'),
    selected: false,
    //badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/card',
    component: 'Carte - Card',
    key: 'cardTemplate',
    title: 'Carte - Card',
    url: './card',
    description: "La carte est un lien vers une page éditoriale dont elle donne un aperçu.",
    img: getCardImage('composants_cartes.png'),
    selected: false,
    //badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/quote',
    component: 'Citation - Quote',
    key: 'quoteTemplate',
    title: 'Citation - Quote',
    url: './quote',
    description: "La citation permet de citer un texte dans une page éditoriale.",
    img: getCardImage('composants_citation.png'),
    selected: false,
   // badges: badgesNouveau, // v4
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/media',
    component: 'Contenu médias - Responsive medias',
    key: 'mediaTemplate',
    title: 'Contenu médias - Responsive medias',
    url: null,
    description: "Les contenus médias désignent vos contenus photos et vidéos.",
    img: getCardImage('composants_contenu_medias.png'),
    selected: false,
    badges: badgesSoon,
    disabled: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/header',
    component: 'En-tête - Header',
    key: 'headerTemplate',
    title: 'En-tête - Header',
    url: './header',
    description: "L’en-tête permet aux utilisateurs d’identifier sur quel site ils se trouvent.",
    img: getCardImage('composants_en_tete.png'),
    selected: false,
    //badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/breadcrumb',
    component: 'Fil d\'ariane - Breadcrumb',
    key: 'breadcrumbTemplate',
    title: 'Fil d\'ariane - Breadcrumb',
    url: './breadcrumb',
    description: "Le fil d’Ariane est un système de navigation secondaire qui permet à l’utilisateur de se situer sur le site qu’il consulte.",
    img: getCardImage('composants_fil_ariane.png'),
    selected: false,
    //badges: badgesNouveau
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/consent',
    component: 'Gestionnaire de consentement - Consent banner',
    key: 'consentTemplate',
    title: 'Gestionnaire de consentement - Consent banner',
    url: null,
    description: "Le gestionnaire de consentement permet à l'utilisateur de définir ses préférences sur l'utilisation de ses données personnelles, notamment le dépôt de cookies non fonctionnels dans son navigateur)",
    img: getCardImage('composants_gestionnaire_de_consentement.png'),
    selected: false,
    badges: badgesSoon,
    disabled: true,
    workingOn: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/favIcon',
    component: 'Icônes de favori - Favicon',
    key: 'favIconTemplate',
    title: 'Icônes de favori - Favicon',
    url: null,
    description: "L’icône de favori est une petite icône associée à un site web visible sur l'onglet du navigateur.",
    img: getCardImage('composants_icone_de_favoris.png'),
    selected: false,
    badges: badgesSoon,
    disabled: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/stepIndication',
    component: 'Indicateur d\'étapes - Stepper',
    key: 'stepIndicationTemplate',
    title: 'Indicateur d\'étapes - Stepper',
    url: './stepper',
    description: "L’indicateur d'étapes permet d’indiquer à l’utilisateur où il se trouve dans un formulaire ou dans une démarche.",
    img: getCardImage('composants_indicateur_etape.png'),
    selected: false,
    badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/toggle',
    component: 'Interrupteur - Toggle',
    key: 'toggleTemplate',
    title: 'Interrupteur - Toggle',
    url: null,
    description: "Le composant “Interrupteur” permet à l’utilisateur de faire un choix entre deux états opposés (activé / désactivé).",
    img: getCardImage('composants_interrupteur.png'),
    selected: false,
    badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/link',
    component: 'Lien - Link',
    key: 'linkTemplate',
    title: 'Lien - Link',
    url: './link',
    description: "Le lien permet la navigation entre une page et un autre contenu au sein de la même page, du même site ou externe.",
    img: getCardImage('composants_liens.png'),
    selected: false,
    //badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/sidemenu',
    component: 'Menu latéral - Sidemenu',
    key: 'sidemenuTemplate',
    title: 'Menu latéral - Sidemenu',
    url: './sidemenu',
    description: "Le menu latéral permet aux utilisateurs de naviguer entre les différentes pages d’une rubrique ou d’un même thème.",
    img: getCardImage('composants_menu_lateral.png'),
    selected: false,
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/callout',
    component: 'Mise en avant - Callout',
    key: 'calloutTemplate',
    title: 'Mise en avant - Callout',
    url: './callout',
    description: "La mise en avant permet à l’utilisateur de distinguer rapidement une information qui vient compléter le contenu consulté.",
    img: getCardImage('composants_mise_en_avant.png'),
    selected: false,
    badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/highlight',
    component: 'Mise en exergue - Highlight',
    key: 'highlightTemplate',
    title: 'Mise en exergue - Highlight',
    url: './highlight',
    description: "La mise en exergue permet à l’utilisateur de distinguer et repérer une information facilement.",
    img: getCardImage('composants_mise_en_exergue.png'),
    selected: false,
    badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/modal',
    component: 'Modale - Modal',
    key: 'modalTemplate',
    title: 'Modale - Modal',
    url: './modal',
    description: "La modale permet de concentrer l’attention de l’utilisateur exclusivement sur une tâche ou un élément d’information, sans perdre le contexte de la page en cours. Ce composant nécessite une action de l’utilisateur afin d'être fermé ou ouvert.",
    img: getCardImage('composants_modale.png'),
    selected: false,
   // badges: badgesNouveau
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/nav',
    component: 'Navigation principale - Navigation',
    key: 'navTemplate',
    title: 'Navigation principale - Navigation',
    url: './nav',
    description: "La navigation principale est l'élément central de la navigation au sein du site, il oriente l’utilisateur à travers les grandes sections du site et sur éventuellement plusieurs niveaux de profondeur. ",
    img: getCardImage('composants_navigation_principale.png'),
    selected: false,
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/tabs',
    component: 'Onglet - Tab',
    key: 'tabsTemplate',
    title: 'Onglet - Tab',
    url: './tabs',
    description: "Le composant Onglet permet aux utilisateurs de naviguer dans différentes sections de contenu au sein d’une même page.",
    img: getCardImage('composants_champs_de_saisie.png'),
    selected: false,
    //badges: badgesSoon,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/pagination',
    component: 'Pagination',
    key: 'paginationTemplate',
    title: 'Pagination',
    url: './pagination',
    description: "La pagination permet à l’utilisateur de naviguer entre les différentes pages d’une liste d'éléments.",
    img: getCardImage('composants_pagination.png'),
    selected: false,
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/display',
    component: 'Paramètre d\'affichage - Display',
    key: 'displayTemplate',
    title: 'Paramètre d\'affichage - Display',
    url: null,
    description: "Le parcours “Paramètres d’affichage” permet à l’utilisateur de choisir d'afficher le site en thème clair ou en thème sombre",
    img: getCardImage('composants_parametres_d_affichage.png'),
    selected: false,
    badges: badgesSoon,
    disabled: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/share',
    component: 'Partage - Share',
    key: 'shareTemplate',
    title: 'Partage - Share',
    url: null,
    description: "Les boutons de partage permettent aux utilisateurs de partager facilement un contenu qu’il consulte à d’autres utilisateur.",
    img: getCardImage('composants_partage.png'),
    selected: false,
    badges: badgesSoon,
    disabled: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/footer',
    component: 'Pied de page - Footer',
    key: 'footerTemplate',
    title: 'Pied de page - Footer',
    url: './footer',
    description: "Le pied de page propose des éléments d’information sur le site et une navigation secondaire pour l’utilisateur afin qu’il poursuive son parcours.",
    img: getCardImage('composants_pied_de_page.png'),
    selected: false,
    //badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/langage',
    component: 'Selecteur de langue',
    key: 'langageTemplate',
    title: 'Selecteur de langue',
    url: null,
    description: "Le sélecteur de langue permet à l’utilisateur de choisir la langue dans laquelle est affiché le contenu du site, si celui-ci est disponible en plusieurs langues.",
    img: getCardImage('composants_selecteur_de_langue.png'),
    selected: false,
    badges: badgesSoon,
    disabled: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/summary',
    component: 'Sommaire - Summary',
    key: 'summaryTemplate',
    title: 'Sommaire - Summary',
    url: './summary',
    description: "Le sommaire permet aux utilisateurs d’avoir un aperçu du contenu et de naviguer entre les différentes sections d’une page.",
    img: getCardImage('composants_sommaire.png'),
    selected: false,
    badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/table',
    component: 'Tableau - Table',
    key: 'tableTemplate',
    title: 'Tableau - Table',
    url: './table', // 'table',
    description: "Le tableau permet de présenter une liste structurée de données textuelles et/ou numériques",
    img: getCardImage('composants_tableau.png'),
    selected: false,
    badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/tag',
    component: 'Tag - Tag',
    key: 'tagTemplate',
    title: 'Tag',
    url: './tag',
    description: "Le tag catégorise/classe/organise les contenus à l'aide de mots-clés. Il aide les utilisateurs à rechercher et à trouver facilement une information.",
    img: getCardImage('composants_tag.png'),
    selected: false,
   // badges: badgesNouveau
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/download',
    component: 'Téléchargement de fichier - Uploader',
    key: 'downloadTemplate',
    title: 'Téléchargement de fichier - Uploader',
    url: null,
    description: "Le lien de téléchargement permet de mettre à disposition un ou plusieurs fichiers en téléchargement au fil du texte pour que l’utilisateur puisse les télécharger.",
    img: getCardImage('composants_telechargement_fichier.png'),
    selected: false,
    badges: badgesSoon,
    disabled: true,
    workingOn: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/composants/tile',
    component: 'Tuile - Tile',
    key: 'tileTemplate',
    title: 'Tuile - Tile',
    url: './tile', //'tile',
    description: "La tuile est un raccourci ou point d’entrée qui redirige les utilisateurs vers des pages de contenu. Elle fait généralement partie d'une collection ou liste de tuiles similaires.",
    img: getCardImage('composants_tuile.png'),
    selected: false,
   // badges: badgesNouveau,
    isSpecific: null,
    disabled: false
  },
];

// Eléments de formulaire
const forms: ComponentOrder[] = [
  {
    urlMenu: '/elements-d-interface/forms/upload',
    component: 'Ajout de fichier - Upload',
    key: 'autocompleteTemplate',
    title: 'Ajout de fichier - Upload',
    url: './upload',
    description: "Ce composant permet aux utilisateurs de sélectionner et envoyer un ou plusieurs fichiers par l'explorateur de fichiers.",
    img: getCardImage('composants_ajout_de_fichier.png'),
    badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/upload-drag-and-drop',
    component: 'Ajout de fichier avec Glisser/Déposer - File upload with drag and drop',
    key: 'autocompleteTemplate',
    title: 'Ajout de fichier avec Glisser/Déposer - File upload with drag and drop',
    url: './upload-drag-and-drop',
    description: "Ce composant permet aux utilisateurs de sélectionner et envoyer un ou plusieurs fichiers soit par l'explorateur de fichiers soit par un Glisser/Déposer. Un tableau récapitulatif permet de lister les fichiers téléchargés",
    img: getCardImage('composants_ajout_de_fichier.png'),
    badges: badgesSpec,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/search-bar',
    component: 'Barre de recherche - Search bar',
    key: 'searchbarTemplate',
    title: 'Barre de recherche',
    url: './search-bar',
    description: "La barre de recherche est un système de navigation qui permet à l'utilisateur d’accéder rapidement à un contenu en lançant une recherche sur un mot clé ou une expression.",
    img: getCardImage('composants_barre_de_recherche.png'),
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/autocomplete',
    component: 'Barre de saisie automatique - Autocomplete',
    key: 'autocompleteTemplate',
    title: 'Barre de saisie automatique - Autocomplete',
    url: null, //'autocomplete',
    description: "description",
    badges: badgesSoon,
    disabled: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/button',
    component: 'Boutons - Buttons',
    key: 'buttonTemplate',
    title: 'Bouton',
    url: './button',
    description: "Le bouton est un élément d’interaction avec l’interface permettant à l’utilisateur d’effectuer une action.",
    img: getCardImage('composants_boutons.png'),
    //badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/radio',
    component: 'Bouton radio - Radio button',
    key: 'radioTemplate',
    title: 'Bouton radio - Radio button',
    url: './radio',
    description: "Les boutons radio permettent à l’utilisateur de sélectionner une seule option dans une liste.",
    img: getCardImage('composants_boutons_radio.png'),
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/radio-rich',
    component: 'Bouton radio \'riches\' - Rich radio button',
    key: 'radioRichTemplate',
    title: 'Bouton radio enrichi - Rich radio button',
    url: './radio-rich',
    description: "Les boutons radio riches permettent de sélectionner un choix parmi une liste d’options illustrées. À la différence du bouton radio simple, l’image permet d’illustrer et d’accompagner l’utilisateur dans son choix.",
    img: getCardImage('composants_boutons_radio.png'),
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/checkbox',
    component: 'Case à cocher - Checkbox',
    key: 'checkboxTemplate',
    title: 'Case à cocher - Checkbox',
    url: './checkbox',
    description: "Les cases à cocher permettent à l’utilisateur de sélectionner une ou plusieurs options dans une liste.",
    img: getCardImage('composants_cases_a_cocher.png'),
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  // {
  //   urlMenu: '/elements-d-interface/forms/form-field',
  //   component: 'Champ de formulaire - Form field',
  //   key: 'formFieldTemplate',
  //   title: 'Champ de formulaire - Form field',
  //   url: './form-field',
  //   description: "Champ de formulaire",
  //   badges: badgesNouveau,
  //   subItems: [
  //     {
  //       urlMenu: '/elements-d-interface/forms/form-field/input',
  //       component: 'Champ de saisie - Input',
  //       key: 'checkboxTemplate',
  //       selected: false
  //     },
  //     {
  //       urlMenu: '/elements-d-interface/forms/form-field/select',
  //       component: 'Liste déroulante - Select',
  //       key: 'checkboxTemplate',
  //       selected: false
  //     },
  //     {
  //       urlMenu: '/elements-d-interface/forms/form-field/checkbox',
  //       component: 'Case à cocher - Checkbox',
  //       key: 'checkboxTemplate',
  //       selected: false
  //     },
  //     {
  //       urlMenu: '/elements-d-interface/forms/form-field/link',
  //       component: 'Lien - Link',
  //       key: 'checkboxTemplate',
  //       selected: false
  //     },
  //     {
  //       urlMenu: '/elements-d-interface/forms/form-field/button',
  //       component: 'Bouton - Button',
  //       key: 'checkboxTemplate',
  //       selected: false
  //     },
  //   ]
  // },
  {
    urlMenu: '/elements-d-interface/forms/input',
    component: 'Champ de saisie - Input',
    key: 'inputTemplate',
    title: 'Champ de saisie - Input',
    url: './input',
    description: "Les champs permettent à un utilisateur d'entrer du contenu ou des données.",
    img: getCardImage('composants_champs_de_saisie.png'),
    //badges: badgesNouveau
     disabled: false,
    isSpecific: false
  }, // TODO real one (text)
  {
    urlMenu: '/elements-d-interface/forms/btns-group',
    component: 'Groupe de Boutons - Buttons group',
    key: 'groupButtonTemplate',
    title: 'Groupe de boutons - Buttons group',
    url: './btns-group',
    description: "Le groupe de boutons permet de gérer un ensemble de boutons.",
    img: getCardImage('composants_boutons.png'),
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/form-group',
    component: 'Groupe de formulaire - Form group',
    key: 'formFieldTemplate',
    title: 'Group de formulaire - Form group',
    url: './form-group',
    description: "Composant utilisé pour regrouper les champs de contrôle `case à cocher` ou encore les `boutons radio`.",
    //badges: badgesNouveau,
     disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/toggleSwitch',
    component: 'Interrupteur - Toggle',
    key: 'toggleSwitchTemplate',
    title: 'Interrupteur - Toggle',
    url: null,
    description: "Le composant “Interrupteur” permet à l’utilisateur de faire un choix entre deux états opposés (activé / désactivé).",
    img: getCardImage('composants_interrupteur.png'),
    badges: badgesNouveau,
    disabled: false,
    isSpecific: false
    //workingOn: true
  },
  {
    urlMenu: '/elements-d-interface/forms/select',
    component: 'Liste déroulante - Select',
    key: 'selectTemplate',
    title: 'Liste déroulante - Select',
    url: './select',
    description: "La liste déroulante permet à un utilisateur de choisir un élément dans une liste donnée.",
    img: getCardImage('composants_liste_deroulante.png'),
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/selectMultiple',
    component: 'Liste déroulante multiple - Multiselect',
    key: 'selectMultipleTemplate',
    title: 'Champ de sélection multiple - Multiselect',
    url: 'selectMultiple',
    description: "Variante de la selection, celle-ci permet une selection multiple à l'aide de radio bouton intégré à la liste",
    img: getCardImage('composants_liste_deroulante.png'),
    badges: badgesSoon,
    disabled: false,
    workingOn: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/selectDynamic',
    component: 'Liste déroulante dynamique - Dynamic select',
    key: 'selectDynamicTemplate',
    title: 'Champ de sélection dynamique - Dynamic select',
    url: 'selectDynamic',
    description: "Variante de la selection, celle-ci permet également d'insérer des valeurs à la liste déroulte",
    img: getCardImage('composants_liste_deroulante.png'),
    badges: badgesSoon,
    disabled: false,
    workingOn: true,
    isSpecific: false
  },
  {
    urlMenu: '/elements-d-interface/forms/form-field-textarea',
    component: 'Zone de texte - Textarea',
    key: 'textareaTemplate',
    title: 'Zone de texte - Textarea',
    url: 'form-field-textarea', //'textarea',
    description: "Les zones de texte permettent à un utilisateur d'entrer du contenu ou des données",
    img: getCardImage('composants_champs_de_saisie.png'),
   // badges: badgesNouveau,
    disabled: false,
    isSpecific: false
  },
];

const templates: ComponentOrder[] = [
  {
    urlMenu: '/templates/errors',
    component: 'Modèle de page d\'erreur',
    key: 'signinTemplate',
    title: 'Modèle de page de connexion',
    url: null, //'signin',
    description: "Le modèle de page de connexion permet de demander à l'utilisateur de se connecter à un service",
    badges: badgesSoon,
    disabled: true
  },
  {
    urlMenu: '/templates/signin',
    component: 'Modèle de page de login',
    key: 'signinTemplate',
    title: 'Modèle de page d\'erreur',
    url: null, //'errors',
    description: "Les modèles de page d'erreur permettent d'informer l'utilisateur qu'un problème est rencontré sur le site pendant sa navigation.",
    badges: badgesSoon,
    disabled: true
  },
];

const elementsInterface: ComponentOrder[] = [
  {
    urlMenu: '/elements-d-interface/composants',
    component: "Composants",
    key: 'elements-d-interface-composants',
    title: 'Modèle de page de connexion',
    url: null, //'signin',
    description: "Le modèle de page de connexion permet de demander à l'utilisateur de se connecter à un service",
    badges: badgesSoon,
    disabled: true,
    subItems: composants
  },
  {
    urlMenu: '/elements-d-interface/elements-formulaire',
    component: 'Éléments de formulaire',
    key: 'elements-d-interface-el-formulaires',
    title: 'Modèle de page d\'erreur',
    url: null, //'errors',
    description: "Les modèles de page d'erreur permettent d'informer l'utilisateur qu'un problème est rencontré sur le site pendant sa navigation.",
    badges: badgesSoon,
    disabled: true,
    subItems: forms
  },
  {
    urlMenu: '/elements-d-interface/directives',
    component: 'Directives',
    key: 'elements-d-interface-directives',
    title: 'Modèle de page d\'erreur',
    url: null, //'errors',
    description: "Les modèles de page d'erreur permettent d'informer l'utilisateur qu'un problème est rencontré sur le site pendant sa navigation.",
    badges: badgesSoon,
    disabled: true
  },
];

export {elementsInterface, composants, forms, templates}
