import {Component, EventEmitter, Output} from '@angular/core';
import {SideMenu, SidemenuService} from "./service/sidemenu.service";
import {BehaviorSubject, Observable} from "rxjs";
import {ComponentOrder} from "../models/component-order.model";

@Component({
  selector: 'common-sidemenu-outlet',
  templateUrl: './sidemenu.component.html',
  styleUrls: ['./sidemenu.component.scss']
})
export class SidemenuComponent {
  @Output() itemClicked = new EventEmitter();

  selectedKey?: string;

  isEnabled = new BehaviorSubject<boolean>(true);

  get sidemenu$(): Observable<SideMenu> {
    return this.sidemenuService.sidemenu$;
  }

  get enabled$(): Observable<boolean> {
    return this.sidemenuService.isEnabled$;
  }

  constructor(private sidemenuService: SidemenuService) {}

  setListStatus(items: any[], item: any): void {
    if (item?.wip) return;
    this.removeOldListStatus(items);
    item.selected = true;
    this.sendComponentName(item.key)
  }

  removeOldListStatus(items): void {
    items.filter(item => item.selected).forEach(item => item.selected = false)
  }

  sendComponentName(key: string): void {
    this.selectedKey = key;
    this.itemClicked.emit(key);
  }

  setAriaCurrent(item: ComponentOrder, val?: boolean): string {
    if (val) {
      item.selected = true;
    }
    return val ? 'page' : null
  }
}
