import {Component, Input} from "@angular/core";
import {Property} from "../../models/subject-data.model";

@Component({
  selector: 'app-subject-properties',
  styleUrls: ['./custom-property.component.scss'],
  template: `
<div *ngIf="properties != null && properties.length > 0" class="fr-my-4w">
  <h2 *ngIf="showTitle">{{title}}</h2>
  <p *ngIf="description" class="fr-my-2w">{{description}}</p>
  <div class="fr-table">
    <table class="fr-table__width--full">
      <caption class="visually-hidden">tableau des propriétés</caption>
      <thead>
        <tr>
          <th scope="col">Nom</th>
          <th scope="col">Description</th>
        </tr>
      </thead>
      <tbody>
      <ng-container *ngFor="let prop of properties">
        <tr>
          <td>
            <ng-container *ngIf="prop?.inOut === 'input' || prop?.inOut === 'output'">
              <ng-container *ngIf="prop?.inOut === 'input'">
                <span class="fr-text--regular dsmj-subject-property__display--block">
                  {{getInOutValue(prop?.inOut)}}
                  <span class="dsmj-text__align--right">{{ prop?.required ? 'Champ obligatoire' : null }}</span>
                </span>
              </ng-container>
            </ng-container>
            <span class="fr-text--bold dsmj-subject-property__display--block"><u>{{prop.name}}</u>&nbsp;: <span class="fr-text--regular">{{prop.type}}</span></span>
            <app-subject-property-default [defaultVal]="prop.default"></app-subject-property-default>
          </td>
          <td>
            <span class="fr-text--light dsmj-subject-property__display--block">{{prop.description}}</span>
          </td>
        </tr>
      </ng-container>
      </tbody>
    </table>
  </div>
</div>
`
})
export class CustomPropertiesComponent {
  @Input() properties!: Property[];
  @Input() title?: string = 'Propriétés';
  @Input() description?: string;
  @Input() showTitle?: boolean = true;

  getInOutValue(inOut: string) {
    return inOut === 'input' ? '@Input()' : inOut === 'output' ? '@Output()' : '';
  }
}

@Component({
  selector: 'app-subject-property-default',
  styleUrls: ['./custom-property.component.scss'],
  template: `\
    <ng-container *ngIf="defaultVal != null && (isString || isArray)">
      <span class="fr-text--light fr-mt-2w dsmj-subject-property__display--block" *ngIf="isString">
        <i>Valeur par défaut : </i>
        <span class="fr-text--regular">{{defaultVal}}</span>
      </span>
      <span class="fr-text--light fr-mt-2w dsmj-subject-property__display--block" *ngIf="isArray">
        <i>Valeur par défaut : </i>
        <span class="fr-text--regular dsmj-subject-property__display--block" *ngFor="let d of defaultVal">{{d}}</span>
      </span>
    </ng-container>
  `
})
export class CustomPropertyDefaultComponent {
  @Input() defaultVal: string | string[] = undefined

  get isString() {
    return typeof this.defaultVal === 'string'
  }

  get isArray() {
    return typeof this.defaultVal !== 'string' && typeof this.defaultVal === 'object'
  }
}
