import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {AlertService} from "@mjfr/ng-dsmj";
import {alertDataExample} from "./alert.data";
import {codeSnippetBtn} from "./snippet/alert-btn";
import {codeSnippetAutoClose} from "./snippet/alert-autoclose";
import {codeSnippetSize} from "./snippet/alert-size-sm";
import {codeSnippetSizeMd} from "./snippet/alert-size-md";

@Component({
  selector: 'doc-alert-example',
  templateUrl: './alert-example.component.html',
  styleUrls: ['./alert-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class AlertExampleComponent {
  title = 'Alert';

  data = alertDataExample;
  helpItems = []

  constructor(protected alertService: AlertService) {}

  alertMessagingInfo = (id: string, text: string, autoClose: boolean = false): void => this.alertService.info(id, text, undefined, { autoClose });
  alertMessagingSuccess = (id: string, text: string, autoClose: boolean = false): void => this.alertService.success(id, text, undefined, { autoClose });
  alertMessagingWarning = (id: string, text: string, autoClose: boolean = false): void => this.alertService.warn(id, text, undefined, { autoClose });
  alertMessagingError = (id: string, text: string, autoClose: boolean = false): void => this.alertService.error(id, text, undefined, { autoClose });

  info = (id: string): void => this.alertMessagingInfo(id, 'info', true);
  success = (id: string): void => this.alertMessagingSuccess(id, 'success', true);
  warning = (id: string): void => this.alertMessagingWarning(id, 'warn', true);
  error = (id: string): void => this.alertMessagingError(id, 'error', true);

  infoSmall = (id: string): void => this.alertService.info(id, "Il est important de boire de l'eau !", undefined, { autoClose: true });

  infoMedium = (id: string): void => this.alertService.info(id, "Il est important de boire de l'eau !", 'Information importante', { autoClose: true });

  infoBtn = (id: string): void => this.alertMessagingInfo(id, 'info');
  successBtn = (id: string): void => this.alertMessagingSuccess(id, 'success');
  warningBtn = (id: string): void => this.alertMessagingWarning(id, 'warn');
  errorBtn = (id: string): void => this.alertMessagingError(id, 'error');

  codeSnippetAutoClose: CodeSnippet = codeSnippetAutoClose;
  codeSnippetBtn: CodeSnippet = codeSnippetBtn;
  codeSnippetSmall: CodeSnippet = codeSnippetSize;
  codeSnippetMedium: CodeSnippet = codeSnippetSizeMd;

  baliseClipboard: string = `\
<!-- Cette balise est à placer dans l'application -->
<!-- Elle indique l'emplacement à partir duquel les l'alertes seront affichés -->
<dsmj-alert></dsmj-alert>`

}
