import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {Badge} from "@mjfr/ng-dsmj";
import { badgeDataExample } from './badge.data';
import {badgeCodeSnippet} from "./snippet/generic";
import {badgeGroupSmallCodeSnippet} from "./snippet/group-small";
import {badgeGroupMediumCodeSnippet} from "./snippet/group-medium";
import {badgeWithIconCodeSnippet} from "./snippet/with-icon";
import {badgeWithoutIconCodeSnippet} from "./snippet/without-icon";
import {badgeMediumCodeSnippet} from "./snippet/medium";
import {badgeSmallCodeSnippet} from "./snippet/small";
import {badgeColorSuccessCodeSnippet} from "./snippet/color-success";
import {badgeColorSuccessWithoutIconCodeSnippet} from "./snippet/color-success-without-icon";

@Component({
  selector: 'doc-badge-example',
  templateUrl: './badge-example.component.html',
  styleUrls: ['./badge-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class BadgeExampleComponent {
  title = 'Badge';

  data = badgeDataExample;
  cs1 = badgeGroupSmallCodeSnippet
  cs2 = badgeGroupMediumCodeSnippet
  cs3 = badgeWithIconCodeSnippet
  cs4 = badgeWithoutIconCodeSnippet
  cs5 = badgeMediumCodeSnippet
  cs6 = badgeSmallCodeSnippet
  cs7 = badgeColorSuccessCodeSnippet
  cs8 = badgeColorSuccessWithoutIconCodeSnippet

  badges: Badge[] = [
    { label: 'yellow-tournesol', color: 'yellow-tournesol' },
    { label: 'yellow-moutarde', color: 'yellow-moutarde' },
    { label: 'warning', color: 'warning' },
    { label: 'warning', color: 'warning', noIcon: true },
    { label: 'success', color: 'success' },
    { label: 'success', color: 'success', noIcon: true },
    { label: 'purple-glycine', color: 'purple-glycine' },
    { label: 'pink-tuile', color: 'pink-tuile' },
    { label: 'pink-macaron', color: 'pink-macaron' },
    { label: 'orange-terre-battue', color: 'orange-terre-battue' },
    { label: 'new', color: 'new' },
    { label: 'new', color: 'new', noIcon: true },
    { label: 'info', color: 'info' },
    { label: 'info', color: 'info', noIcon: true },
    { label: 'green-tilleul-verveine', color: 'green-tilleul-verveine' },
    { label: 'green-menthe', color: 'green-menthe' },
    { label: 'green-emeraude', color: 'green-emeraude' },
    { label: 'green-bourgeon', color: 'green-bourgeon' },
    { label: 'green-archipel', color: 'green-archipel' },
    { label: 'error', color: 'error' },
    { label: 'error', color: 'error', noIcon: true },
    { label: 'brown-opera', color: 'brown-opera' },
    { label: 'brown-caramel', color: 'brown-caramel' },
    { label: 'brown-cafe-creme', color: 'brown-cafe-creme' },
    { label: 'blue-ecume', color: 'blue-ecume' },
    { label: 'blue-cumulus', color: 'blue-cumulus' },
    { label: 'beige-gris-galet', color: 'beige-gris-galet' },
  ]

  badgesSmall: Badge[] = this.badges.map(badge => {
    return {
      ...badge,
      size: 'sm'
    }
  })

  badgesNoIcon: Badge[] = this.badgesSmall.filter(b => b.noIcon)

  badgesWithIcon: Badge[] = this.badgesNoIcon.map(badge => {
    return {
      ...badge,
      noIcon: false
    }
  })

  codeSnippetSingleBadge: string = `\
<div class="fr-grid-row fr-grid-row--gutters">
  <h4 class="fr-col-12">Badge unique</h4>
  <dsmj-badge class="fr-col-12" size="sm" color="info" label="badge unique"></dsmj-badge>
</div>`

  codeSnippetGroupBadge: string = `\
<div class="fr-grid-row fr-grid-row--gutters">
  <h4 class="fr-col-12">Groupe de badge</h4>
  <dsmj-badges-group class="fr-col-12"
    [badges]="[{color: 'info', label: 'badge 1'}, {size: 'sm', color: 'info', label: 'badge 2'}]"
  ></dsmj-badges-group>
</div>`

}
