import {Component, TemplateRef, ViewChild, ViewEncapsulation} from '@angular/core';
import {BannerService} from "@mjfr/ng-dsmj";
import {bannerDataExample} from "./banner.data";
import {bannerCodeSnippetNotCloseable} from "./snippet/banner-not-closeable";
import {bannerCodeSnippetBtn} from "./snippet/banner-btn";
import {bannerCodeSnippetLink} from "./snippet/banner-link";
import {bannerCodeSnippetCustom} from "./snippet/banner-custom";
import {FormBuilder, Validators} from "@angular/forms";

@Component({
  selector: 'doc-banner-example',
  templateUrl: './banner-example.component.html',
  encapsulation: ViewEncapsulation.None
})
export class BannerExampleComponent {
  @ViewChild('bannerLinkTpl') bannerLinkTpl: TemplateRef<any>

  title = 'Banner';

  data = bannerDataExample;

  codeSnippetBtn = bannerCodeSnippetBtn;
  codeSnippetLink = bannerCodeSnippetLink;
  codeSnippetCustom = bannerCodeSnippetCustom;
  codeSnippetNotCloseable = bannerCodeSnippetNotCloseable;

  fgCustom = this.fb.group({
    message: ["Ceci est un bandeau customizable", [Validators.required]],
    type: ['info', [Validators.required]],
    isClosable: [true, [Validators.required]],
  })

  constructor(protected bannerService: BannerService, protected fb: FormBuilder) {}

  showBanner() {
    this.bannerService.newMessage('this one is not dismissible', { id: 'banner' })
  }

  showBannerLink() {
    this.bannerService.newMessage(this.bannerLinkTpl, { id: 'banner-link', isClosable: true })
  }

  showBannerBtn() {
    this.bannerService.newMessage('this one is dismissible', { id: 'banner-btn', isClosable: true })
  }

  showBannerCustom() {
    const message = this.fgCustom.get('message')?.value;
    const type = this.fgCustom.get('type')?.value;
    const isClosable = this.fgCustom.get('isClosable')?.value;
    this.bannerService.newMessage(message, { id: 'banner-custom', isClosable, type })
  }

  baliseClipboard: string = `\
<!-- Cette balise est à placer dans l'application -->
<!-- Elle indique la ou seront afficher les bandeau d'information -->
<dsmj-banner></dsmj-banner>`

}

