import {CodeSnippet} from "../../../commons/models/code-snippet.model";


const customCodeSnippet: CodeSnippet = {
  html:
    `\
<!-- breadcrumb.component.html -->
<ng-container *ngIf="canShowBreadcrumb$ | async">
  <dsmj-breadcrumb></dsmj-breadcrumb>
</ng-container>
`,
  ts: `\
// breadcrumb.component.ts
import {Component} from '@angular/core';

@Component({
    templateUrl: './breadcrumb.component.html',
    encapsulation: ViewEncapsulation.None
})
export class BreadcrumbComponent {
  @Input() hideUrls: string[] = ['/'];

  canShowBreadcrumb$: Observable<boolean>;
  navigationEvents$: Observable<NavigationEnd>;

  constructor(private router: Router) {
  }

  ngOnInit() {
    this.navigationEvents$ = this.router.events.pipe(
      filter(event => event instanceof NavigationEnd),
      // This one is not really needed but we're giving some hints to the typescript compiler
      map(event => event as NavigationEnd)
    );
    // Here we define the stream of booleans that determine whether to show the component or not on your template.
    this.canShowBreadcrumb$ = this.navigationEvents$.pipe(
      map(event => this.shouldShowBreadcrumb(event.url))
    );
  }

  shouldShowBreadcrumb(url: string): boolean {
    const conditions = this.hideUrls.map(hUrl => !(hUrl === url));
    return conditions.some(isTrue => isTrue);
  }
}`,
  'router.module': `\
// app-routing.module.ts
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import {
 AccueilComponent,
 ArticleComponent,
 ArticleListComponent,
 CaterorieComponent,
 CaterorieListComponent,
 SectionListComponent
 SectionComponent,
} from "./pages/all.component";

const routes: Routes = [
  { path: '', redirectTo: '/accueil', pathMatch: 'full' },
  { path: 'accueil', component: AccueilComponent, data: { breadcrumb: 'Accueil'} },
  {
    path: 'page',
    children: [
      { path: '', component: CaterorieListComponent, data: { breadcrumb: 'Pages'} },
      { path: ':id', component: CaterorieComponent, data: { breadcrumb: 'Page ' + id } },
      {
        path: ':id/subpage',
        children: [
          { path: '', component: ArticleListComponent, data: { breadcrumb: 'Sous-page'} },
          { path: ':id', component: ArticleComponent, data: { breadcrumb: 'Sous-page ' + id } },
          {
            path: ':id/section',
            children: [
              { path: '', component: SectionComponent, data: { breadcrumb: 'Sections'} },
              { path: ':id', component: SectionListComponent, data: { breadcrumb: 'Section ' + id } }
            ]
          }
        ]
      }
    ]
  }
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule]
})
export class AppRoutingModule { }
  `
}

export default customCodeSnippet;
