import {Component, ViewEncapsulation} from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-btn-franceconnect-example',
  templateUrl: './btn-franceconnect-example.component.html',
  encapsulation: ViewEncapsulation.None
})
export class BtnFranceconnectExampleComponent {
  properties: any = [
    {
      name: 'secure',
      inOut: 'input',
      type: 'boolean',
      required: false,
      default: "false",
      description: `Active l'usage du service d'authentification renforcée FranceConnect+`
    },
    {
      name: 'externalUrl',
      inOut: 'input',
      type: 'string',
      required: false,
      default: "",
      description: `Renseigne l'url à rédiriger lorsque le bouton FranceConnect est pressé`
    },
    {
      name: 'additionalParams',
      inOut: 'input',
      type: 'string[]',
      required: false,
      default: "",
      description: `Renseigne les paramètres complémentaire à passer à l'url lorsque le bouton FranceConnect est pressé`
    },
    {
      name: 'clicked',
      inOut: 'output',
      type: 'EventEmitter',
      required: false,
      default: "",
      description: `Renvoi les informations du clique sur le bouton principal de FranceConnect`
    }
  ];

  cs1: CodeSnippet = {
    html: `<dsmj-btn-franceconnect></dsmj-btn-franceconnect>`
  };

  cs2: CodeSnippet = {
    html: `<dsmj-btn-franceconnect (click)="onClick($event)"></dsmj-btn-franceconnect>`,
    ts: `onClick(e) { console.log(e); }`
  };

  cs3: CodeSnippet = {
    html: `<dsmj-btn-franceconnect externalUrl="http://mon-fournisseur-d-identite.site-fictif.tld"></dsmj-btn-franceconnect>`
  };

  cs4: CodeSnippet = {
    html: `<dsmj-btn-franceconnect externalUrl="http://mon-fournisseur-d-identite.site-fictif.tld" [additionalParams]='["paramA","paramB","paramC"]'></dsmj-btn-franceconnect>`
  };

  cs5: CodeSnippet = {
    html: `<dsmj-btn-franceconnect [secure]="true"></dsmj-btn-franceconnect>`
  };



  onClick(e) { console.log(e); }
}
