import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import { Badge } from '@mjfr/ng-dsmj';

@Component({
  selector: 'doc-callout-example',
  templateUrl: './callout-example.component.html',
  encapsulation: ViewEncapsulation.None
})

export class CalloutExampleComponent {

  badges: Badge[] = [
    { label: 'yellow-tournesol', color: 'yellow-tournesol' },
    { label: 'yellow-moutarde', color: 'yellow-moutarde' },
    { label: 'purple-glycine', color: 'purple-glycine' },
    { label: 'pink-tuile', color: 'pink-tuile' },
    { label: 'pink-macaron', color: 'pink-macaron' },
    { label: 'orange-terre-battue', color: 'orange-terre-battue' },
    { label: 'green-tilleul-verveine', color: 'green-tilleul-verveine' },
    { label: 'green-menthe', color: 'green-menthe' },
    { label: 'green-emeraude', color: 'green-emeraude' },
    { label: 'green-bourgeon', color: 'green-bourgeon' },
    { label: 'green-archipel', color: 'green-archipel' },
    { label: 'brown-opera', color: 'brown-opera' },
    { label: 'brown-caramel', color: 'brown-caramel' },
    { label: 'brown-cafe-creme', color: 'brown-cafe-creme' },
    { label: 'blue-ecume', color: 'blue-ecume' },
    { label: 'blue-cumulus', color: 'blue-cumulus' },
    { label: 'beige-gris-galet', color: 'beige-gris-galet' },
  ]

  public popup(): void {
    alert("Ceci est une pop-up!")
  }

  properties: any = [
    {
      name: 'icon',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "L'icône a utiliser dans la mise en avant, lien vers la liste des icones disponible dans la partie \"Personnalisation\" plus bas"
    },{
      name: 'color',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "La couleur de la mise en avant, liste de couleurs disponibles dans la partie \"Personnalisation\" plus bas"
    }
  ];

  cs1: CodeSnippet = {
    html:`
<dsmj-callout>
  <p dsmjCalloutDescription>
    Les parents d’enfants de 11 à 14 ans n’ont aucune démarche à accomplir : 
    les CAF versent automatiquement l’ARS aux familles déjà allocataires qui remplissent les conditions.
  </p>
</dsmj-callout>`
  }

  cs2: CodeSnippet = {
    html:`
<dsmj-callout icon="fr-icon-scales-3-line">
  <h3 dsmjCalloutTitle>Titre mis en avant</h3>
  <p dsmjCalloutDescription>Une icône d'une  balance</p>
</dsmj-callout>`
  }

  cs3: CodeSnippet = {
    html:`
<dsmj-callout icon="fr-icon-information-line" color="orange-terre-battue">
  <h4 dsmjCalloutTitle>Titre mis en avant</h4>
  <p dsmjCalloutDescription>Le bouton ouvre un message d'alerte</p>
  <button dsmjButton color="primary" (click)="popup()">Message d'alerte</button>
</dsmj-callout>`,
    ts:`
import {Component} from '@angular/core';

@Component({
  selector: 'doc-callout-example',
  templateUrl: './callout-example.component.html',
})

export class CalloutExampleComponent {

  public popup(): void {
    alert("Ceci est une pop-up!")
  }
}`
  }

  cs4: CodeSnippet = {
    html:`
<dsmj-callout icon="fr-icon-home-4-line">
  <h4 dsmjCalloutTitle>Titre mis en avant</h4>
  <p dsmjCalloutDescription>Le clique sur le bouton redirige vers la page d'accueil</p>
  <a dsmjButton color="primary" href="/">Accueil</a>
</dsmj-callout>`
  }
}
