import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {cardDataExample} from "./card.data";
import {cs1, cs2, cs3, cs4, cs5, cs6, cs7, cs8} from "./snippet/generic";
import {csb1, csb2, csb3, csb4} from "./snippet/generic-border";
import {csf1} from "./snippet/card-links";
import {cshl1} from "./snippet/card-header-less";
import {HttpClient} from "@angular/common/http";
import {tap} from "rxjs/operators";

@Component({
  selector: 'doc-card-example',
  templateUrl: './card-example.component.html',
  styleUrls: ['./card-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class CardExampleComponent {
  title = 'Card';

  data = cardDataExample;

  randomImg = { src: 'https://picsum.photos/250/140', alt: 'Image test' };

  cards: any[] = [
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte détaillée horizontale', img: undefined, link: 'https://google.fr', disabled: false, isHorizontal: true,
      showDetailStartPictoWarning: true, showDetailEndPictoWarning: true,
      detailStartDescription: "détail (optionnel)", detailEndDescription: "détail (optionnel)",
      badges: [{color: 'info', label: 'badge 1'}],
      tags: [],
      footerLinks: [],
      footerLinksType: undefined,
      description: '<h2>Voici la description de cette carte</h2>',
      codeSnippet: cs1
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte détaillée', img: undefined, link: '..', disabled: false, isHorizontal: false,
      showDetailStartPictoWarning: true, showDetailEndPictoWarning: true,
      detailStartDescription: "détail (optionnel)", detailEndDescription: "détail (optionnel)",
      badges: [],
      tags: [{label: 'tag 2'}],
      footerLinks: [],
      footerLinksType: undefined,
      description: 'Voici la description de cette carte',
      codeSnippet: undefined
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec badge', img: undefined, link: '.', disabled: false, isHorizontal: false,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [{color: 'info', label: 'badge 3', position: 'header'}, {color: 'info', label: 'badge 3.1'}],
      tags: [],
      footerLinks: [],
      footerLinksType: '',
      description: 'Voici la description de cette carte',
      codeSnippet: undefined
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec tag', img: undefined, link: '.', disabled: false, isHorizontal: false,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [],
      tags: [{label: 'tag 3'}],
      footerLinks: [],
      footerLinksType: '',
      description: 'Voici la description de cette carte',
      codeSnippet: cs2
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte sans badge ni tag', img: undefined, link: '.', disabled: false, isHorizontal: false,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [],
      tags: [],
      footerLinks: [],
      footerLinksType: '',
      description: 'Voici la description de cette carte',
      codeSnippet: undefined
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec image', img: this.randomImg, link: '.', disabled: false, isHorizontal: false,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [],
      tags: [],
      footerLinks: [],
      footerLinksType: '',
      description: 'Voici la description de cette carte',
      codeSnippet: cs3
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec bouton primaire', img: undefined, link: undefined, disabled: false, isHorizontal: false,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [],
      tags: [],
      footerLinks: [{'id': 'card-link-1','label': 'Bouton primaire','link': '.'}],
      footerLinksType: 'button',
      description: 'Voici la description de cette carte',
      codeSnippet: undefined
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec bouton secondaire', img: undefined, link: undefined, disabled: false, isHorizontal: false,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [],
      tags: [],
      footerLinks: [{'id': 'card-link-1','label': 'Bouton secondaire','link': '.', isSecondary: true}],
      footerLinksType: 'button',
      description: 'Voici la description de cette carte',
      codeSnippet: undefined
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec lien', img: undefined, link: undefined, disabled: false, isHorizontal: false,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [],
      tags: [],
      footerLinks: [{'id': 'card-link-1','label': 'Lien','link': '.'}],
      footerLinksType: 'link',
      description: 'Voici la description de cette carte',
      codeSnippet: cs8
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte horizontale avec badge', img: undefined, link: '.', disabled: false, isHorizontal: true,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [{color: 'info', label: 'badge 3', position: 'header'}, {color: 'info', label: 'badge 3.1'}],
      tags: [],
      footerLinks: [],
      footerLinksType: '',
      description: 'Voici la description de cette carte',
      codeSnippet: cs4
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte horizontale avec tag', img: undefined, link: '.', disabled: false, isHorizontal: true,
      showDetailStartPictoWarning: false, showDetailEndPictoWarning: false,
      detailStartDescription: undefined, detailEndDescription: undefined,
      badges: [],
      tags: [{label: 'tag 3'}],
      footerLinks: [],
      footerLinksType: '',
      description: 'Voici la description de cette carte',
      codeSnippet: cs5
    },
  ]

  cardLinks: any[] = [
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec plusieurs liens', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined,
      footerLinks: [{'id': 'card-link-2-1','label': 'Ici','link': '.'}, {'id': 'card-link-2-1-bis','label': 'La-Bas','link': '.'}],
      footerLinksType: 'link'
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec plusieurs liens', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: undefined,
      footerLinks: [{'id': 'card-link-2-2','label': 'Ici','link': '.'}, {'id': 'card-link-2-2-bis','label': 'La-Bas','link': '.'}],
      footerLinksType: 'link'
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec un lien et un bouton', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined,
      footerLinks: [{'id': 'card-link-3-1','label': 'Ici','link': '.', isSecondary: true}, {'id': 'card-link-3-1-bis','label': 'La-Bas','link': '.'}],
      footerLinksType: 'button'
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte avec un lien et un bouton', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: csf1,
      footerLinks: [{'id': 'card-link-3-2','label': 'Ici','link': '.', isSecondary: true}, {'id': 'card-link-3-2-bis','label': 'La-Bas','link': '.'}],
      footerLinksType: 'button'
    },
  ]

  cardBorders: any[] = [
    {
      noBorder: true, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte sans bordure', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined
    },
    {
      noBorder: true, shadowBorder: false, noBackground: false, greyBackground: false,
      title: 'Carte horizontale sans bordure', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: csb1
    },
    {
      noBorder: false, shadowBorder: true, noBackground: false, greyBackground: false,
      title: 'Carte avec ombre', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined
    },
    {
      noBorder: false, shadowBorder: true, noBackground: false, greyBackground: false,
      title: 'Carte horizontale avec ombre', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: csb2
    },
    {
      noBorder: false, shadowBorder: false, noBackground: true, greyBackground: false,
      title: 'Carte transparente', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined
    },
    {
      noBorder: false, shadowBorder: false, noBackground: true, greyBackground: false,
      title: 'Carte horizontale transparente', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: csb3
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: true,
      title: 'Carte grisée', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: true,
      title: 'Carte horizontale grisée', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: csb4
    },
  ]

  cardImageLess: any[] = [
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false, showImg: false,
      title: 'Carte sans image avec un badge', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined,
      badges: [{color: 'info', label: 'badge'}],
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false, showImg: false,
      title: 'Carte horizontale sans image avec un tag', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: undefined,
      tags: [{label: 'tag'}],
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false, showImg: false,
      title: 'Carte sans image avec plusieurs liens', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined,
      footerLinks: [{'id': 'card-link-2-1','label': 'Ici','link': '..'}],
      footerLinksType: 'link'
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false, showImg: false,
      title: 'Carte horizontale sans image avec plusieurs liens', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: undefined,
      footerLinks: [{'id': 'card-link-2-2','label': 'Ici','link': 'https://google.fr'}],
      footerLinksType: 'link'
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false, showImg: false,
      title: 'Carte sans image avec un lien et un bouton', link: '.', isHorizontal: false,
      description: 'Voici la description de cette carte', codeSnippet: undefined,
      footerLinks: [{'id': 'card-link-3-1','label': 'Ici','link': '.'}],
      footerLinksType: 'button'
    },
    {
      noBorder: false, shadowBorder: false, noBackground: false, greyBackground: false, showImg: false,
      title: 'Carte horizontale sans image avec un bouton', link: '.', isHorizontal: true,
      description: 'Voici la description de cette carte', codeSnippet: cshl1,
      footerLinks: [{'id': 'card-link-3-2','label': 'Ici','link': '.'}],
      footerLinksType: 'button'
    },
  ];
}
