import {Component, ViewEncapsulation} from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import {CodeSnippet} from "../../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-form-field-checkbox-example',
  templateUrl: './checkbox-example.component.html',
  encapsulation: ViewEncapsulation.None
})
export class FormFieldCheckboxExampleComponent {

  form3 = this.fb.group({
    invalid1: [null],
    invalid2: [null],
    invalid3: [null, [Validators.required]],
  })

  form4 = this.fb.group({
    valid1: [null],
    valid2: [null],
    valid3: [true, [Validators.required]],
  })

  form5 = this.fb.group({
    disabled1: [null],
    disabled2: [null],
    disabled3: [null],
  })

  constructor(private fb: FormBuilder) {
  }


  cs1: CodeSnippet = {
    html:
`<dsmj-form-field for="checkbox-1">
  <label for="checkbox-1">Case à cocher</label>
  <input type="checkbox" dsmjInput id="checkbox-1" />
</dsmj-form-field>`
  };

  cs2: CodeSnippet = {
    html:
      `<dsmj-form-group
label="Mon groupe de champs"
hint="Mon groupe de champs contient une liste de cases à cocher"
[inline]="true">
  <dsmj-form-field label="Choix 1" for="checkbox-1">
    <input type="checkbox" dsmjInput id="checkbox-1" />
  </dsmj-form-field>
  <dsmj-form-field [class]="'fr-mx-2w'" label="Choix 2" for="checkbox-2">
    <input type="checkbox" dsmjInput id="checkbox-2" />
  </dsmj-form-field>
  <dsmj-form-field required="true" label="Choix 3" for="checkbox-3">
    <input type="checkbox" dsmjInput id="checkbox-3" />
  </dsmj-form-field>
</dsmj-form-group>`
  };

  cs3: CodeSnippet = {
    html:
      `<dsmj-form-group
label="Mon groupe de champs"
hint="Mon groupe de champs contient une liste de cases à cocher"
[errorMessage]="'Le champ est invalide'"
[inline]="false">
  <dsmj-form-field label="Choix 1" for="checkbox-5">
    <input type="checkbox" dsmjInput id="checkbox-5" />
  </dsmj-form-field>
  <dsmj-form-field label="Choix 2" for="checkbox-6">
    <input type="checkbox" dsmjInput id="checkbox-6" />
  </dsmj-form-field>
  <dsmj-form-field required="true" label="Choix 3" for="checkbox-7">
    <input type="checkbox" dsmjInput id="checkbox-7" />
  </dsmj-form-field>
</dsmj-form-group>`
  };

  cs4: CodeSnippet = {
    html:
`<dsmj-form-group
  [label]="'Mon groupe de champs'"
  [hint]="'Mon groupe de champs contient une liste de cases à cocher'"
  [validMessage]="'Le champ est valide'"
  [inline]="true">
  <dsmj-form-field label="Choix 1" for="checkbox-8">
    <input type="checkbox" dsmjInput id="checkbox-8" />
  </dsmj-form-field>
  <dsmj-form-field [class]="'fr-mx-2w'"  label="Choix 2" for="checkbox-9">
    <input type="checkbox" dsmjInput id="checkbox-9" />
  </dsmj-form-field>
  <dsmj-form-field [required]="true" label="Choix 3" for="checkbox-10">
    <input type="checkbox" dsmjInput id="checkbox-10" />
  </dsmj-form-field>
</dsmj-form-group>`
  };

  cs5: CodeSnippet = {
    html:
`<dsmj-form-group
  [label]="'Mon groupe de champs'"
  [hint]="'Mon groupe de champs contient une liste de cases à cocher'"
  [disabled]="true">
  <dsmj-form-field label="Choix 1" for="checkbox-11">
    <input type="checkbox" dsmjInput id="checkbox-11" [formControlName]="'disabled1'" />
  </dsmj-form-field>
  <dsmj-form-field [class]="'fr-mx-2w'"  label="Choix 2" for="checkbox-12">
    <input type="checkbox" dsmjInput id="checkbox-12" [formControlName]="'disabled2'" />
  </dsmj-form-field>
  <dsmj-form-field [required]="true" label="Choix 3" for="checkbox-13">
    <input type="checkbox" dsmjInput id="checkbox-13" [formControlName]="'disabled3'" />
  </dsmj-form-field>
</dsmj-form-group>`
  };

  cs6: CodeSnippet = {
    html:
`<dsmj-form-group
  [label]="'Mon groupe de champs'"
  [hint]="'Mon groupe de champs contient une liste de cases à cocher'">
  <dsmj-form-field [size]="'sm'" label="Choix 1" for="checkbox-14">
    <input type="checkbox" dsmjInput id="checkbox-14" [formControlName]="'disabled1'" />
  </dsmj-form-field>
  <dsmj-form-field [size]="'sm'" [class]="'fr-mx-2w'"  label="Choix 2" for="checkbox-15">
    <input type="checkbox" dsmjInput id="checkbox-15" [formControlName]="'disabled2'" />
  </dsmj-form-field>
  <dsmj-form-field [size]="'sm'" [required]="true" label="Choix 3" for="checkbox-16">
    <input type="checkbox" dsmjInput id="checkbox-16" [formControlName]="'disabled3'" />
  </dsmj-form-field>
</dsmj-form-group>`
  };
}
