import {Component, ViewEncapsulation} from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-form-field-example',
  templateUrl: './form-field-example.component.html',
  encapsulation: ViewEncapsulation.None
})
export class FormFieldExampleComponent {

  codeSnippet: CodeSnippet = {
    html:
`<dsmj-form-field>
  <dsmj-label>Label pour liste déroulante</dsmj-label>
  <select dsmjSelect>
    <option>Selectionnez une option</option>
    <option value="1">Option 1</option>
    <option value="2">Option 2</option>
    <option value="3">Option 3</option>
    <option value="4">Option 4</option>
  </select>
</dsmj-form-field>`,
  }

  constructor(protected fb: FormBuilder) {
  }

  formGroup2: FormGroup = this.fb.group({
    select_auto_validator: ['', Validators.required],
    select_manual_validator: ['', Validators.required],
  });

  codeSnippet2: CodeSnippet = {
    html:
`<!-- Cette liste déroulante gére les erreurs /-->
<form [formGroup]="myFormGroup">
  <dsmj-form-field>
    <dsmj-label for="etat-erreur" hint="Cette liste déroulante gère l'état des erreurs du champ de manière automatique">Liste déroulante</dsmj-label>
    <select dsmjSelect id="etat-erreur" formControlName="select_auto_validator">
      <option value="">Selectionnez une option</option>
      <option value="1">Option 1</option>
      <option value="2">Option 2</option>
      <option value="3">Option 3</option>
      <option value="4">Option 4</option>
    </select>
  </dsmj-form-field>

  <!-- Cette liste déroulante ne gére pas les erreurs /-->
  <dsmj-form-field [disableValidator]="true">
    <dsmj-label for="etat-erreur-manuel" hint="Cette liste déroulante laisse le développeur gérer l'état des erreurs du champ">Liste déroulante</dsmj-label>
    <select dsmjSelect id="etat-erreur-manuel" formControlName="select_manual_validator">
      <option value="">Selectionnez une option</option>
      <option value="1">Option 1</option>
      <option value="2">Option 2</option>
      <option value="3">Option 3</option>
      <option value="4">Option 4</option>
    </select>
  </dsmj-form-field>
</form>
`,
    ts:
`myFormGroup: FormGroup = this.fb.group({
  select_auto_validator: ['', Validators.required],
  select_manual_validator: ['', Validators.required],
});`
  }

  codeSnippet3: CodeSnippet = {
    html:
`<dsmj-form-field validMessage="Texte de validation">
  <dsmj-label for="etat-valide">Liste déroulante</dsmj-label>
  <select dsmjSelect id="etat-valide">
    <option value="">Selectionnez une option</option>
    <option value="1">Option 1</option>
    <option value="2">Option 2</option>
    <option value="3">Option 3</option>
    <option value="4">Option 4</option>
  </select>
</dsmj-form-field>
`};

  codeSnippet4: CodeSnippet = {
    html:
`<dsmj-form-field [disabled]="true">
<dsmj-label for="etat-desactive">Liste déroulante</dsmj-label>
<select dsmjSelect id="etat-desactive">
  <option value="">Selectionnez une option</option>
  <option value="1">Option 1</option>
  <option value="2">Option 2</option>
  <option value="3">Option 3</option>
  <option value="4">Option 4</option>
</select>
</dsmj-form-field>
`};

  codeSnippet5: CodeSnippet = {
    html:
`<dsmj-form-field>
<dsmj-label for="texte-aide" hint="texte de description additionnel">Liste déroulante</dsmj-label>
<select dsmjSelect id="texte-aide">
  <option value="">Selectionnez une option</option>
  <option value="1">Option 1</option>
  <option value="2">Option 2</option>
  <option value="3">Option 3</option>
  <option value="4">Option 4</option>
</select>
</dsmj-form-field>
`};
}
