import {Component, ViewEncapsulation} from '@angular/core';
import { FormBuilder } from '@angular/forms';
import {CodeSnippet} from "../../../commons/models/code-snippet.model";
import {radioDataExample, radioGroupDataExample} from "./radio.data";

@Component({
  selector: 'doc-form-field-radio-example',
  templateUrl: './radio-example.component.html',
  encapsulation: ViewEncapsulation.None
})
export class FormFieldRadioExampleComponent {

  radioGroupData = radioGroupDataExample;
  data = radioDataExample;
  yesno: 'oui' | 'non' = 'oui';

  form = this.fb.group({
    'radio-default': ['2'],
    invalid: [null],
    valid: [null],
    disabled: [null],
    selectable: [null],
  })

  constructor(private fb: FormBuilder) {
  }

  formString = `
this.formBuilder.group({
  'radio-default': ['2'],
  invalid: [null],
  valid: [null],
  disabled: [null],
  selectable: [null],
});`


  cs1: CodeSnippet = {
    html:
`<!-- yesno: 'oui' | 'non' = 'oui' -->

<dsmj-radio-group [(ngModel)]="yesno" [inline]="true">
  <dsmj-radio [id]="'radio-0-yes'" [value]="'oui'">Oui</dsmj-radio>
  <dsmj-radio [id]="'radio-0-no'" [value]="'non'">Non</dsmj-radio>
</dsmj-radio-group>`
  };

  cs2: CodeSnippet = {
    html:
`<div class="fr-p-10v" style="border: 1px solid grey" [formGroup]="form">
  <dsmj-radio-group [formControlName]="'radio-default'" [inline]="true" [legend]="'Mon groupe de champs'" [legendHint]="'Mon groupe de champs contient une liste de boutons radio'">
    <dsmj-radio [id]="'radio-1'" [value]="'1'">Choix 1</dsmj-radio>
    <dsmj-radio [id]="'radio-2'" [value]="'2'">Choix 2</dsmj-radio>
    <dsmj-radio [id]="'radio-3'" [value]="'3'">Choix 3</dsmj-radio>
  </dsmj-radio-group>
<!--  <p>Valeur sélectionné : {{form?.get('radio-default')?.value | json}}</p>  -->
</div>`
  };

  cs3: CodeSnippet = {
    html:
`<div class="fr-p-10v" style="border: 1px solid grey" [formGroup]="form">
  <dsmj-radio-group
    [formControlName]="'invalid'"
    [legend]="'Mon groupe de champs'"
    [legendHint]="'Mon groupe de champs contient une liste de boutons radio'"
    [status]="'error'"
    [statusMessage]="'Le champ est invalide'"
    [inline]="false">
    <dsmj-radio [id]="'radio-4'" [value]="'1'">Choix 1</dsmj-radio>
    <dsmj-radio [id]="'radio-5'" [value]="'2'">Choix 2</dsmj-radio>
    <dsmj-radio [id]="'radio-6'" [value]="'3'">Choix 3</dsmj-radio>
  </dsmj-radio-group>
<!--  <p>Valeur sélectionné : {{form?.get('invalid')?.value | json}}</p>  -->
</div>`
  };

  cs4: CodeSnippet = {
    html:
`<div class="fr-p-10v" style="border: 1px solid grey" [formGroup]="form">
  <dsmj-radio-group
    [formControlName]="'valid'"
    [legend]="'Mon groupe de champs'"
    [legendHint]="'Mon groupe de champs contient une liste de boutons radio'"
    [status]="'success'"
    [statusMessage]="'Le champ est valide'"
    [inline]="true">
    <dsmj-radio [id]="'radio-7'" [value]="'1'">Choix 1</dsmj-radio>
    <dsmj-radio [id]="'radio-8'" [value]="'2'">Choix 2</dsmj-radio>
    <dsmj-radio [id]="'radio-9'" [value]="'3'">Choix 3</dsmj-radio>
  </dsmj-radio-group>
<!--  <p>Valeur sélectionné : {{form?.get('valid')?.value | json}}</p>  -->
</div>`
  };

  cs5: CodeSnippet = {
    html:
`<div class="fr-p-10v" style="border: 1px solid grey" [formGroup]="form">
  <dsmj-radio-group
    [formControlName]="'disabled'"
    [legend]="'Mon groupe de champs'"
    [legendHint]="'Mon groupe de champs contient une liste de boutons radio'"
    [disabled]="true">
    <dsmj-radio [id]="'radio-10'" [value]="'1'">Choix 1</dsmj-radio>
    <dsmj-radio [id]="'radio-11'" [value]="'2'">Choix 2</dsmj-radio>
    <dsmj-radio [id]="'radio-12'" [value]="'3'">Choix 3</dsmj-radio>
  </dsmj-radio-group>
<!--  <p>Valeur sélectionné : {{form?.get('disabled')?.value | json}}</p>  -->
</div>`
  };

  cs6: CodeSnippet = {
    html:
`<div class="fr-p-10v" style="border: 1px solid grey" [formGroup]="form">
  <dsmj-radio-group
    [formControlName]="'selectable'"
    [legend]="'Mon groupe de champs'"
    [legendHint]="'Mon groupe de champs contient une liste de boutons radio'">
    <dsmj-radio [id]="'radio-13'" [isSmall]="true" [value]="'1'">Choix 1</dsmj-radio>
    <dsmj-radio [id]="'radio-14'" [isSmall]="true" [value]="'2'">Choix 2</dsmj-radio>
    <dsmj-radio [id]="'radio-15'" [isSmall]="true" [value]="'3'">Choix 3</dsmj-radio>
  </dsmj-radio-group>
<!--  <p>Valeur sélectionné : {{form?.get('selectable')?.value | json}}</p>  -->
</div>`
  };
}
