import {Component, ViewEncapsulation} from '@angular/core';
import { FormBuilder } from '@angular/forms';
import {CodeSnippet} from "../../../commons/models/code-snippet.model";
import {radioGroupDataExample, radioRichDataExample} from "./radio-rich.data";

@Component({
  selector: 'doc-form-field-radio-rich-example',
  templateUrl: './radio-rich-example.component.html',
  encapsulation: ViewEncapsulation.None
})
export class FormFieldRadioRichExampleComponent {

  radioGroupData = radioGroupDataExample;
  data = radioRichDataExample;
  yesno: 'oui' | 'non' = 'oui'

  randomImg = { src: 'https://picsum.photos/80/80', alt: 'Image test' };

  form = this.fb.group({
    'radio-default': ['2'],
    'radio-default-vertical': ['1'],
    invalid: [null],
    valid: [null],
    disabled: [null],
    icon: [null],
    image: [null],
  })

  constructor(private fb: FormBuilder) {
  }

  formString = `// radio-rich-example.component.ts

  form = this.fb.group({
    'radio-default': ['2'],
    'radio-default-vertical': ['1'],
    invalid: [null],
    valid: [null],
    disabled: [null],
    icon: [null],
    image: [null],
  });`;


  cs1: CodeSnippet = {
    html:
`<dsmj-radio-extended id="radio-1" name="zazerty" [value]="true">Choix 1</dsmj-radio-extended>`
  };

  cs2: CodeSnippet = {
    html:
`<ng-container [formGroup]="form">
  <dsmj-radio-group [formControlName]="'radio-default'" [inline]="true" [legend]="'Mon groupe de champs'" [legendHint]="'Mon groupe de champs contient une liste de boutons radio riche'">
    <dsmj-radio-extended [id]="'radio-2'" [value]="'1'">Choix 1</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-3'" [value]="'2'">Choix 2</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-4'" [value]="'3'">Choix 3</dsmj-radio-extended>
  </dsmj-radio-group>
  <!--  <p>Valeur sélectionné : {{form?.get('radio-default')?.value | json}}</p>  -->
</ng-container>`
  };

  cs2b: CodeSnippet = {
    html:
`<ng-container [formGroup]="form">
  <dsmj-radio-group [inline]="false" [formControlName]="'radio-default-vertical'" [legend]="'Mon groupe de champs'" [legendHint]="'Mon groupe de champs contient une liste de boutons radio riche'">
    <dsmj-radio-extended [id]="'radio-2b'" [value]="'1'">Choix 1</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-3b'" [value]="'2'">Choix 2</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-4b'" [value]="'3'">Choix 3</dsmj-radio-extended>
  </dsmj-radio-group>
  <!--  <p>Valeur sélectionné : {{form?.get('radio-default-vertical')?.value | json}}</p>  -->
</ng-container>`
  };

  cs3: CodeSnippet = {
    html:
`<ng-container [formGroup]="form">
  <dsmj-radio-group [formControlName]="'invalid'" [inline]="false" [status]="'error'" [statusMessage]="'Le champ est invalide'" [legend]="'Mon groupe de champs'" [legendHint]="'Mon groupe de champs contient une liste de boutons radio riche'">
    <dsmj-radio-extended [id]="'radio-5'" [value]="'5'">Choix 1</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-6'" [value]="'6'">Choix 2</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-7'" [value]="'7'">Choix 3</dsmj-radio-extended>
  </dsmj-radio-group>
  <!--  <p>Valeur sélectionné : {{form?.get('invalid')?.value | json}}</p>  -->
</ng-container>`
  };

  cs4: CodeSnippet = {
    html:
`<ng-container [formGroup]="form">
  <dsmj-radio-group [formControlName]="'valid'" [inline]="true" [status]="'success'" [statusMessage]="'Le champ est valide'" [legend]="'Mon groupe de champs'" [legendHint]="'Mon groupe de champs contient une liste de boutons radio riche'">
    <dsmj-radio-extended [id]="'radio-8'" [value]="'8'">Choix 1</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-9'" [value]="'9'">Choix 2</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-10'" [value]="'10'">Choix 3</dsmj-radio-extended>
  </dsmj-radio-group>
  <!--  <p>Valeur sélectionné : {{form?.get('valid')?.value | json}}</p>  -->
</ng-container>`
  };

  cs5: CodeSnippet = {
    html:
`<ng-container [formGroup]="form">
  <dsmj-radio-group [formControlName]="'disabled'" [disabled]="true" [legend]="'Mon groupe de champs'" [legendHint]="'Mon groupe de champs contient une liste de boutons radio riche'">
    <dsmj-radio-extended [id]="'radio-11'" [value]="'11'">Choix 1</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-12'" [value]="'12'">Choix 2</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-13'" [value]="'13'">Choix 3</dsmj-radio-extended>
  </dsmj-radio-group>
  <!--  <p>Valeur sélectionné : {{form?.get('disabled')?.value | json}}</p>  -->
</ng-container>`
  };

  cs6: CodeSnippet = {
    html:
`<ng-container [formGroup]="form">
  <dsmj-radio-group [formControlName]="'icon'" [legend]="'Mon groupe de champs'" [legendHint]="'Mon groupe de champs contient une liste de boutons radio riche'">
    <dsmj-radio-extended [id]="'radio-14'" [value]="'14'" [icon]="'fr-icon-checkbox-line'">Choix 1</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-15'" [value]="'15'" [icon]="'fr-icon-close-circle-line'">Choix 2</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-16'" [value]="'16'" [icon]="'fr-icon-delete-line'">Choix 3</dsmj-radio-extended>
  </dsmj-radio-group>
  <!--  <p>Valeur sélectionné : {{form?.get('icon')?.value | json}}</p>  -->
</ng-container>`
  };

  cs7: CodeSnippet = {
    html:
`<ng-container [formGroup]="form">
  <dsmj-radio-group [formControlName]="'image'" [legend]="'Mon groupe de champs'" [legendHint]="'Mon groupe de champs contient une liste de boutons radio riche'">
    <dsmj-radio-extended [id]="'radio-17'" [value]="'17'" [img]="{ src: 'https://picsum.photos/80/80', alt: 'Image test' }">Choix 1</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-18'" [value]="'18'" [img]="{ src: 'https://picsum.photos/80/80', alt: 'Image test' }">Choix 2</dsmj-radio-extended>
    <dsmj-radio-extended [id]="'radio-19'" [value]="'19'" [img]="{ src: 'https://picsum.photos/80/80', alt: 'Image test' }">Choix 3</dsmj-radio-extended>
  </dsmj-radio-group>
  <!--  <p>Valeur sélectionné : {{form?.get('image')?.value | json}}</p>  -->
</ng-container>`
  };
}
