import {Component, OnInit, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {FormBuilder, Validators} from "@angular/forms";
import {BehaviorSubject, Observable} from "rxjs";
import {InputValue} from "@mjfr/ng-dsmj";

@Component({
  selector: 'doc-input-autocomplete-example',
  templateUrl: './input-autocomplete-example.component.html',
  styleUrls: ['./input-autocomplete-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class InputAutocompleteExampleComponent implements OnInit {

  list = new BehaviorSubject<InputValue[]>([]);
  datas: InputValue[] = [
    { value: '0', label: 'Afrique' },
    { value: '1', label: 'Amérique' },
    { value: '2', label: 'Asie' },
    { value: '3', label: 'Europe' },
    { value: '4', label: 'Océanie' },
  ];

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: '',
  })

  get list$ (): Observable<InputValue[]> {
    return this.list.asObservable();
  }

  constructor(protected fb: FormBuilder) {
  }

  ngOnInit(): void {
    this.list.next(this.datas)
  }

  codeSnippet: CodeSnippet = {
    html:
`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input-autocomplete nameInput="optional" [inputValues]="list$" label="Optional" class="fr-col-4"></dsmj-input-autocomplete>
  <dsmj-input-autocomplete nameInput="required" [inputValues]="list$" label="Required" class="fr-col-4"></dsmj-input-autocomplete>
  <dsmj-input-autocomplete nameInput="disabled" [inputValues]="list$" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input-autocomplete>
</div>`,
    ts:
`@Component({
  selector: 'input-autocomplete-example',
  templateUrl: './input-autocomplete-example.component.html',
  styleUrls: ['./input-autocomplete-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ExampleComponent {

  list = new BehaviorSubject([
    { value: '0', label: 'Afrique' },
    { value: '1', label: 'Amérique' },
    { value: '2', label: 'Asie' },
    { value: '3', label: 'Europe' },
    { value: '4', label: 'Océanie' },
  ]);

  formGroup = this.fb.group({
    lastname: ['', Validators.required],
    firstname: ['', Validators.required],
    birthdate: '',
  })

  get list$ () {
    return this.list.asObservable();
  }

  constructor(protected fb: FormBuilder) {
  }

}`,
  }
}
