import {Component, ViewEncapsulation} from '@angular/core';
import {FormBuilder, Validators} from "@angular/forms";
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-input-date-example',
  templateUrl: './input-date-example.component.html',
  styleUrls: ['./input-date-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class InputDateExampleComponent  {

  formGroup = this.fb.group({
    dOptional: '',
    dRequired: ['', Validators.required],
    dDisabled: '',
    error: [null, Validators.required],
    success: ['2023-01-01', Validators.required],
  })

  constructor(protected fb: FormBuilder) {
    this.formGroup.get('error').markAsTouched()
    this.formGroup.get('error').markAsDirty()
    this.formGroup.get('success').markAsTouched()
    this.formGroup.get('success').markAsDirty()
    this.formGroup.updateValueAndValidity()
  }

  codeSnippet: CodeSnippet = {
    html:
`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input type="date" id="date-optional" nameInput="optional" label="Optional" class="fr-col-4"></dsmj-input>
  <dsmj-input type="date" id="date-required" nameInput="required" label="Required" class="fr-col-4"></dsmj-input>
  <dsmj-input type="date" id="date-disabled" nameInput="disabled" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input>
</div>`,
    ts:
`@Component({
  selector: 'input-date-example',
  templateUrl: './input-date-example.component.html',
  styleUrls: ['./input-date-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ExampleComponent {
  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {}
}`,
    css:
`.fr-fi-calendar-line::before {
  content: none;
}`
  }
}
