import {ChangeDetectionStrategy, Component} from '@angular/core';
import {FormBuilder, Validators} from "@angular/forms";
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-input-example',
  templateUrl: './input-example.component.html',
  styleUrls: ['./input-example.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class InputExampleComponent  {

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: '',
    error: [null, Validators.required],
    success: ['champ valide', Validators.required],
  })

  constructor(protected fb: FormBuilder) {
    this.formGroup.get('error').markAsTouched()
    this.formGroup.get('error').markAsDirty()
    this.formGroup.get('success').markAsTouched()
    this.formGroup.get('success').markAsDirty()
    this.formGroup.updateValueAndValidity()
  }

  properties: any = [
    {
      name: 'type',
      inOut: 'input',
      type: 'string',
      required: false,
      default: 'text',
      description: 'Défini le type de la balise input'
    },{
      name: 'pattern',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Format regex attendu à la saisie"
    },{
      name: 'list',
      inOut: 'input',
      type: 'string[]',
      required: false,
      default: undefined,
      description: "Contient un ensemble d'éléments qui représentent les valeurs possibles pour l'attribut list de l'input."
    },{
      name: 'min',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "L'attribut min définit la valeur minimale qui est acceptable et valide pour l'entrée contenant l'attribut"
    },{
      name: 'max',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "L'attribut max définit la valeur maximale acceptable et valide pour le champ de saisie contenant l'attribut"
    },{
      name: 'step',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "L'attribut step est un nombre qui indique l'incrément que la valeur doit suivre ou le mot-clé any"
    },{
      name: 'shouldShowError',
      inOut: 'input',
      type: 'string',
      required: false,
      default: "true",
      description: "Active la gestion des erreurs."
    },{
      name: 'shouldShowValid',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Active la gestion du champ valide"
    },{
      name: 'validationMessage',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Ajoute un texte de validation"
    },{
      name: 'hintText',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Texte additionnel en dessous du label permettant d'apporter des détails au champ"
    }
  ];


  codeSnippet: CodeSnippet = {
    html:
`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input nameInput="optional" label="Optional" class="fr-col-4"></dsmj-input>
  <dsmj-input nameInput="required" label="Required" class="fr-col-4"></dsmj-input>
  <dsmj-input nameInput="disabled" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input>
  <dsmj-input nameInput="error" label="Error" class="fr-col-4"></dsmj-input>
  <dsmj-input nameInput="success" label="Success" class="fr-col-4"></dsmj-input>
</div>`,
    ts:
`@Component({
  selector: 'input-text-example',
  templateUrl: './input-text-example.component.html',
  styleUrls: ['./input-text-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ExampleComponent {
  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {}
}`,
  }
}
