import {Component, ViewEncapsulation} from '@angular/core';
import {FormBuilder, Validators} from "@angular/forms";
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-input-number-example',
  templateUrl: './input-number-example.component.html',
  styleUrls: ['./input-number-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class InputNumberExampleComponent  {

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: '',
    error: [null, Validators.required],
    success: [86, Validators.required],
  })

  constructor(protected fb: FormBuilder) {
    this.formGroup.get('error').markAsTouched()
    this.formGroup.get('error').markAsDirty()
    this.formGroup.get('success').markAsTouched()
    this.formGroup.get('success').markAsDirty()
    this.formGroup.updateValueAndValidity()
  }

  codeSnippet: CodeSnippet = {
    html:
`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input type="number" id="number-optional" nameInput="optional" label="Optional" class="fr-col-4"></dsmj-input>
  <dsmj-input type="number" id="number-required" nameInput="required" label="Required" class="fr-col-4"></dsmj-input>
  <dsmj-input type="number" id="number-disabled" nameInput="disabled" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input>
</div>`,
    ts:
`@Component({
  selector: 'input-number-example',
  templateUrl: './input-number-example.component.html',
  styleUrls: ['./input-number-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ExampleComponent {
  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {}
}`,
  }
}
