import {Component, OnInit, ViewEncapsulation} from '@angular/core';
import {FormBuilder, Validators} from "@angular/forms";
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {InputValue} from "@mjfr/ng-dsmj";

@Component({
  selector: 'doc-input-select-dynamic-example',
  templateUrl: './input-select-dynamic-example.component.html',
  styleUrls: ['./input-select-dynamic-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class InputSelectDynamicExampleComponent implements OnInit {

  listDynamic: InputValue[] = [];
  list1: InputValue[] = [];
  list2: InputValue[] = [];
  list3: InputValue[] = [];
  list: InputValue[] = [
    { value: 'africa', label: 'Afrique' },
    { value: 'america', label: 'Amérique' },
    { value: 'asia', label: 'Asie' },
    { value: 'europe', label: 'Europe' },
    { value: 'oceania', label: 'Océanie' },
  ]

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: '',
    search: '',
    hide: [['africa','america']],
    show: [['africa','america']]
  })

  constructor(protected fb: FormBuilder) {
  }

  ngOnInit(): void {
    this.listDynamic = [...this.list];
  }

  addItem($event: InputValue): void {
    let val = this.listDynamic.find(v => v.label.toLowerCase() == $event.label.toLowerCase())
    if (val) {
      return
    }
    this.listDynamic.push($event);
  }

  codeSnippet: CodeSnippet = {
    html:
`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input-select-multiple-dynamic nameInput="optional" [inputValues]="list" label="Optional" class="fr-col-4"></dsmj-input-select-multiple-dynamic>
  <dsmj-input-select-multiple-dynamic nameInput="required" [inputValues]="list" label="Required" class="fr-col-4"></dsmj-input-select-multiple-dynamic>
  <dsmj-input-select-multiple-dynamic nameInput="disabled" [inputValues]="list" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input-select-multiple-dynamic>
</div>`,
    ts:
`import {InputValue} from "@mjfr/ng-dsmj";

@Component({
  selector: 'input-select-example',
  templateUrl: './input-select-example.component.html',
  styleUrls: ['./input-select-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ExampleComponent {
  list: InputValue[] = [
    { value: '0', label: 'Afrique' },
    { value: '1', label: 'Amérique' },
    { value: '2', label: 'Asie' },
    { value: '3', label: 'Europe' },
    { value: '4', label: 'Océanie' },
  ]

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {}
}`,
  }
}
