import {Component, ViewEncapsulation} from '@angular/core';
import {FormBuilder, Validators} from "@angular/forms";
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {InputValue} from "@mjfr/ng-dsmj";

@Component({
  selector: 'doc-input-select-example',
  templateUrl: './input-select-example.component.html',
  styleUrls: ['./input-select-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class InputSelectExampleComponent  {

  list: InputValue[] = [
    { value: '0', label: 'Afrique' },
    { value: '1', label: 'Amérique' },
    { value: '2', label: 'Asie' },
    { value: '3', label: 'Europe' },
    { value: '4', label: 'Océanie' },
  ]

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {
  }

  codeSnippet: CodeSnippet = {
    html:
`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input-select nameInput="optional" [inputValues]="list" label="Optional" class="fr-col-4"></dsmj-input-select>
  <dsmj-input-select nameInput="required" [inputValues]="list" label="Required" class="fr-col-4"></dsmj-input-select>
  <dsmj-input-select nameInput="disabled" [inputValues]="list" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input-select>
</div>`,
    ts:
`import {InputValue} from "@mjfr/ng-dsmj";

@Component({
  selector: 'input-select-example',
  templateUrl: './input-select-example.component.html',
  styleUrls: ['./input-select-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ExampleComponent {
  list: InputValue[] = [
    { value: '0', label: 'Afrique' },
    { value: '1', label: 'Amérique' },
    { value: '2', label: 'Asie' },
    { value: '3', label: 'Europe' },
    { value: '4', label: 'Océanie' },
  ]

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {}
}`,
  }
}
