import {Component, ViewEncapsulation} from '@angular/core';
import {FormBuilder, Validators} from "@angular/forms";
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {InputValue} from "@mjfr/ng-dsmj";
import {Banner} from "../../../../../lib";

@Component({
  selector: 'doc-input-select-multiple-example',
  templateUrl: './input-select-multiple-example.component.html',
  styleUrls: ['./input-select-multiple-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class InputSelectMultipleExampleComponent  {

  ban: Banner[] = [
    {
      message: "'blable'",
      type: 'error',
      options: {
        fade: true,
        keepAfterRouteChange: true
      }
    }
  ]

  list: InputValue[] = [
    { value: 'africa', label: 'Afrique' },
    { value: 'america', label: 'Amérique' },
    { value: 'asia', label: 'Asie' },
    { value: 'europe', label: 'Europe' },
    { value: 'oceania', label: 'Océanie' },
  ]

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: '',
    search: '',
    hide: [['africa','america']],
    show: [['africa','america']]
  })

  constructor(protected fb: FormBuilder) {
  }

  codeSnippet: CodeSnippet = {
    html:
`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input-select-multiple nameInput="optional" [inputValues]="list" label="Optional" class="fr-col-4"></dsmj-input-select-multiple>
  <dsmj-input-select-multiple nameInput="required" [inputValues]="list" label="Required" class="fr-col-4"></dsmj-input-select-multiple>
  <dsmj-input-select-multiple nameInput="disabled" [inputValues]="list" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input-select-multiple>

  <dsmj-input-select-multiple id="select-search" nameInput="search" [inputValues]="list" label="With search bar" [withSearch]="true" class="fr-col-4"></dsmj-input-select-multiple>
  <dsmj-input-select-multiple id="select-hide" nameInput="hide" [inputValues]="list" label="Selected and Hide" [showValues]="false" class="fr-col-4"></dsmj-input-select-multiple>
  <dsmj-input-select-multiple id="select-show" nameInput="show" [inputValues]="list" label="Selected and shown" class="fr-col-4"></dsmj-input-select-multiple>
</div>`,
    ts:
`import {InputValue} from "@mjfr/ng-dsmj";

@Component({
  selector: 'input-select-multiple-example',
  templateUrl: './input-select-multiple-example.component.html',
  styleUrls: ['./input-select-multiple-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ExampleComponent {
  list: InputValue[] = [
    { value: '0', label: 'Afrique' },
    { value: '1', label: 'Amérique' },
    { value: '2', label: 'Asie' },
    { value: '3', label: 'Europe' },
    { value: '4', label: 'Océanie' },
  ]

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {}
}`,
  }
}
