import {Component, OnInit, ViewEncapsulation} from '@angular/core';
import {FormBuilder, Validators} from "@angular/forms";
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-input-time-example',
  templateUrl: './input-time-example.component.html',
  styleUrls: ['./input-time-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class InputTimeExampleComponent {

  formGroup = this.fb.group({
    custom: '',
    required: ['', Validators.required],
    disabled: '',
    error: [null, Validators.required],
    success: ['11:11', Validators.required],
  })

  constructor(protected fb: FormBuilder) {
    this.formGroup.get('error').markAsTouched()
    this.formGroup.get('error').markAsDirty()
    this.formGroup.get('success').markAsTouched()
    this.formGroup.get('success').markAsDirty()
    this.formGroup.updateValueAndValidity()
  }

  list = [
    '06:00',
    '07:00',
    '08:00',
    '09:00',
    '10:00',
    '11:00',
    '12:00',
    '13:00',
    '14:00',
    '15:00',
    '16:00',
    '17:00',
    '18:00',
    '19:00',
    '20:00',
    '21:00',
    '22:00',
  ]
  min = '08:00'
  max = '20:00'
  step = '3600'

  codeSnippet: CodeSnippet = {
    html:
`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input-time id="time-custom" [list]="list" [min]="min" [max]="max" [step]="step" nameInput="custom" label="Custom liste" class="fr-col-4"></dsmj-input-time>
  <dsmj-input-time id="time-required" nameInput="required" label="Required" class="fr-col-4"></dsmj-input-time>
  <dsmj-input-time nameInput="disabled" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input-time>
</div>`,
    ts:
`@Component({
  selector: 'input-time-example',
  templateUrl: './input-time-example.component.html',
  styleUrls: ['./input-time-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ExampleComponent {
  formGroup = this.fb.group({
    custom: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {}

  list = [
    '06:00',
    '07:00',
    '08:00',
    '09:00',
    '10:00',
    '11:00',
    '12:00',
    '13:00',
    '14:00',
    '15:00',
    '16:00',
    '17:00',
    '18:00',
    '19:00',
    '20:00',
    '21:00',
    '22:00',
  ]
  min = '08:00'
  max = '20:00'
  step = '3600'
}`,
    css:
`.fr-fi-calendar-line::before {
  content: none;
}`
  }
}
