import {Component, TemplateRef, ViewChild, ViewEncapsulation,OnInit} from '@angular/core';
import {FormBuilder, Validators} from "@angular/forms";
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {InsideModalComponent as InsideModalView} from "./inside-modal.component";
import {InsideFormModalComponent as InsideModalForm} from "./inside-form-modal.component";
import {ModalComponent, ModalService} from "@mjfr/ng-dsmj";
import codeSnippet from "./snippet/simple";
import codeSnippetZA from "./snippet/zone-action";
import codeSnippetForm from "./snippet/formulaire";
import {modalDataExample} from "./modal.data";
import {Property} from "../../commons/models/subject-data.model";
import * as dsfr from '@gouvfr/dsfr/dist/dsfr.module.js';
declare var dsfr: any;

@Component({
  selector: 'doc-modal-example',
  templateUrl: './modal-example.component.html',
  styleUrls: ['./modal-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class ModalExampleComponent {
  @ViewChild('templateInsideModal') insideModal: TemplateRef<any>
  @ViewChild('insideChild') insideChild: InsideModalView
  @ViewChild('templateInsideFormModal') insideFormModal: TemplateRef<any>
  @ViewChild('insideFormChild') insideFormChild: InsideModalForm

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  data = {
    description: 'Le contenu d\'une modale est totalement customizable lorsqu\'on y place un template'
  };

  modalData = modalDataExample;
  helpItems = []

  get modaleOptionsProperties(): Property[] {
    return [
      {
        name: 'title',
        inOut: 'input',
        type: 'string',
        description: 'Titre de la modale'
      },
      {
        name: 'iconTitleClass',
        inOut: 'input',
        type: 'string',
        description: 'Classes icon à appliquer à côté du titre'
      },
      {
        name: 'classes',
        inOut: 'input',
        type: 'string',
        description: 'Classes à appliquer'
      },
      {
        name: 'bodyTpl',
        inOut: 'input',
        type: 'TemplateRef<any>',
        description: 'Component à afficher à l\'intérieur de la modale'
      },
      {
        name: 'message',
        inOut: 'input',
        type: 'string',
        description: 'Message à afficher à l\'intérieur de la modale'
      },
      {
        name: 'data',
        inOut: 'input',
        type: 'object',
        description: 'Propriétés à récupérer depuis la modal'
      },
      {
        name: 'buttons',
        inOut: 'input',
        type: '{ confirm: string | ButtonOptions, cancel: string | ButtonOptions }',
        description: 'Voir le tableau ci-dessous pour en savoir plus sur le type ButtonOptions'
      },
    ]
  }

  get modaleButtonOptionsProperties(): Property[] {
    return [
      {
        name: 'label',
        inOut: 'input',
        type: 'string',
        description: 'Titre de la modale'
      },
      {
        name: 'call',
        inOut: 'input',
        type: 'Function',
        description: 'function à éxécuter au clique'
      },
      {
        name: 'classes',
        inOut: 'input',
        type: 'string',
        description: 'Classes à appliquer'
      },
      {
        name: 'options',
        inOut: 'input',
        type: '{ disabled: boolean }',
        description: 'désactiver ou non le bouton'
      }
    ]
  }

  appModule = `\
import DsmjModalModule from '@mjfr/ng-dsmj';

@NgModule ({
  imports: [
    DsmjModalModule,
  ]
})
class AppModule {}`

  appOpenModal = `\
...
import {ModalComponent, ModalService} from "@mjfr/ng-dsmj";

@Component({
...
})
...

@ViewChild('templateInsideModal') insideModal: TemplateRef<any>
@ViewChild('insideChild') insideChild: InsideModalView

data = {
  description: 'Le contenu d\\'une modale est totalement customizable lorsqu\\'on y place un template'
};

constructor(protected modalService: ModalService) {}

openModal() {
  const modalRef = this.modalService.open(ModalComponent, {
    title: "Titre de la modale", // titre de la modal
    iconTitleClass: '', // classes icon à appliquer à côté du titre
    classes: undefined, // classes à appliquer
    bodyTpl: this.insideModal, // component à afficher à l'intérieur de la modale
    message: "This modal can show a message or a template", // message à afficher à l'intérieur de la modale
    data: data // propriétés à récupérer depuis la modal
    buttons: { // les boutons sont optionnels, à modifier uniquement si le model par défaut ne convient pas
      confirm: {
        label: 'Oui' // nom du bouton de confirmation
        call: () => {console.log('call yes')} // function à exécuter au click
        classes: 'fr-btn fr-btn-primary' // classes à appliquer au bouton
        options: { disabled: false } // options permet uniquement de définir si le bouton est désactivé ou non
      }
      cancel: {
        label: 'Non' // nom du bouton de confirmation
        call: () => {console.log('call no')} // function à exécuter au click
        classes: 'fr-btn fr-btn-secondary' // classes à appliquer au bouton
        options: { disabled: false } // options permet uniquement de définir si le bouton est désactivé ou non
      }
    }
  });

  modalRef.onResult().subscribe(
    {
      // action à effectuer lorsque la modale est fermé via un bouton d'action
      next: closed => {},
      // action à effectuer lorsque la modale est fermé
      // via le bouton du haut ou le bouton d'action 'cancel'
      error: dismissed => {
      },
      // action à effectuer après la fermeture de la modale
      complete: () => {
      }
    }
  );
}

...`

  appModalTemplate = `\
<ng-template #templateInsideModal let-data="data">
  <doc-inside-modal #insideChild [data]="data"></doc-inside-modal>
</ng-template>`

  constructor(protected fb: FormBuilder, protected modalService: ModalService) {}

  openModal(): void {
    const modalRef = this.modalService.open(ModalComponent, {
      title: "Titre de modal simple",
      bodyTpl: this.insideModal,
      buttons: {},
      id: "dsmj-modale-1"
    });

    modalRef.onResult().subscribe(
      {
        next: closed => {},
        error: dismissed => {},
        complete: () => {}
      }
    );
  }

  openModalZA(): void {
    const modalRef = this.modalService.open(ModalComponent, {
      title: "Titre de la modale",
      iconTitleClass: "fr-icon-pen-nib-line",
      bodyTpl: this.insideModal,
      buttons: {
        confirm: {
          label: 'Valider',
          classes: 'fr-btn fr-btn--primary fr-col-6 fr-col-md-4',
          call: () => {
            // @ts-ignore
            alert('Bravo :)')
          }
        },
        cancel: {
          label: 'Annuler',
          classes: 'fr-btn fr-btn--secondary fr-col-6 fr-col-md-4',
          call: () => {
            modalRef.close('cancel')
          }
        }
      },
      id: "dsmj-modale-2"
    });

    modalRef.onResult().subscribe(
      {
        next: closed => {},
        error: dismissed => {},
        complete: () => {}
      }
    );
  }

  openModalForm(): void {
    const modalRef = this.modalService.open(ModalComponent, {
      title: "Titre de la modale",
      iconTitleClass: "fr-icon-edit-box-line fr-fi--lg",
      bodyTpl: this.insideFormModal,
      data: this.data,
      buttons: {
        confirm: {
          label: 'Valider',
          classes: 'fr-btn fr-btn--primary fr-col-6 fr-col-md-4',
          call: () => {
            // @ts-ignore
            alert('Bravo :)')
          }
        },
        cancel: {
          label: 'Annuler',
          classes: 'fr-btn fr-btn--secondary fr-col-6 fr-col-md-4',
          call: () => {
            modalRef.close('cancel')
          }
        }
      },
      id: "dsmj-modale-3"
    });

    modalRef.onResult().subscribe(
      {
        next: closed => {},
        error: dismissed => {},
        complete: () => {}
      }
    );
  }

  codeSnippet: CodeSnippet = codeSnippet;
  codeSnippetZA: CodeSnippet = codeSnippetZA;
  codeSnippetForm: CodeSnippet = codeSnippetForm;
}
