import {CodeSnippet} from "../../../commons/models/code-snippet.model";

const codeSnippetForm: CodeSnippet = {
  html:
`<div>
  <button class="fr-btn justify-content-center" data-fr-opened="false" aria-controls="dsmj-modal-3" title="Modale avec formulaire" (click)="openModal()">Modal avec formulaire</button>
</div>

<ng-template #templateInsideFormModal let-data="data">
  <doc-inside-form-modal #insideFormChild [data]="data"></doc-inside-form-modal>
</ng-template>
`,
  ts:
    `import {InsideModalFormComponent as InsideModalForm} from "./inside-form-modal.component";
import {ModalComponent, ModalService} from "@mjfr/ng-dsmj";

@Component({
    selector: 'modal-example',
    templateUrl: './modal-example.component.html',
    styleUrls: ['./modal-example.component.scss'],
    encapsulation: ViewEncapsulation.None
})
export class ModalExampleComponent {
  @ViewChild('templateInsideFormModal') insideFormModal: TemplateRef<any>
  @ViewChild('insideFormChild') insideFormChild: InsideModalForm

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder, protected modalService: ModalService) {}

  getData() {
    return {
      description: "Le contenu d'une modale est totalement customizable lorsqu'on y place un template";
    }
  }

  openModal() {
    const modalRef = this.modalService.open(ModalComponent, {
      title: "Titre de la modale",
      iconTitleClass: "fr-icon-edit-box-line fr-fi--lg",
      bodyTpl: this.insideFormModal,
      data: this.getData(), // Data needed inside your modal
      buttons: {
        confirm: {
          label: 'Valider',
          classes: 'fr-btn fr-btn--primary fr-col-6 fr-col-md-4',
          call: () => {
            // @ts-ignore
            alert('Bravo :)')
          }
        },
        cancel: {
          label: 'Annuler',
          classes: 'fr-btn fr-btn--secondary fr-col-6 fr-col-md-4',
          call: () => {
            modalRef.close('cancel')
          }
        }
      },
      id: "dsmj-modale-3"
    });

    modalRef.onResult().subscribe(
      {
        next: closed => {
          console.log('closed', closed)
        },
        error: dismissed => {
        },
        complete: () => {
        }
      }
    );
  }
}


@Component({
  selector: 'doc-inside-form-modal',
  encapsulation: ViewEncapsulation.None,
  template:
\`<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <p class="fr-col-12">{{data.desciption}}</p>
</div>
<div [formGroup]="formGroup" class="fr-grid-row fr-grid-row--gutters">
  <dsmj-input type="text" id="text-optional" nameInput="optional" label="Optional" class="fr-col-4"></dsmj-input>
  <dsmj-input type="text" id="text-required" nameInput="required" label="Required" class="fr-col-4"></dsmj-input>
  <dsmj-input type="text" id="text-disabled" nameInput="disabled" [isDisabled]="true" label="Disabled" class="fr-col-4"></dsmj-input>
</div>\`
})
export class InsideModalComponent {
  @Input() data?: { desciption: string };

  formGroup = this.fb.group({
    optional: '',
    required: ['', Validators.required],
    disabled: ''
  })

  constructor(protected fb: FormBuilder) {}
}`,
}

export default codeSnippetForm;
