import {CodeSnippet} from "../../../commons/models/code-snippet.model";


const codeSnippetZA: CodeSnippet = {
  html:
`<div>
  <button class="fr-btn justify-content-center" data-fr-opened="false" aria-controls="dsmj-modal-2" title="Modal avec zone d'action" (click)="openModal()">Modal avec zone d'action</button>
</div>

<ng-template #templateInsideModal let-data="data">
  <doc-inside-modal #insideChild [data]="data"></doc-inside-modal>
</ng-template>
`,
  ts:
    `import {InsideModalComponent as InsideModalForm} from "./inside-modal.component";
import {ModalComponent, ModalService} from "@mjfr/ng-dsmj";

@Component({
    selector: 'modal-example',
    templateUrl: './modal-example.component.html',
    styleUrls: ['./modal-example.component.scss'],
    encapsulation: ViewEncapsulation.None
})
export class ModalExampleComponent {
  @ViewChild('templateInsideModal') insideModal: TemplateRef<any>
  @ViewChild('insideChild') insideChild: InsideModalForm

  constructor(protected modalService: ModalService) {}

  openModal() {
    const modalRef = this.modalService.open(ModalComponent, {
      title: "Titre de la modale",
      iconTitleClass: "fr-icon-pen-nib-line",
      bodyTpl: this.insideModal,
      buttons: {
        confirm: {
          label: 'Valider',
          classes: 'fr-btn fr-btn--primary fr-col-6 fr-col-md-4',
          call: () => {
            // @ts-ignore
            alert('Bravo :)')
          }
        },
        cancel: {
          label: 'Annuler',
          classes: 'fr-btn fr-btn--secondary fr-col-6 fr-col-md-4',
          call: () => {
            modalRef.close('cancel')
          }
        }
      },
      id: "dsmj-modale-2"
    });

    modalRef.onResult().subscribe(
      {
        next: closed => {
          console.log('closed', closed)
        },
        error: dismissed => {
        },
        complete: () => {
        }
      }
    );
  }
}

@Component({
  selector: 'doc-inside-modal',
  encapsulation: ViewEncapsulation.None,
  template:
\`<p>
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas varius tortor nibh, sit
  amet tempor nibh finibus et. Aenean eu enim justo. Vestibulum aliquam hendrerit molestie.
  Mauris malesuada nisi sit amet augue accumsan tincidunt. Maecenas tincidunt, velit ac
  porttitor pulvinar, tortor eros facilisis libero, vitae commodo nunc quam et ligula. Ut
  nec ipsum sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. Integer id
  nisi nec nulla luctus lacinia non eu turpis. Etiam in ex imperdiet justo tincidunt
  egestas. Ut porttitor urna ac augue cursus tincidunt sit amet sed orci.
</p>\`
})
export class InsideModalComponent {
}`,
}

export default codeSnippetZA;
