import {Component} from "@angular/core";
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-sidemenu-example',
  templateUrl: './sidemenu-example.component.html'
})
export class SidemenuExampleComponent {
  properties: any = [
    {
      name: 'title',
      inOut: 'input',
      type: 'string',
      required: false,
      default: "",
      description: `Définit un titre au menu latéral`
    },
    {
      name: 'sticky',
      inOut: 'input',
      type: 'boolean',
      required: false,
      default: "false",
      description: `Permet de fixer le menu latéral sur son conteneur parent`
    },
    {
      name: 'stickyFullHeight',
      inOut: 'input',
      type: 'boolean',
      required: false,
      default: "false",
      description: `Permet de fixer le menu latéral sur toute la hauteur de le page`
    },
    {
      name: 'position',
      inOut: 'input',
      type: 'left | right',
      required: false,
      default: "left",
      description: `Définit le positionnement du menu latéral, soit à gauche, soit à droite`
    }
  ];

  cs1: CodeSnippet = {
    html:
`<dsmj-sidemenu title="Menu latéral à niveau unique">
  <ul>
    <li dsmj-sidemenu-item>
      <a dsmjSidemenuLink href="#/" [current]="true">Accès direct de niveau 1</a>
    </li>
    <li dsmj-sidemenu-item>
      <a dsmjSidemenuLink href="#/">Accès direct de niveau 1</a>
    </li>
    <li dsmj-sidemenu-item>
      <a dsmjSi demenuLink href="#/">Accès direct de niveau 1</a>
    </li>
  </ul>
</dsmj-sidemenu>`
};

cs2: CodeSnippet = {
  html:
`<dsmj-sidemenu title="Menu latéral à 2 niveaux">
  <ul>
    <li dsmj-sidemenu-item>
      <button dsmjSidemenuButton [current]="true">Sous-menu de niveau 1</button>
      <ul>
        <li dsmj-sidemenu-item>
          <a dsmjSidemenuLink href="#/">Accès direct de niveau 2</a>
        </li>
        <li dsmj-sidemenu-item>
          <a dsmjSidemenuLink href="#/">Accès direct de niveau 2</a>
        </li>
        <li dsmj-sidemenu-item>
          <a dsmjSidemenuLink href="#/">Accès direct de niveau 2</a>
        </li>
      </ul>
    </li>
  </ul>
</dsmj-sidemenu>`
};

cs3: CodeSnippet = {
  html:
`<dsmj-sidemenu title="Menu latéral à 3 niveaux">
  <ul>
    <li dsmj-sidemenu-item>
      <button dsmjSidemenuButton [current]="true">Sous-menu de niveau 1</button>
      <ul>
        <li dsmj-sidemenu-item>
          <button dsmjSidemenuButton>Sous-menu de niveau 2</button>
          <ul>
            <li dsmj-sidemenu-item>
              <a dsmjSidemenuLink href="#/">Accès direct de niveau 3</a>
            </li>
          </ul>
          <ul>
            <li dsmj-sidemenu-item>
              <a dsmjSidemenuLink href="#/">Accès direct de niveau 3</a>
            </li>
          </ul>
          <ul>
            <li dsmj-sidemenu-item>
              <a dsmjSidemenuLink href="#/">Accès direct de niveau 3</a>
            </li>
          </ul>
        </li>
      </ul>
    </li>
  </ul>
</dsmj-sidemenu>`
  };

  cs4: CodeSnippet = {
    html:
`<dsmj-sidemenu title="Menu latéral avec menu sélectionné">
  <ul>
    <li dsmj-sidemenu-item>
      <a dsmjSidemenuLink href="#/">Accès direct</a>
    </li>
    <li dsmj-sidemenu-item>
      <a dsmjSidemenuLink href="#/" [current]="true">Accès direct actif</a>
    </li>
    <li dsmj-sidemenu-item>
      <a dsmjSidemenuLink href="#/">Accès direct</a>
    </li>
  </ul>
</dsmj-sidemenu>`
  };

  cs5: CodeSnippet = {
    html:
`<dsmj-sidemenu title="Menu latéral avec menu déplié">
  <ul>
    <li dsmj-sidemenu-item>
      <button dsmjSidemenuButton [expanded]="true" [current]="true">Sous-menu déplié</button>
      <ul>
        <li dsmj-sidemenu-item>
          <a dsmjSidemenuLink href="#/">Accès direct</a>
        </li>
        <li dsmj-sidemenu-item>
          <a dsmjSidemenuLink href="#/">Accès direct</a>
        </li>
        <li dsmj-sidemenu-item>
          <a dsmjSidemenuLink href="#/">Accès direct</a>
        </li>
      </ul>
    </li>
  </ul>
</dsmj-sidemenu>`
  };

  cs6: CodeSnippet = {
    html:
`<dsmj-sidemenu title="Menu latéral positionné à droite" position="right">
  <ul>
    <li dsmj-sidemenu-item>
      <a dsmjSidemenuLink href="#/" [current]="true">Accès direct</a>
    </li>
    <li dsmj-sidemenu-item>
      <a dsmjSidemenuLink href="#/">Accès direct</a>
    </li>
    <li dsmj-sidemenu-item>
      <a dsmjSidemenuLink href="#/">Accès direct</a>
    </li>
  </ul>
</dsmj-sidemenu>`
  };
}
