import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import { DsmjSummaryItem } from "@mjfr/ng-dsmj";

@Component({
  selector: 'doc-summary-example',
  templateUrl: './summary-example.component.html',
  encapsulation: ViewEncapsulation.None
})

export class SummaryExampleComponent {
  public sumList:DsmjSummaryItem[] = [
    {title: "Titre de l'ancre 1", anchor: "titre-ancre-1"},
    {title: "Titre de l'ancre 2", anchor: "titre-ancre-2"},
    {title: "Titre de l'ancre 3", anchor: "titre-ancre-3"},
    {title: "Titre de l'ancre 4", anchor: "titre-ancre-4"},
    {title: "Titre de l'ancre 5", anchor: "titre-ancre-5"},
  ]

  public id: string = 'sommaire-avec-mon-id-1';

  properties: any = [
    {
      name: 'list',
      inOut: 'input',
      type: 'DsmjSummaryItem[]',
      required: true,
      default: undefined,
      description: "La liste des titres de section d’une page avec leurs ancres au format : [ { title: string, anchor: string } ]"
    },{
      name: 'containerTitleId',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Spécifie l'id voulue du titre du sommaire"
    }
  ];

  cs1: CodeSnippet = {
    html:`<dsmj-summary \n  [list]="sumList" \n  [containerId]="id"\n></dsmj-summary>`,
    ts:`import { Component } from '@angular/core';
import { DsmjSummaryItem } from "@mjfr/ng-dsmj";
    
@Component({
  selector: 'doc-summary-example',
  templateUrl: './summary-example.component.html',
})
    
export class SummaryExampleComponent {
  public sumList:DsmjSummaryItem[] = [
    {title: "Titre de l'ancre 1", anchor: "titre-ancre-1"},
    {title: "Titre de l'ancre 2", anchor: "titre-ancre-2"},
    {title: "Titre de l'ancre 3", anchor: "titre-ancre-3"},
    {title: "Titre de l'ancre 4", anchor: "titre-ancre-4"},
    {title: "Titre de l'ancre 5", anchor: "titre-ancre-5"},
  ]

  public id: string = 'sommaire-avec-mon-id-1';
}`
  }

  cs2: CodeSnippet = {
    html:`<dsmj-summary [list]="sumList"></dsmj-summary>`,
    ts:`import { Component } from '@angular/core';
import { DsmjSummaryItem } from "@mjfr/ng-dsmj";
    
@Component({
  selector: 'doc-summary-example',
  templateUrl: './summary-example.component.html',
})
    
export class SummaryExampleComponent {
  public sumList:DsmjSummaryItem[] = [
    {title: "Titre de l'ancre 1", anchor: "titre-ancre-1"},
    {title: "Titre de l'ancre 2", anchor: "titre-ancre-2"},
    {title: "Titre de l'ancre 3", anchor: "titre-ancre-3"},
    {title: "Titre de l'ancre 4", anchor: "titre-ancre-4"},
    {title: "Titre de l'ancre 5", anchor: "titre-ancre-5"},
  ]
}`
  }
}
