import {Component, ViewEncapsulation} from '@angular/core';
import { CodeSnippet } from '../../commons/models/code-snippet.model';
import { Badge } from '@mjfr/ng-dsmj';

@Component({
  selector: 'doc-table-example',
  templateUrl: './table-example.component.html',
  encapsulation: ViewEncapsulation.None
})
export class TableExampleComponent {
  badges: Badge[] = [
    { label: 'yellow-tournesol', color: 'yellow-tournesol' },
    { label: 'yellow-moutarde', color: 'yellow-moutarde' },
    { label: 'purple-glycine', color: 'purple-glycine' },
    { label: 'pink-tuile', color: 'pink-tuile' },
    { label: 'pink-macaron', color: 'pink-macaron' },
    { label: 'orange-terre-battue', color: 'orange-terre-battue' },
    { label: 'green-tilleul-verveine', color: 'green-tilleul-verveine' },
    { label: 'green-menthe', color: 'green-menthe' },
    { label: 'green-emeraude', color: 'green-emeraude' },
    { label: 'green-bourgeon', color: 'green-bourgeon' },
    { label: 'green-archipel', color: 'green-archipel' },
    { label: 'brown-opera', color: 'brown-opera' },
    { label: 'brown-caramel', color: 'brown-caramel' },
    { label: 'brown-cafe-creme', color: 'brown-cafe-creme' },
    { label: 'blue-ecume', color: 'blue-ecume' },
    { label: 'blue-cumulus', color: 'blue-cumulus' },
    { label: 'beige-gris-galet', color: 'beige-gris-galet' },
  ]
  
  properties: any = [
    {
      name: 'title',
      inOut: 'input',
      type: 'string',
      required: true,
      default: undefined,
      description: "Le titre du tableau , obligatoire même si caption == 'none'"
    },{
      name: 'caption',
      inOut: 'input',
      type: 'string',
      required: false,
      default: 'top',
      description: "Spécifie l'endroit où apparaitra le titre du tableau : 'top' | 'bottom' | 'none'"
    },{
      name: 'bordered',
      inOut: 'input',
      type: 'bool',
      required: false,
      default: 'false',
      description: "Précise si le tableau doit avoir des bordures"
    },{
      name: 'color',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "La couleur de la mise en avant, liste de couleurs disponibles dans la partie \"Personnalisation\" plus bas"
    },{
      name: 'noScroll',
      inOut: 'input',
      type: 'bool',
      required: false,
      default: 'false',
      description: "Précise si le tableau peut avoir un scroll horizontal (pour mobile surtout), si le tableau comporte trop de colonnes le tableau sera alors coupé sur la droite"
    },{
      name: 'fixed',
      inOut: 'input',
      type: 'bool',
      required: false,
      default: 'false',
      description: "Précise si le tableau peut avoir une taille fixée, la taille sera alors de 100% et chaque colonne sera de même taille"
    },{
      name: 'tableId',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Précise l'id voulu, si aucun id n'est fourni un id sera automatiquement généré"
    },{
      name: 'idEvent',
      inOut: 'output',
      type: 'EventEmitter<string>',
      required: false,
      default: undefined,
      description: "Renvoi l'id, très utile si on utilise l'id généré automatiquement"
    }
  ];

  cs1: CodeSnippet = {
    html:
`<dsmj-table title="Titre du tableau">
  <th>colonne 1</th>
  <th>colonne 2</th>
  <th>colonne 3</th>
  <tr>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
  </tr>
</dsmj-table>`
  }
  cs2: CodeSnippet = {
    html:
`<dsmj-table title="Titre du tableau" [fixed]="true" [bordered]="true">
  <th>colonne 1</th>
  <th>colonne 2</th>
  <th>colonne 3</th>
  <tr>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
  </tr>
  <tr>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
  </tr>
</dsmj-table>`
  }
  cs3: CodeSnippet = {
    html:
`<dsmj-table title="Titre du tableau" caption="bottom" color="purple-glycine">
  <th>colonne 1</th>
  <th>colonne 2</th>
  <th>colonne 3</th>
  <tr>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
  </tr>
  <tr>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
  </tr>
</dsmj-table>`
  }
  cs4: CodeSnippet = {
    html:
`<dsmj-table [noScroll]="true" title="Titre du tableau" caption="none">
  <th>Colonne 1</th>
  <th>Colonne 2</th>
  <th>Colonne 3</th>
  <th>Colonne 4</th>
  <th>Colonne 5</th>
  <th>Colonne 6</th>
  <th>Colonne 7</th>
  <th>Colonne 8</th>
  <th>Colonne 9</th>
  <tr>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
  </tr>
  <tr>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
    <td>Loremipsum dolor sit amet</td>
  </tr>
</dsmj-table>`
  }
  cs5: CodeSnippet = {
    html:
`<dsmj-table title="Titre du tableau" [fixed]="true">
  <th>Titre long de colonne 1</th>
  <th>Titre long de colonne 2</th>
  <th>Titre long de colonne 3</th>
  <th>Titre long de colonne 4</th>
  <th>Titre long de colonne 5</th>
  <th>Titre long de colonne 6</th>
  <tr>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
  </tr>
  <tr>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
    <td>Lorem ipsum</td>
  </tr>
</dsmj-table>`
  }
  cs6: CodeSnippet = {
    html:
`<dsmj-table title="Titre du tableau">
  <th>Nom et Prénom</th>
  <th>Poste</th>
  <th>Action</th>
  <th>Lien</th>
  <tr>
    <td>Terrieur Alain</td>
    <td>Chef de bureau</td>
    <td><button dsmjButton color="tertiary-no-outline" icon="edit-line" iconPosition="left" href="javascript:void(0);">Label bouton</button></td>
    <td><a dsmjLink href="/">Label lien</a></td>
  </tr>
  <tr>
    <td>Chemonfisse Tierry</td>
    <td>Chef de pole</td>
    <td><button dsmjButton color="tertiary-no-outline" icon="edit-line" iconPosition="left" href="javascript:void(0);">Label bouton</button></td>
    <td><a dsmjLink href="/">Label lien</a></td>
  </tr>
</dsmj-table>`
  }
}
