import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";
import {Tag} from "@mjfr/ng-dsmj";
import {tagDataExample} from "./tag.data";
import {tagCodeSnippet} from "./snippet/simple";

@Component({
  selector: 'doc-tag-example',
  templateUrl: './tag-example.component.html',
  styleUrls: ['./tag-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class TagExampleComponent {
  title = 'Tag';

  data = tagDataExample;
  codeSnippet = tagCodeSnippet;


  tags: Tag[] = [
    { label: 'Label 1', type: 'label', iconClass: 'fr-icon-information-line' },
    { label: 'Label 2', type: 'label', iconClass: 'fr-icon-lock-line' },
    { label: 'Label 3', type: 'label' },
    { label: 'Label 4', type: 'label' },
  ]

  tagsClickable: Tag[] = [
    { label: 'Label 1 lien actif ', type: 'clickable', url: '/composants/tag' },
    { label: 'Label 2 lien non actif ', type: 'clickable', url: undefined, iconClass: 'fr-icon-lock-unlock-line' },
    { label: 'Label 3 lien actif ', type: 'clickable', url: '/composants', iconClass: 'fr-icon-logout-box-r-line' },
    { label: 'Label 4 lien non actif ', type: 'clickable', url: undefined },
  ]

  tagsSelectable: Tag[] = [
    { label: 'Label 1 selectionné ', type: 'selectable', pressed: true },
    { label: 'Label 2 non selectionné ', type: 'selectable', pressed: false, iconClass: 'fr-icon-more-line fr-icon--right' },
    { label: 'Label 3 selectionné ', type: 'selectable', pressed: true, iconClass: 'fr-icon-notification-badge-line fr-icon--right' },
    { label: 'Label 4 non selectionné ', type: 'selectable', pressed: false, iconClass: 'fr-icon-question-line fr-icon--right' },
  ]
  mTagsSelectable = JSON.parse(JSON.stringify(this.tagsSelectable))

  tagsDismissible: Tag[] = [
    { label: 'Label 1 supprimable', type: 'dismissible', iconClass: 'fr-icon-refresh-line fr-icon--right' },
    { label: 'Label 2 supprimable', type: 'dismissible', iconClass: 'fr-icon-search-line fr-icon--right' },
    { label: 'Label 3 supprimable', type: 'dismissible', iconClass: 'fr-icon-settings-5-line fr-icon--right' },
    { label: 'Label 4 supprimable', type: 'dismissible' },
  ]
  mTagsDismissible = JSON.parse(JSON.stringify(this.tagsDismissible))

  codeSnippetTagNormal: string = `\
<div class="fr-grid-row fr-grid-row--gutters">
  <h4 class="fr-col-12">Tag (normal / défaut)</h4>
  <dsmj-tag class="fr-col-12" type="label" label="Tag 1"></dsmj-tag>
</div>`;

  codeSnippetGroupTagClickble: string = `\
<div class="fr-grid-row fr-grid-row--gutters">
  <h4 class="fr-col-12">Tag (cliquable)</h4>
  <dsmj-tags-group class="fr-col-12"
    [tags]="[{type: 'clickable', label: 'Tag 2'}, {type: 'clickable', url: '/composants/tag', label: 'Tag 3'}]">
  </dsmj-tags-group>
</div>`;

  codeSnippetTagSelectable: string = `\
<div class="fr-grid-row fr-grid-row--gutters">
  <h4 class="fr-col-12">Tag (selectionnable)</h4>
  <dsmj-tag class="fr-col-12" type="selectable" label="Tag 4"></dsmj-tag>
</div>`;

  codeSnippetTagDismissible: string = `\
<div class="fr-grid-row fr-grid-row--gutters">
  <h4 class="fr-col-12">Tag (Supprimable)</h4>
  <dsmj-tags-group class="fr-col-12"
                     [tags]="[{type: 'dismissible', label: 'Tag 5'}, {type: 'dismissible', label: 'Tag 6'}]">
  </dsmj-tags-group>
</div>`;

}
