import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-tile-example',
  templateUrl: './tile-example.component.html',
  styleUrls: ['./tile-example.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class TileExampleComponent {
  public compteur: number = 0;

  public tilesCounter: { title: string, description: string, fn: Function, imgSrc?: string, imgAlt?: string }[] = [
    { title: 'Choix 1', description: '+1 au compteur', fn: (event): void => this.nextCounter(1, event), imgSrc: "/assets/favicon/android-chrome-192x192.png" },
    { title: 'Choix 2', description: '+2 au compteur', fn: (event): void => this.nextCounter(2, event), imgSrc: "/assets/favicon/android-chrome-192x192.png" },
    { title: 'Choix 3', description: '+3 au compteur', fn: (event): void => this.nextCounter(3, event), imgSrc: "/assets/favicon/android-chrome-192x192.png" },
    { title: 'Choix 4', description: '+4 au compteur', fn: (event): void => this.nextCounter(4, event), imgSrc: "/assets/favicon/android-chrome-192x192.png" },
  ]

  nextCounter = (nb: number, event: Event): void => {
    event.stopPropagation(); // needed to stop propagation cause if absent method will be called twice
    this.compteur += nb
  }

  public properties: any = [
    {
      name: 'title',
      inOut: 'input',
      type: 'string',
      required: true,
      default: undefined,
      description: "Le titre qui sera affiché dans la tuile"
    },{
      name: 'headingTag',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "La balise a utiliser pour le titre : h2 | h3 | h4 | h5 | h6"
    },{
      name: 'description',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "La description qui se trouve dans la tuile"
    },{
      name: 'orientation',
      inOut: 'input',
      type: 'string',
      required: false,
      default: 'vertical',
      description: "L'orientation de la tuile elle peut être \"vertical\" ou \"horizontal\""
    },{
      name: 'imgSrc',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "La source de l'image de la tuile"
    },{
      name: 'imgAlt',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Le texte alternatif de l'image de la tuile ( optionnel car le DSFR définit le titre et la description comme accomplissant déjà ce travail, à n'utiliser que si cela n'est pas le cas )"
    },{
      name: 'hasClick',
      inOut: 'input',
      type: 'event',
      required: false,
      default: undefined,
      description: "Permet de personnaliser le callback du clique sur la tuile"
    },{
      name: 'url',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "L'url vers lequel on souhaite rediriger l'utilisateur lors du click, a n'utiliser que si l'event hasClick est vide car l'url désactivera le hasClick. L'url sera utiliser par un [routerLink] permettant un usage d'angular et de ses fonctionnalités"
    },{
      name: 'tileId',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "L'id de la tuile, si aucun ne lui est donnée un id sera automatiquement généré"
    }
  ];

  public codeSnippetBasic: CodeSnippet = {
    html:
`<div>
  <div class="fr-col-12">
    <dsmj-tile title="Tuile 1" headingTag="h4" description="Sert a ramener sur la page" imgSrc="/assets/favicon/banner/android-chrome-192x192.png" imgAlt="Le logo marianne" url="/elements-d-interface/composants/tile"></dsmj-tile>
  </div>
</div>`
  }

  public codeSnippetCompteur: CodeSnippet = {
    html:
`<div class="fr-grid-row fr-grid-row--gutters">
  <div class="fr-col-6 fr-col-md-4 fr-col-lg-3" *ngFor="let tile of tilesCounter;">
    <dsmj-tile title="{{tile.title}}" description="{{tile.description}}" (hasClick)="tile.fn($event)" imgSrc="{{tile?.imgSrc}}" imgAlt="{{tile?.imgAlt}}"></dsmj-tile>
  </div>
</div>
<div class="fr-grid-row fr-grid-row--gutters">
  <div class="fr-col-12">
    <span class="">Counter: {{ compteur }}</span>
  </div>
</div>`,
    ts:
`
import {Component} from '@angular/core';

@Component({
    selector: 'tile-example',
    templateUrl: './tile-example.component.html',
    styleUrls: ['./tile-example.component.scss'],
})
export class TileExampleComponent {
  public compteur: number = 0;

  public tilesCounter: { title: string, description: string, fn: Function, imgSrc?: string, imgAlt?: string }[] = [
    { title: 'Choix 1', description: '+1 au compteur', fn: (event): void => this.nextCounter(1, event), imgSrc: "/assets/favicon/android-chrome-192x192.png" },
    { title: 'Choix 2', description: '+2 au compteur', fn: (event): void => this.nextCounter(2, event), imgSrc: "/assets/favicon/android-chrome-192x192.png" },
    { title: 'Choix 3', description: '+3 au compteur', fn: (event): void => this.nextCounter(3, event), imgSrc: "/assets/favicon/android-chrome-192x192.png" },
    { title: 'Choix 4', description: '+4 au compteur', fn: (event): void => this.nextCounter(4, event), imgSrc: "/assets/favicon/android-chrome-192x192.png" },
  ]

  nextCounter = (nb: number, event: Event) => {
    event.stopPropagation(); // needed to stop propagation cause if absent method will be called twice
    this.compteur += nb
  }
}`,
  }
  public codeSnippetVar: CodeSnippet = {
    html:
`<div id="tileExample" class="fr-grid-row fr-grid-row--gutters">
  <div class="fr-col-6 fr-col-md-4 fr-col-lg-3">
    <dsmj-tile title="Tuile 1" url="/elements-d-interface/composants/tile"></dsmj-tile>
  </div>
  <div class="fr-col-6 fr-col-md-4 fr-col-lg-3">
    <dsmj-tile title="Tuile 2" description="Avec un url vide, ce qui renvoit a l'accueil" url=""></dsmj-tile>
  </div>
  <div class="fr-col-6 fr-col-md-4 fr-col-lg-3">
    <dsmj-tile title="Tuile 3" imgSrc="/assets/favicon/android-chrome-192x192.png" url="/elements-d-interface/composants/tile"></dsmj-tile>
  </div>
  <div class="fr-col-6 fr-col-md-4 fr-col-lg-3">
    <dsmj-tile title="Tuile 4" headingTag="h6" description="Avec des balises h6" url="/elements-d-interface/composants/tile"></dsmj-tile>
  </div>
</div>`
  }

  public codeSnippetHorizontal: CodeSnippet = {
    html:
`<div>
  <dsmj-tile title="Tuile 1" tileId="tile-horizontal-1" orientation="horizontal" headingTag="h4" description="Sert a ramener sur la page" imgSrc="/assets/favicon/android-chrome-192x192.png" imgAlt="Le logo marianne" url="/elements-d-interface/composants/tile"></dsmj-tile>
</div>`
  }
}
