import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-toggle-example',
  templateUrl: './toggle-example.component.html',
  encapsulation: ViewEncapsulation.None
})

export class ToggleExampleComponent {

  public toggleChecked: boolean = false;

  updateToggleChecked(state: boolean): void {
    this.toggleChecked = state;
  }

  properties: any = [
    {
      name: 'label',
      inOut: 'input',
      type: 'string',
      required: true,
      default: undefined,
      description: "Le label servant de titre pour le composant"
    },
    {
      name: 'hint',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Spécifie la description du composant qui sera affiché en dessous de l'interrupteur"
    },
    {
      name: 'position',
      inOut: 'input',
      type: '"left" | "right',
      required: false,
      default: undefined,
      description: "Indique de quel coté on désire avoir le label"
    },
    {
      name: 'checkedText',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Spécifie le texte à affiché pour décrire le composant lorsque celui-ci est activer"
    },
    {
      name: 'uncheckedText',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Spécifie le texte à affiché pour décrire le composant lorsque celui-ci est désactiver"
    },
    {
      name: 'border',
      inOut: 'input',
      type: 'boolean',
      required: false,
      default: 'false',
      description: "Spécifie si on veut une bordure de séparation sur cet élément"
    },
    {
      name: 'disabled',
      inOut: 'input',
      type: 'boolean',
      required: false,
      default: "false",
      description: "Permet de définir si l'interrupteur est activer ou non ( il reste visible mais non interactif )"
    },
    {
      name: 'toggleStateEvent',
      inOut: 'output',
      type: 'EventEmitter<boolean>',
      required: false,
      default: undefined,
      description: "Renvois un événement à chaque activation avec l'état actuel de l'interrupteur"
    },
    {
      name: 'toggleId',
      inOut: 'input',
      type: 'string',
      required: false,
      default: "",
      description: `Renseigne l'id du checkbox du composant afin de le personnaliser`
    },
    {
      name: 'descId',
      inOut: 'input',
      type: 'string',
      required: false,
      default: "",
      description: `Renseigne l'id de la description du composant afin de le personnaliser`
    },
    {
      name: 'idEvent',
      inOut: 'output',
      type: 'EventEmitter<string>',
      required: false,
      default: "",
      description: `Renvoi l'id, très utile si on utilise l'id généré automatiquement`
    }
  ];

  cs1: CodeSnippet = {
    html:`<dsmj-toggle label="Label action interrupteur" uncheckedText="Désactivé" checkedText="Activé" hint="Texte d’aide pour clarifier l’action" [border]="true" (toggleStateEvent)="updateToggleChecked($event)"></dsmj-toggle>
<p>Etat de l'interrupteur : {{ toggleChecked ? "Activé" : "Désactivé" }}</p>`,
    ts:`export class ToggleExampleComponent {

  public toggleChecked: boolean = false;

  updateToggleChecked(state: boolean): void {
    this.toggleChecked = state;
  }
}`
  }

  cs2: CodeSnippet = {
    html:`<dsmj-toggle label="Label action interrupteur" uncheckedText="Désactivé" checkedText="Activé" position="left" hint="Texte d’aide pour clarifier l’action"></dsmj-toggle>`
  }

  cs3: CodeSnippet = {
    html:`<dsmj-toggle label="Label action interrupteur" uncheckedText="Désactivé" checkedText="Activé" toggleId="dsmj-toggle-example" descId="dsmj-toggle-description-example" hint="Texte d’aide pour clarifier l’action"></dsmj-toggle>`
  }

  cs4: CodeSnippet = {
    html:`<dsmj-toggle [disabled]="true" label="Label action interrupteur" uncheckedText="Désactivé" checkedText="Activé" hint="Texte d’aide pour clarifier l’action"></dsmj-toggle>`
  }

  cs5: CodeSnippet = {
    html:`<dsmj-toggle label="Label action interrupteur" uncheckedText="Désactivé" checkedText="Activé"></dsmj-toggle>`
  }
}
