import {CodeSnippet} from "../../../commons/models/code-snippet.model";


const codeSnippet: CodeSnippet = {
  html:
`<dsmj-upload-file
  [files]="files"
  [allowedExtensions]="allowedExt"
  [filesNumberLimit]="filesNumberLimit"
  [filesSizeLimit]="filesSizeLimit"
  (filesChangeEmitter)="onFileChange($event)"
>
  <ng-container description>
      <span class="fr-hint-text">Vous pouvez ajouter jusqu'à {{filesNumberLimit}} documents en une seule fois.</span>
      <span class="fr-hint-text">Format de documents autorisé : {{allowedExt.join(', ')}}. Taille du fichier : {{filesSizeLimit}} Mo maximum</span>
  </ng-container>
  <ng-container list-files>
    <dsmj-viewer-file
      [files]="files"
      [nameField]="'name'"
      [sizeField]="'size'"
      (filesToDeleteEmitter)="onFileDelete($event)"
    ></dsmj-viewer-file>
  </ng-container>
</dsmj-upload-file>
`,
  ts:
`import { Component } from '@angular/core';

@Component({
  selector: 'doc-upload-file-example',
  templateUrl: './update-file-example.component.html',
  styleUrls: ['./update-file-example.component.scss']
})
export class UpdateFileExampleComponent {

  files: Set<any> = new Set();

  allowedExt: Array<string> = ['jpg', 'png', 'jpeg'];
  filesNumberLimit: number = 20;
  filesSizeLimit: number = 5;

  constructor() {}

  onFileChange(events: Set<File>) {
    events.forEach(ev => this.files.add(ev))
    console.log('event emitted from upload file component, contains(', events, ')')
  }

  onFileDelete(files: Set<File>) {
    const status = [];
    files.forEach(f => {
      status.push(this.files.delete(f))
    })

    return (status.every(s => s === true));
  }
}`
}

export default codeSnippet;
