import { Component } from '@angular/core';
import {modalDataExample} from "./upload-file.data";
import codeSnippet from "./snippet/simple";
import codeSnippetDisable from "./snippet/disable";
import {CodeSnippet} from "../../commons/models/code-snippet.model";

const doc = { id: 1, name: 'mocked-server-file.jpg', size: 12345 };

@Component({
  selector: 'doc-upload-file-example',
  templateUrl: './update-file-example.component.html',
  styleUrls: ['./update-file-example.component.scss']
})
export class UpdateFileExampleComponent {

  files: Set<any> = new Set();
  filesDisabled: Set<any> = new Set();
  filesDownloaded: Set<any> = new Set().add(doc);

  allowedExt: Array<string> = ['jpg', 'png', 'jpeg'];
  filesNumberLimit: number = 20;
  filesSizeLimit: number = 5;

  uploadData = modalDataExample;

  appTemplate = `\
<dsmj-upload-file
  [files]="files"
  [allowedExtensions]="['jpg', 'png', 'jpeg']"
  [filesNumberLimit]="20" // Nombre max de fichier uploadable
  [filesSizeLimit]="5" // Taille max des fichiers
  (filesChangeEmitter)="onFileChange($event)"
>
  <ng-container description>
      <span class="fr-hint-text">Vous pouvez ajouter jusqu'à {{filesNumberLimit}} documents en une seule fois.</span>
      <span class="fr-hint-text">Format de documents autorisé : {{allowedExt.join(', ')}}. Taille du fichier : {{filesSizeLimit}} Mo maximum</span>
  </ng-container>
</dsmj-upload-file>`

  importViewer = `\
import { DsmjUploadFileModule, DsmjViewerModule } from '@mjfr/ng-dsmj';

@NgModule ({
  imports: [
    DsmjUploadFileModule,
    DsmjViewerModule,
  ]
})
class AppModule {}`

  viewerIntegration = `\
<ng-container list-files>
  <!-- Le dsmj-viewer-file reste un viewer générique, il peut être remplacé par un viewer spécifique -->
  <dsmj-viewer-file [files]="files" [disabled]="false"
                    [nameField]="'name'" [sizeField]="'size'"
                    (filesToDeleteEmitter)="onFileDelete($event)"></dsmj-viewer-file>

  <!-- [files] Cet propriété doit être identique à l'objet renseigné dans la propriété "files" du composant dsmj-upload-files. -->
  <!-- [disabled] Cet propriété doit indique si le viewer est désactivé. -->
  <!-- [nameField] Cet propriété doit matcher avec la propriété contenant le nom du fichier dans l'objet "files" indiqué à la ligne au dessus. -->
  <!-- [sizeField] Cet propriété doit matcher avec la propriété contenant la taille du fichier dans l'objet "files" indiqué à la ligne au dessus. -->
  <!-- (filesToDeleteEmitter) Cet EventEmitter permet de récupérer l'évènement de suppression d'un fichier à partir du viewer. -->
</ng-container>`

  onFileChange(events: Set<Object | File>) {
    events.forEach(ev => this.files.add(ev))
    console.log('event emitted from upload file component, contains(', events, ')')
  }

  onFileChangeDownloaded(events: Set<Object | File>) {
    events.forEach(ev => this.filesDownloaded.add(ev))
    console.log('event emitted from upload file component, contains(', events, ')')
  }

  onFileChangeDisabled(events: Set<Object | File>) {
    events.forEach(ev => this.filesDisabled.add(ev))
    console.log('event emitted from upload file component, contains(', events, ')')
  }

  onFileDelete(files: Set<Object | File>) {
    this.deleteFile(this.files, files);
  }

  onFileDeleteDownloaded(files: Set<Object | File>) {
    this.deleteFile(this.filesDownloaded, files);
  }

  onFileDeleteDisabled(files: Set<Object | File>) {
    this.deleteFile(this.filesDisabled, files);
  }

  deleteFile(arr: Set<any>, files: Set<Object | File>) {
    const status = [];
    files.forEach(f => {
      if ((f instanceof File)) {
        status.push(arr.delete(f))
      } else {
        // IN REAL APP IT WILL CALL AN API WHICH DELETE OBJECT IN DB
      }
    })

    return (status.every(s => s === true));
  }

  codeSnippet: CodeSnippet = codeSnippet;
  codeSnippetDisable: CodeSnippet = codeSnippetDisable;
}
