import {SubjectData} from "../../commons/models/subject-data.model";

export const modalDataExample: SubjectData = {
  main: {
    title: 'Ajout de fichier',
    description: {
      main: 'Ce composant permet aux utilisateurs de sélectionner et envoyer un ou plusieurs fichiers.'
    }
  },
  integration: {
    title: 'Intégration du module',
    module: "DsmjAjoutFichierModule",
    description: {
      main: ""
    },
  },
  informations: [
    {
      title: 'Structure',
      description: {
        main: "Ce composant est composé de :",
        paragraphs: [
          {
            type: "list",
            texts: [
              "Un label - le texte du label exprime clairement l’action attendue pour l’utilisateur, par défaut : “Ajouter un fichier” - obligatoire",
              "Un texte explicatif qui précise les contraintes au niveau du ou des fichiers attendus : format, poids attendus, nombre de fichiers possible… - obligatoire",
              "Le bouton “Choisir un fichier” - obligatoire",
              "Une zone pour le Glisser/Déposer - Elle indique les limites dans laquelle il est possible de glisser et déposer un fichier - optionnel",
              "Une liste des fichiers téléchargés",
            ]
          },
          {
            type: "raw",
            text: "Au clic sur le bouton “Choisir un fichier” la boite de dialogue de sélection de fichier s’affiche. Les noms des fichiers sélectionnés par téléchargement ou Glisser/Déposer viennent s’afficher sous forme de liste avec des boutons icônes de suppression de fichier."
          }
        ]
      }
    },
    {
      subtitle: "Ajout de fichier (Défaut)",
      template_id: 'upload-file-simple-template-snippet'
    },
    {
      subtitle: "Ajout de fichier (Téléchargé)",
      template_id: 'upload-file-downloaded-template-snippet'
    },
    {
      subtitle: "Ajout de fichier (Désactivé)",
      template_id: 'upload-file-disable-template-snippet'
    },
  ],
  properties: [
    {
      name: 'files',
      inOut: 'input',
      type: 'Set<File | Object>',
      required: true,
      default: undefined,
      description: "Contient la liste des fichiers géré par le composant. Peut contenir à la fois les fichiers ajouté depuis la boite de dialogue de fichier ou les fichiers récupérés depuis un appel à une API "
    },
    {
      name: 'allowedExtensions',
      inOut: 'input',
      type: 'string[]',
      required: false,
      default: "['pdf', 'png', 'jpeg', 'jpg', 'bmp']",
      description: "Permet d'indiquer les extensions de fichier gérées par le composant, un message d'erreur sera affiché si un l'utilisateur essaie d'envoyer un fichier avec une extension non autorisée"
    },
    {
      name: 'title',
      inOut: 'input',
      type: 'string',
      required: false,
      default: 'Ajouter vos documents',
      description: 'Permet de modifier le titre affiché en haut du composant'
    },
    {
      name: 'btnLabel',
      inOut: 'input',
      type: 'string',
      required: false,
      default: 'Choisir vos fichiers',
      description: "Permet de modifier le text situé au centre du cadre permettant le glisser/Déposer"
    },
    {
      name: 'dndLabel',
      inOut: 'input',
      type: 'string',
      required: false,
      default: 'Glisser/Déposer vos fichiers ici',
      description: 'Permet de modifier le texte situé au centre du cadre permettant le glissé/déposeé'
    },
    {
      name: 'errorsLabel',
      inOut: 'input',
      type: 'DndErrorManager',
      required: false,
      default: [
        'format: "Format de fichier non supporté"',
        'size: "Taille de fichier dépasse la limite autorisée de ${filesSizeLimit} Mo"',
        'number: "Le nombre maximum de fichiers est de ${filesNumberLimit}"',
      ],
      description: "Les différents messages affichés en fonction du type d'erreur"
    },
    {
      name: 'noFilesLabel',
      inOut: 'input',
      type: 'string',
      required: false,
      default: 'Aucun fichier sélectionné',
      description: "Texte affiché pour indiquer à l'utilisateur qu'aucun fichier n'a été ajouté"
    },
    {
      name: 'disabled',
      inOut: 'input',
      type: 'boolean',
      required: false,
      default: 'false',
      description: "Permet d'activer ou désactiver l'upload de fichier"
    },
    {
      name: 'errorTimerLimit',
      inOut: 'input',
      type: 'number | undefined',
      required: false,
      default: '5000',
      description: "Permet de paramétrer le temps pendant lequel le message d'erreur reste affiché (en milliseconde)"
    },
    {
      name: 'filesNumberLimit',
      inOut: 'input',
      type: 'number',
      required: false,
      default: '10',
      description: 'Nombre maximum de fichier pouvant être ajoutés au composant'
    },
    {
      name: 'filesSizeLimit',
      inOut: 'input',
      type: 'number',
      required: false,
      default: '10',
      description: "La taille maximum d'un fichier en Megaoctet (Mo)"
    },
    {
      name: 'filesChangeEmitter',
      inOut: 'output',
      type: 'Set<File | Object>',
      required: false,
      default: undefined,
      description: "EventEmitter permet de récupérer la liste des documents après ajout d'un nouveau fichier"
    },
  ]
}
