import {Component, ViewEncapsulation} from '@angular/core';
import {CodeSnippet} from "../../commons/models/code-snippet.model";

@Component({
  selector: 'doc-upload-example',
  templateUrl: './upload-example.component.html',
  encapsulation: ViewEncapsulation.None
})

export class UploadExampleComponent {

  public url: string | ArrayBuffer = '';
  updatePreview(event) {
    if (event.target.files && event.target.files[0]) {
      var reader = new FileReader();

      // récupération de l'url
      reader.readAsDataURL(event.target.files[0]);

      //sauvegarde de l'url
      reader.onload = (event) => {
        this.url = event.target.result;
      }
    }
  }

  properties: any = [
    {
      name: 'label',
      inOut: 'input',
      type: 'string',
      required: true,
      default: undefined,
      description: "Le texte qui servira à exprimer clairement l’action attendu pour l’utilisateur, par défaut : 'Ajouter un fichier'"
    },
    {
      name: 'hint',
      inOut: 'input',
      type: 'string',
      required: true,
      default: undefined,
      description: "Le texte qui servira a décrire plus en détail les contraintes du ou des fichiers attendus"
    },
    {
      name: 'errorMessage',
      inOut: 'input',
      type: 'string',
      required: false,
      default: undefined,
      description: "Le texte en cas d'erreur à afficher, lorsque ce champ est renseigné met automatiquement le field en erreur"
    },
  ];

  cs1: CodeSnippet = {
    html:`<dsmj-form-field for="file-upload" 
  label="Ajouter un fichier" 
  hint="Taille maximale : 500 Mo. Formats supportés : jpg, png, pdf.">
  <input dsmjInputFile type="file" id="file-upload" name="file-upload">
</dsmj-form-field>`,
  }

  cs2: CodeSnippet = {
    html:`<dsmj-form-field  for="file-upload-with-error" 
  label="Ajouter un fichier" 
  hint="Taille maximale : 500 Mo. Formats supportés : jpg, png, pdf."
  errorMessage="Format de fichier non supporté">
  <input dsmjInputFile type="file" id="file-upload-with-error" name="file-upload-with-error">
</dsmj-form-field>`,
  }

  cs3: CodeSnippet = {
    html:`<dsmj-form-field for="file-upload-with-preview" 
  label="Ajouter un fichier" 
  hint="Taille maximale : 500 Mo. Formats supportés : jpg, png.">
  <input dsmjInputFile type="file" id="file-upload-with-preview" name="file-upload-with-preview" (change)="updatePreview($event)">
</dsmj-form-field>
<img [src]="url">`,
    ts:`export class UploadExampleComponent {
  public url: string | ArrayBuffer = '';
  updatePreview(event) {
    if (event.target.files && event.target.files[0]) {
      var reader = new FileReader();

      // récupération de l'url
      reader.readAsDataURL(event.target.files[0]);

      //sauvegarde de l'url
      reader.onload = (event) => {
        this.url = event.target.result;
      }
    }
  }
}
    `
  }

  cs4: CodeSnippet = {
    html:`<dsmj-form-field for="file-upload-multiple" 
  label="Ajouter des fichiers" 
  hint="Taille maximale : 500 Mo. Formats supportés : jpg, png, pdf. Plusieurs fichiers possibles.">
  <input dsmjInputFile multiple type="file" id="file-upload-multiple" name="file-upload-multiple">
</dsmj-form-field>`,
  }
}
