import {Injectable} from "@angular/core";
import {Observable, Subject} from "rxjs";
import {Alert, AlertType, Options} from "../model/alert.model";
import {filter} from "rxjs/operators";

@Injectable({
  providedIn: 'root',
})
export class AlertService {
  private subject = new Subject<Alert>();
  private defaultId = 'default-alert';

  // enable subscribing to alerts observable
  onAlert(id = this.defaultId): Observable<Alert> {
    return this.subject.asObservable().pipe(filter(x => x && x.id === id));
  }

  // convenience methods
  defaultSuccess(message: string, title?: string, options?: Options): void {
    this.alert({type: AlertType.Success, message, title, options} as Alert)
  }

  success(id: string, message: string, title?: string, options?: Options): void {
    this.alert({id, type: AlertType.Success, message, title, options} as Alert)
  }

  defaultError(message: string, title?: string, options?: Options): void {
    this.alert({type: AlertType.Error, message, title, options} as Alert)
  }

  error(id: string, message: string, title?: string, options?: Options): void {
    this.alert({id, type: AlertType.Error, message, title, options} as Alert)
  }

  defaultInfo(message: string, title?: string, options?: Options): void {
    this.alert({type: AlertType.Info, message, title, options} as Alert)
  }

  info(id: string, message: string, title?: string, options?: Options): void {
    this.alert({id, type: AlertType.Info, message, title, options} as Alert)
  }

  defaultWarn(message: string, title?: string, options?: Options): void {
    this.alert({type: AlertType.Warning, message, title, options} as Alert)
  }

  warn(id: string, message: string, title?: string, options?: Options): void {
    this.alert({id, type: AlertType.Warning, message, title, options} as Alert)
  }

  // main alert method
  alert(alert: Alert): void {
    alert.id = alert.id || this.defaultId;
    this.subject.next(alert);
  }

  // clear alerts
  clear(id = this.defaultId): void {
    this.subject.next({ id } as Alert)
  }

}


