import {Injectable, TemplateRef} from "@angular/core";
import {Observable, Subject} from "rxjs";
import {Banner} from "../model/banner.model";
import {filter} from "rxjs/operators";

@Injectable({
  providedIn: 'root',
})
export class BannerService {
  private subject = new Subject<Banner>();
  private defaultId = 'default-banner';

  // enable subscribing to alerts observable
  onMessage(id = this.defaultId): Observable<Banner> {
    return this.subject.asObservable().pipe(filter(x => x && x.id === id));
  }


  // convenience methods
  newMessage(content: string | TemplateRef<any>, ban?: Banner): void {
    const msg: string = typeof content === 'string' ? content : undefined;
    const tpl = !msg && typeof content !== 'string' ? content : undefined;
    const options = ban.options ?  ban.options : { keepAfterRouteChange: true, fade: true };

    ban.message = msg;
    ban.template = tpl;
    ban.options = options;

    this.message(ban)
  }

  // main alert method
  message(banner: Banner): void {
    banner.id = banner.id || this.defaultId;
    banner.type = banner.type || 'info';
    this.subject.next(banner);
  }

  // clear alerts
  clear(id = this.defaultId): void {
    this.subject.next({ id } as Banner)
  }

}
