import {Component, EventEmitter, Input, OnInit, Output} from "@angular/core";

@Component({
  selector: 'dsmj-btn-franceconnect',
  templateUrl: './bouton-france-connect.component.html'
})
export class BoutonFranceConnectComponent implements OnInit {

  /** URL vers la FAQ du service franceconnect */
  readonly URL_FRANCECONNECT_FAQ: string = 'https://franceconnect.gouv.fr/';

  /** URL vers la FAQ du service franceconnect+ */
  readonly URL_FRANCECONNECT_PLUS_FAQ: string = 'https://franceconnect.gouv.fr/france-connect-plus';

  /**
   * Active le bouton franceconnect+
   */
  @Input() secure: boolean = false;
  @Input() externalUrl?: string
  @Input() additionalParams?: string[]
  @Output() clicked = new EventEmitter();

  navigation: 'emitter' | 'url' | undefined = undefined;

  ngOnInit(): void {
    if(this.clicked.observers.length > 0) {
      this.navigation = 'emitter'
    } else if (this.externalUrl && this.externalUrl !== '') {
      this.navigation = 'url'
    }
  }

  proceedConnexion(): void {
    const connexion = (connexionUrl: string, additionalParams?: string[]): void => {
      const params = additionalParams && additionalParams.length > 0 ? additionalParams.join('') : undefined

      if (params) {
        connexionUrl.concat('?').concat(params)
      }

      window.location.href = connexionUrl;
    };

    if (this.navigation === 'url') {
      connexion(this.externalUrl, this.additionalParams)
    } else if (this.navigation === 'emitter') {
      this.clicked.emit()
    } else {
      console.warn("Bouton FranceConnect, vous pouvez au choix indiquer une url de redirection ou transmettre l'évènement du clic au composant parent")
    }
  }

  /**
   * récupère le lien de la FAQ du service FranceConnect selon l'usage ou non du mode de connexion securisée
   */
  getFAQFranceconnectUrl(): string {
    return this.secure ? this.URL_FRANCECONNECT_PLUS_FAQ : this.URL_FRANCECONNECT_FAQ;
  }
}
