import {ComponentFixture, TestBed} from '@angular/core/testing';

import { CalloutComponent } from "./callout.component";
import { Component } from '@angular/core';

describe('CalloutComponent', () =>{
  let component: CalloutComponent;
  let fixture: ComponentFixture<CalloutComponent>;
  let element: HTMLElement;

  
  let testComponent: TestComponent;
  let testFixture: ComponentFixture<TestComponent>;
  let testElement: HTMLElement;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ 
        CalloutComponent,
        TestComponent      
      ],
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(CalloutComponent);
    testFixture = TestBed.createComponent(TestComponent);

    component = fixture.componentInstance;
    testComponent = testFixture.componentInstance;

    element = fixture.nativeElement
    testElement = testFixture.nativeElement
    fixture.detectChanges();
    testFixture.detectChanges();
  });

  it("should create component dsmj-callout", () =>{
    expect(component).toBeTruthy()
  })

  it("should have the same description as the one given by description", () =>{
    testComponent.desc = "Description de la mise en avant"
    testFixture.detectChanges()
    testElement = testFixture.nativeElement
    expect(testElement.getElementsByTagName('p').item(0).textContent.trim()).toContain("Description de la mise en avant")
  })

  it("should have the same title and same balise as the one given", () =>{
    testComponent.desc = "Description de la mise en avant"
    testComponent.title = "Titre"
    testFixture.detectChanges()
    testElement = testFixture.nativeElement
    expect(testElement.getElementsByTagName('h2').item(0).textContent.trim()).toContain("Titre")
  })

  it("should have the color declared by color", () =>{
    testComponent.desc = "Description de la mise en avant"
    testComponent.color = "pink-macaron"
    testFixture.detectChanges()
    testElement = testFixture.nativeElement
    expect(testElement.getElementsByTagName('div').item(0).className).toContain("fr-callout--pink-macaron")
  })

  it("should have the icon declared by icon", () =>{
    testComponent.desc = "Description de la mise en avant"
    testComponent.icon = "fr-icon-information-line"
    testFixture.detectChanges()
    testElement = testFixture.nativeElement
    expect(testElement.getElementsByTagName('div').item(0).className).toContain("fr-icon-information-line")
  })

  it("should have the button declared by the html balise", () =>{
    testComponent.desc = "Description de la mise en avant"
    testComponent.button = 'Pop-up'
    testFixture.detectChanges()
    testElement = testFixture.nativeElement
    expect(testElement.getElementsByTagName('button').item(0)).toBeTruthy()
  })

  it("should have the link declared by the html balise", () =>{
    testComponent.desc = "Description de la mise en avant"
    testComponent.a = 'Accueil'
    testFixture.detectChanges()
    testElement = testFixture.nativeElement
    expect(testElement.getElementsByTagName('a').item(0)).toBeTruthy()
  })
})

@Component({
  template: `
    <dsmj-callout [icon]="icon" [color]="color">
      <h2 *ngIf="title" dsmjCalloutTitle>{{title}}</h2>
      <p *ngIf="desc" dsmjCalloutDescription>{{desc}}</p>
      <button *ngIf="button" dsmjButton>{{button}}</button>
      <a *ngIf="a" class="fr-btn">{{a}}</a>
    </dsmj-callout>
  `
})
class TestComponent {
  button: string;
  a: string;
  desc: string;
  title: string;
  icon: string;
  color: string;
}
