import {Component, EventEmitter, Input, OnInit, Output} from "@angular/core";
import {FooterLink} from "../model/footer-link.model";

@Component({
  selector: 'app-card-footer-link',
  template: `
    <ng-container *ngIf="footerOption.handleAction; else actionLink">
      <a class="fr-link fr-icon-arrow-right-line fr-link--icon-right"
         [id]="footerOption.id"
         href="javascript:void(0)"
         [attr.alt]="footerOption.alt"
         [attr.aria-label]="footerOption.alt"
         (click)="sendFooterLinkEvent(footerOption)">
        {{ footerOption.label }}
      </a>
    </ng-container>
    <ng-template #actionLink>
      <ng-container *ngIf="isInternal">
        <a class="fr-link fr-icon-arrow-right-line fr-link--icon-right"
           [id]="footerOption.id"
           [routerLink]="footerOption.link"
           [attr.alt]="footerOption.alt"
           [attr.aria-label]="footerOption.alt">
          {{ footerOption.label }}
        </a>
      </ng-container>
      <ng-container *ngIf="!isInternal">
        <a class="fr-link fr-icon-arrow-right-line fr-link--icon-right"
           [id]="footerOption.id"
           target="_blank"
           [href]="footerOption.link"
           [attr.alt]="footerOption.alt"
           [attr.aria-label]="footerOption.alt">
          {{ footerOption.label }}
        </a>
      </ng-container>
    </ng-template>
  `
})
export class CardFooterLinkComponent implements OnInit {
  @Input() footerOption: FooterLink;

  /**
   * Evenement `click` émis lorsque le client a cliqué sur un bouton/lien en pied de carte
   */
  @Output() hasClickOnFooterLink = new EventEmitter<string>();

  get isInternal() {
    return this.isInternalLink(this.footerOption.link);
  }

  ngOnInit(): void {
    if (this.footerOption === null || this.footerOption === undefined) {
      throw new TypeError("[CardComponent] The input ‘footerOption’ is required");
    }
  }

  public sendFooterLinkEvent = (footerOption: FooterLink): void => {
    this.hasClickOnFooterLink.emit(footerOption.id);
  }

  private isInternalLink(url: string): boolean {
    const base = new URL(`${window.location.protocol}//${window.location.host}`);
    return new URL(url, base).hostname === base.hostname;
  }
}
