import {Component, EventEmitter, Input, OnInit, Output} from "@angular/core";

@Component({
  selector: 'app-card-header-link',
  template: `
    <ng-container *ngIf="handleAction; else actionLink">
      <a href="javascript:void(0)"
         [attr.alt]="alt"
         [attr.aria-label]="alt"
         (click)="sendLinkEvent()">
        {{ title }}
      </a>
    </ng-container>
    <ng-template #actionLink>
      <ng-container *ngIf="isAnActiveLink">
        <ng-container *ngIf="isInternal">
          <a [routerLink]="link"
             [attr.alt]="alt"
             [attr.aria-label]="alt"
          >{{title}}</a>
        </ng-container>
        <ng-container *ngIf="!isInternal">
          <a target="_blank"
             [href]="link"
             [attr.alt]="alt"
             [attr.aria-label]="alt"
          >{{title}}</a>
        </ng-container>
      </ng-container>
      <ng-template #notALinkOrDisabled>
        <span>{{title}}</span>
      </ng-template>
    </ng-template>
  `
})
export class CardHeaderLinkComponent implements OnInit {
  /**
   * Required - Label for the link
   */
  @Input() title: string;

  /**
   * Required if handleAction is true - id to return by the EventEmitter
   */
  @Input() id: any;

  /**
   * Indicate if click action must be sent to parent with an EventEmitter
   */
  @Input() handleAction: boolean;

  /**
   * Contains the link (internal or external)
   */
  @Input() link: string;

  /**
   * texte alternatif au lien
   */
  @Input() alt: string;

  /**
   * Indicate if link should be disabled or not
   */
  @Input() disabled: boolean = false;

  /**
   * Required if handleAction is true - Evenement `click` émis lorsque d'un clique
   */
  @Output() hasClickOnLink = new EventEmitter<string>();

  get isInternal() {
    return this.isInternalLink(this.link);
  }

  get isAnActiveLink() {
    return !this.disabled && this.link;
  }

  ngOnInit(): void {
    if (this.title === null || this.title === undefined) {
      throw new TypeError("[CardComponent] The input ’title’ is required");
    }
  }

  public sendLinkEvent() {
    this.hasClickOnLink.emit(this.id)
  }

  private isInternalLink(url: string): boolean {
    const base = new URL(`${window.location.protocol}//${window.location.host}`);
    return new URL(url, base).hostname === base.hostname;
  }
}
