# Composant `dsmj-footer`

Ce composant permet d'intégrer le pied de page du système de design de l'état (DSFR). notamment en permettant de personnaliser différentes parties du pied de page tel que :

- Le pied de page simple - obligatoire
- Le pied de page complet - optionnel
- Le pied de page avec partenaires - optionnel

## Pied de page simple

Le composant `dsmj-footer` vous permet de générer le pied de page simple, et d'y apporter des éléments de customisation, notamment sur les blocs suivants :

- Le bloc-marque et l'identité du site ou du service
- Un texte de présentation - optionnel
- La liste de liens liés aux obligations légales. Cette liste doit être définie en fonction du site, toutefois les liens & contenus suivants sont obligatoires : “accessibilité : non/partiellement/totalement conforme”, mentions légales, données personnelles et gestion des cookies. - obligatoire.

### Bloc-marque (obligatoire)

Par défaut, le bloc-marque est configuré pour afficher le nom de l'administration `Ministère de la Justice`, vous pouvez néanmoins modifier le nom en utilisant l'option `logoLabel` (string|string[]), auquel chaque ligne du tableau correspondra à une ligne visuelle du bloc-marque:

```html
<dsmj-footer [logoLabel]="['République','Française']"></dsmj-footer>
```

### Identité du site ou du service (optionnel)

Vous avez la possibilité d'ajouter une identité au site ou au service, pour cela, le composant `<dsmj-footer>` vous propose différents type de personnalisation :

- Le nom du site / service
  - à travers l'option `organisationName` (string)
- Un logo
  - spécifier le chemin de l'image à l'aide de l'option `organisationImagePath` (string)
  - définir l'orientation de l'image avec l'option `organisationImagePosition` ('horizontal'|'vertical')
  - définir une description obligatoire à l'image avec l'option `organisationImageDescription` (string)

Le lien intégré au bloc de l'identité du site / service / bloc-marque pointe par défaut vers la racine du site (`/`) mais peut-être rédéfini avec l'option `brandLink` (string).

```html
<dsmj-footer organisationName="Mon application"></dsmj-footer>
```

### Texte de présentation (optionnel)

Vous avez la possibilité d'ajouter un texte de présentation, pour cela, ajouter votre texte dans le contenu du composant comme suit :

```html
<dsmj-footer>
  Exemple de texte de présentation de l'application
</dsmj-footer>
```

### Liste de liens liés aux obligations légales (obligatoire)

Vous devez indiquer les liens pointant vers les mentions obligatoires, ceci en utilisant le composant prévu à cet effet `dsmj-footer-bottom`, tout en respectant la structure suivante :

```html
<dsmj-footer>
  <dsmj-footer-bottom>
    <li>
      <a href="#">Plan du site</a>
    </li>
    <li>
      <a href="#">Accessibilité : non/partiellement/totalement conforme</a>
    </li>
    <li>
      <a href="#">Mentions légales</a>
    </li>
    <li>
      <a href="#">Données personnelles</a>
    </li>
    <li>
      <a href="#">Gestion des cookies</a>
    </li>
  </dsmj-footer-bottom>
</dsmj-footer>
```

## Pied de page complet (optionnel)

Vous pouvez utiliser le pied de page complet, à l'aide du composant `dsmj-footer-top` prévu à cet effet.

`dsmj-footer-top` gère une liste de catégories, dont il est possible d'utiliser le composant `dsmj-footer-top-category` pour faciliter sa structuration.

### Composant `dsmj-footer-top-category`

`dsmj-footer-top-category` accepte les éléments de type `<li>` et peut être configuré pour ajouter un titre de catégorie à travers l'option `label` (string) ainsi que le niveau de heading du label, à l'aide de l'option `labelHeading` (h1-6) par défaut il utilise le niveau `<h3>`

``` html
<dsmj-footer-top>
  <dsmj-footer-top-category label="Nom de la catégorie" labelHeading="h3">
    <li>
      <a href="#">Lien de navigation</a>
    </li>
    <li>
      <a href="#">Lien de navigation</a>
    </li>
    <li>
      <a href="#">Lien de navigation</a>
    </li>
  </dsmj-footer-top-category>
  <dsmj-footer-top-category label="Nom de la catégorie" labelHeading="h3">
    <li>
      <a href="#">Lien de navigation</a>
    </li>
    <li>
      <a href="#">Lien de navigation</a>
    </li>
    <li>
      <a href="#">Lien de navigation</a>
    </li>
  </dsmj-footer-top-category>
  <dsmj-footer-top-category label="Nom de la catégorie" labelHeading="h3">
    <li>
      <a href="#">Lien de navigation</a>
    </li>
    <li>
      <a href="#">Lien de navigation</a>
    </li>
    <li>
      <a href="#">Lien de navigation</a>
    </li>
  </dsmj-footer-top-category>
</dsmj-footer-top>
```

## Pied de page avec partenaires (optionnel)

Il est possible d'intégrer le pied de page avec partenaires. Vous pouvez de ce fait ajouter votre partenaire principal (obligatoire) ainsi que des partenaires additionnels (optionnel).

### Partenaire principal (obligatoire)

Vous pouvez ajouter votre partenaire principal à l'aide du composant `dsmj-footer-partners-main`, tout en respectant la structure suivante :

```html
<div dsmj-footer-partners-main>
  <a href="#/">
    <img src="https://via.placeholder.com/160x90" alt="Image exemple représentant un rectangle gris au format 160x90p">
    <!-- L’alternative de l’image (attribut alt) doit impérativement être renseignée et reprendre le texte visible dans l’image -->
  </a>
</div>
```

### Partenaires additionnel (optionnel)

Vous pouvez, en plus du partenaire principal, ajouter une liste de partenaires additionnels, pour cela, utiliser le composant `dsmj-footer-partners-sub`, tout en respectant la structure ci-dessous :

```html
<ul dsmj-footer-partners-sub>
  <li>
    <a href="#/">
      <img src="https://via.placeholder.com/160x90" alt="Image exemple représentant un rectangle gris au format 160x90p">
    </a>
  </li>
  <li>
    <a href="#/">
      <img src="https://via.placeholder.com/100x100" alt="Image exemple représentant un rectangle gris au format 100x100p">
    </a>
  </li>
  <li>
    <a href="#/">
      <img src="https://via.placeholder.com/90x160" alt="Image exemple représentant un rectangle gris au format 90x160">
    </a>
  </li>
</ul>
```

## Exemple d'implémentation complète du pied de page

Pied de page complet avec partenaires.

```html
<dsmj-footer organisationName="Mon Application">

  <!-- Pied de page complet -->
  <dsmj-footer-top>
    <dsmj-footer-top-category label="Nom de la catégorie" labelHeading="h3">
      <li>
        <a href="#">Lien de navigation</a>
      </li>
      <li>
        <a href="#">Lien de navigation</a>
      </li>
      <li>
        <a href="#">Lien de navigation</a>
      </li>
    </dsmj-footer-top-category>
    <dsmj-footer-top-category label="Nom de la catégorie" labelHeading="h3">
      <li>
        <a href="#">Lien de navigation</a>
      </li>
      <li>
        <a href="#">Lien de navigation</a>
      </li>
      <li>
        <a href="#">Lien de navigation</a>
      </li>
    </dsmj-footer-top-category>
    <dsmj-footer-top-category label="Nom de la catégorie" labelHeading="h3">
      <li>
        <a href="#">Lien de navigation</a>
      </li>
      <li>
        <a href="#">Lien de navigation</a>
      </li>
      <li>
        <a href="#">Lien de navigation</a>
      </li>
    </dsmj-footer-top-category>
  </dsmj-footer-top>

  <!-- Mentions obligatoires -->
  <dsmj-footer-bottom>
    <li>
      <a href="#">Plan du site</a>
    </li>
    <li>
      <a href="#">Accessibilité : totalement conforme</a>
    </li>
    <li>
      <a href="#">Mentions légales</a>
    </li>
    <li>
      <a href="#">Données personnelles</a>
    </li>
    <li>
      <a href="#">Gestion des cookies</a>
    </li>
  </dsmj-footer-bottom>

  <!-- Liste des partenaires -->
  <dsmj-footer-partners>
    <div dsmj-footer-partners-main>
      <a href="#/">
        <img src="https://via.placeholder.com/160x90" alt="Image exemple représentant un rectangle gris au format 160x90p">
      </a>
    </div>
    <ul dsmj-footer-partners-sub>
      <li>
        <a href="#/">
          <img src="https://via.placeholder.com/160x90" alt="Image exemple représentant un rectangle gris au format 160x90p">
        </a>
      </li>
      <li>
        <a href="#/">
          <img src="https://via.placeholder.com/100x100" alt="Image exemple représentant un rectangle gris au format 100x100p">
        </a>
      </li>
      <li>
        <a href="#/">
          <img src="https://via.placeholder.com/90x160" alt="Image exemple représentant un rectangle gris au format 90x160">
        </a>
      </li>
    </ul>
  </dsmj-footer-partners>

  <!-- Texte descriptif du footer -->
  <p>
      Exemple de texte de présentation de l'application
  </p>
</dsmj-footer>
```
