import { Component, Input } from '@angular/core';

@Component({
  selector: 'dsmj-footer',
  templateUrl: './footer.component.html',
  styleUrls: ['./footer.component.scss']
})
export class FooterComponent {

  /**
   * Indique le nom de l'organisation - obligatoire
   */
  @Input() organisationName?: string;

  /**
   * Indique le chemin vers l'image de l'organisation
   */
  @Input() organisationImagePath?: string;

  /**
   * Défini une description à l'image de l'organisation si cette dernière est définie
   */
  @Input() organisationImageDescription?: string;

  /**
   * Défini l'orientation de l'image de l'organisation si cette dernière est définie
   */
  @Input() organisationImagePosition?: 'horizontal' | 'vertical';

  /**
   * Défini le nom de l'administration du bloc-marque
   */
  @Input() logoLabel: string | string[] = ['République','Française'];

  /**
   * Défini le chemin vers la page d'accueil du site
   */
  @Input() brandLink: string = '/';

  /**
   * Récupère la description des liens vers la page d'accueil
   */
  public get brandLinkDescription(): string {
    let organisationNameText: string = this.organisationName ? ' - ' + this.organisationName : '';

    return `Retour à l’accueil du site${organisationNameText} - ${this.logoLabelString}`;
  }

  /**
   * Retourne le nom de l'organisation du logo sous format string
   */
  public get logoLabelString(): string {

    let logoLabel: string;
    // si le label est au format tableau, on le retravail
    if(typeof this.logoLabel === 'object') {
      logoLabel = "";
      this.logoLabel.forEach(str => {
        logoLabel += " " + str;
      });
    // si le label est déjà au format string, on le renvoit tel quel
    } else
      return this.logoLabel;

    return logoLabel;
  }

  constructor() { }

}
