import { FormGroup } from '@angular/forms';
import { DsmjFormControlDirective } from './form-control.directive';
import { Validator } from './validator';

export class Control {

  /**
   * Objet de validation du contrôleur
   */
  protected _validator: Validator;

  /**
   * FormGroup du parent
   */
  protected _formGroupParent: FormGroup;

  /**
   * Objet de contrôle permettant d'accès aux éléments du DOM
   */
  protected _item: DsmjFormControlDirective;

  /**
   * Retourne le validator du contrôle
   */
  public get validator(): Validator { return this._validator; }

  /**
   * Retourne le type du controle
   */
  public get type(): string {
    return this.item.el.nativeElement.getAttribute('type');
  }

  /**
   * Retourne le type de controle: select, input, textarea, etc.
   */
  public get tag(): string {
    return this.item.el.nativeElement.tagName;
  }

  /**
   * Retourne l'objet de contrôle
   */
  public get item(): DsmjFormControlDirective { return this._item; }

  /**
   * Défini l'objet de controle
   */
  public set item(item: DsmjFormControlDirective) {
    this._item = item;
    if(this.formGroup)
      this._validator = new Validator(this.formGroup);
  }

  /**
   * Retourne le formGroup du contrôleur
   */
  public get formGroup(): FormGroup {
    if(!this._formGroupParent)
      return null;

    return this._formGroupParent.controls[this.controlName] as FormGroup;
  }

  /**
   * Retourne le nom du contrôleur affecté au formGroup
   */
  public get controlName(): string {
    return this.item ? this.item.el.nativeElement.getAttribute('formControlName') : null;
  }

  constructor(formGroup?: FormGroup) {
    this._formGroupParent = formGroup;
  }
}
