import { FormGroup } from "@angular/forms";

const VALIDATOR_INVALID_MESSAGE = {
  required: 'Ce champ est obligatoire',
  min: 'La valeur du champ est trop basse',
  max: 'La valeur du champ est trop élevé',
  minlength: 'Le nombre de caractère n\'est pas suffisant',
  maxlength: 'Le nombre de caractère dépasse la limite autorisée',
  pattern: 'Le format du champ est invalide',
  email: 'Le format de l\'email est invalide',
}

export class Validator {

  /**
   * formGroup associé à ce validator
   */
  protected _formGroup: FormGroup;

  /**
   * Retourne la liste des messages d'erreurs
   */
  public get errors(): string[] {
    let messages: string[] = [];
    if(this.isInvalid()) {
      Object.keys(this._formGroup.errors).forEach((key: string) => {
        if(this._formGroup.errors[key])
          messages.push(VALIDATOR_INVALID_MESSAGE[key]);
      });
    }
    return messages;
  }

  constructor(formGroup: FormGroup) {
    this._formGroup = formGroup;
  }

  /**
   * Indique si l'objet de control est invalide
   * @return boolean
   */
  isInvalid(): boolean {
    // Retourne faux si:
    // - le formGroup ou l'objet de contrôle errors lié au formGroup n'existe pas
    if(!this._formGroup.errors)
      return false;

    // - le nombre d'erreur est égal à 0
    if(Object.keys(this._formGroup.errors).length == 0)
      return false

    // Sinon retourne vrai
    return true;
  }
}
