import { Component, Input } from "@angular/core";
import { v4 as uuidv4 } from 'uuid';

/** Unique id de l'objet */
const UUID: string = uuidv4();

/** Id de la legend du fieldset */
export const IDNAME_FIELDSET_LEGEND: string = 'dsmj-fieldset__legend-' + UUID;

/** Id du message d'erreur */
export const IDNAME_ERROR_MESSAGE: string = 'dsmj-fieldset__error-desc-' + UUID;

/** Id du message de validation */
export const IDNAME_VALID_MESSAGE: string = 'dsmj-fieldset__valid-desc-' + UUID;

@Component({
  selector: 'dsmj-form-group',
  templateUrl: './form-group.component.html'
})
export class FormGroupComponent {

  /**
   * Légende pour l'ensemble de champs
   */
  @Input() label: string;

  /**
   * Texte de description additionnel
   */
  @Input() hint: string;

  /**
   * Désactiver le groupe de champs
   */
  @Input() disabled: boolean;

  /**
   * Positionne les champs en ligne
   */
  @Input() inline: boolean;

  /**
   * Message d'erreur - Note, renseigner une valeur active l'état d'erreur
   */
  @Input() errorMessage: string;


  /**
   * Message de validation - Note, renseigner une valeur active l'état de validation
   */
  @Input() validMessage: string;

  /**
   * Indique si le groupe de champ est en erreur
   */
  get error(): boolean {
    return !!this.errorMessage;
  }

  /**
   * Indique si le groupe de champ est valide
   */
  get valid(): boolean {
    return !!this.validMessage;
  }

  get id(): string {
    return this._id;
  }

  /**
   * Retourne la liste des noms des identifiants
   */
  get idname(): {
    IDNAME_FIELDSET_LEGEND,
    IDNAME_ERROR_MESSAGE,
    IDNAME_VALID_MESSAGE} {
    return {
      'IDNAME_FIELDSET_LEGEND': IDNAME_FIELDSET_LEGEND,
      'IDNAME_ERROR_MESSAGE': IDNAME_ERROR_MESSAGE,
      'IDNAME_VALID_MESSAGE': IDNAME_VALID_MESSAGE
    };
  }

  protected _id: string;
};
