import {Injectable} from '@angular/core'
import {Observable, Subject} from 'rxjs'
import {filter} from "rxjs/operators";

/**
 * Service permettant l'écoute de l'évent click sur le document. <br>
 * Prévu pour les composant|directive|etc ayant besoin de connaitre la position du click du pointer. <br>
 * @see SelectComponent
 */
@Injectable({
  providedIn: 'root',
})
export class DomClickService {
  /** Contient la valeur cible du click*/
  private subject = new Subject<EventTarget | null>();

  constructor() {
    document.addEventListener('click', el => this.click(el.target))
  }

  /** Permet l'observation global */
  onClick(): Observable<EventTarget | null> {
    return this.subject;
  }

  /** Change la valeur cible du click */
  private click(el: EventTarget | null): void {
    this.subject.next(el);
  }

  /** Permet l'observation de click hors du composant cible */
  onClickOut(nativeElement: any): Observable<EventTarget | null> {
    return this.subject.asObservable().pipe(filter(x => !nativeElement.contains(x)));
  }
}
