import {Directive, OnInit} from '@angular/core'
import {FormBaseComponent} from './form-base.component'
import {FormGroup} from '@angular/forms'

@Directive()
export class FormAIBaseComponent<T> extends FormBaseComponent<T> implements OnInit {
  accordionId = ''

  override ngOnInit(): void {
    super.ngOnInit()

    // on configure l'accordionId via un nom machine autogénéré afin d'éviter les collisions entre multibloc de meme composant
    this.accordionId = this.buildName()
  }

  /**
   * Construit un nom machine en se basant sur le formGroup et le _nameControl
   */
  protected buildName(): string {
    let name = ''
    if (!this.formGroup) {
      return name
    }
    for (const parent in this.formGroup.controls) {
      if (parent === this._nameControl) {
        name = this._findName(this.formGroup)
      }
    }

    return name + '-' + this._nameControl
  }

  /**
   * Construit un nom machine en se basant sur l'arbre du formGroup
   */
  protected _findName(fb: FormGroup): string {
    const fbParent = fb?.parent
    for (const parentKey in fbParent?.controls) {
      if (fbParent?.get(parentKey) == fb) {
        const r = this._findName(fbParent as FormGroup)
        return r != '' ? r + '-' + parentKey : parentKey
      }
    }

    return ''
  }
}
