import {Directive, OnInit} from "@angular/core";
import {Form, FormArray, FormGroup} from "@angular/forms";
import {FormBaseComponent} from "./form-base.component";

/** type du formGroup attendu pour la génération de fg à injecter dans le fb parent */
interface FormGroupFunc {
  (): FormGroup
}

@Directive()
export class FormArrayBaseComponent<T extends any[]> extends FormBaseComponent<T> implements OnInit {
  /** nom de l'input array dans lequel le formGroup doit être injecté */
  override _nameControl: string
  /** function pour la génération de formGroup à injecter dans le parentContainer.formGroup - formArray */
  override _formGroup: FormGroupFunc

  override ngOnInit(): void {
    super.ngOnInit()
  }

  /** Injection, selon le contenu de 'data', des formGroups de la fonction _formGroup dans le formGroup parent */
  override injectFormGroup(): void {
    if (this.formGroup && this._nameControl) {
      this.formGroup.setControl(this._nameControl, this.fb.array([]));
      if (this.data && this.data.length > 0 && typeof this._formGroup == 'function') {
        for (let i = 0; i < this.data.length; ++i) {
          (this.formGroup?.get(this._nameControl) as FormArray).push(this._formGroup())
        }
      }
    }
  }

  /** Hydrate les FormGroups du composant */
  override loadData(): void {
    if (this.formGroup && this._nameControl) {
      const fbp = (this.formGroup.get(this._nameControl) as FormArray)?.controls
      for (const fbpKey in fbp) {
        const y = (this.formGroup.get(this._nameControl)?.get(fbpKey) as FormArray)
        const x = this.data?.[fbpKey]
        for (const fbpKey in y?.controls) {
          if (typeof x?.[fbpKey] != undefined) {
            y.get(fbpKey)?.setValue(x?.[fbpKey])
          }
        }
      }
    }
  }

  /** retourne le formGroup parent du composant */
  get subFormGroup(): FormArray {
    return this.formGroup.get(this._nameControl) as FormArray
  }

  /** permet l'ajout d'une nouvelle entrée dans le formGroup parent */
  add(): void {
    this.subFormGroup.push(this._formGroup());
  }

  /** supprime un formGroup du formGroup parent */
  remove(i: number): void {
    if (this.subFormGroup.at(i)) {
      this.subFormGroup.removeAt(i)
    }
  }
}
