import {ComponentFixture, fakeAsync, TestBed, tick, waitForAsync} from '@angular/core/testing';

import {AutocompleteComponent} from './autocomplete.component';
import {
  ControlContainer,
  FormControl,
  FormGroup,
  Validators,
  FormsModule,
  ReactiveFormsModule,
} from "@angular/forms";
// import {MatInputModule} from "@angular/material/input";
import {MatAutocompleteModule} from "@angular/material/autocomplete";
import {fakeTyping, getMockedControlContainer} from "../../../helper/spec-helper";
import {BehaviorSubject} from "rxjs";
import {InputValue} from "../_base/InputValue";

const field = 'autocomplete';

describe('AutocompleteComponent', () => {
  let component: AutocompleteComponent;
  let fixture: ComponentFixture<AutocompleteComponent>;
  let element: HTMLElement;

  let fg: FormGroup = new FormGroup({
    [field]: new FormControl(undefined, Validators.required),
  });

  let found = new BehaviorSubject<InputValue[]>([
    { value: 'Art1', label: 'architecture' },
  ])

  let options = new BehaviorSubject<InputValue[]>([
    { value: 'Art1', label: 'architecture' },
    { value: 'Art2', label: 'sculpture' },
    { value: 'Art3', label: 'arts visuels (peinture, dessin, etc.)' },
    { value: 'Art4', label: 'musique' },
    { value: 'Art5', label: 'littérature (poésie ou dramaturgie)' },
    { value: 'Art6', label: 'arts de la scène (théâtre, danse, mime, cirque, humour)' },
    { value: 'Art7', label: 'cinéma' },
  ])

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ AutocompleteComponent ],
      imports: [ReactiveFormsModule, FormsModule,
        // MatInputModule,
        MatAutocompleteModule],
      providers: [
        { provide: ControlContainer, useValue: getMockedControlContainer(fg) }
      ]
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(AutocompleteComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    component.nameInput = field;
    component.inputValues = options.asObservable()
    fixture.detectChanges();
  });

  afterEach(() => {
    component.ngOnDestroy()
    fixture.destroy()
  })

  it('autocomplete component should be created', () => {
    expect(component).toBeTruthy();
  });

  it('initial autocomplete value', () => {
    fixture.detectChanges()
    expect(component.formGroup?.valid).toBeFalsy();
  });

  it('autocomplete value after user has clicked', fakeAsync(() => {
    component.ngOnInit();
    const input = fixture.nativeElement.querySelector('input');
    fakeTyping(fixture, 'archi', input)
    expect(input.value).toBe('archi')
    // const dropdownItems = getElement(element, 'mat-option') // TODO : mat-option is not populated in template
    // expect(dropdownItems.length).toBe(1)
  }));
});
