import {ChangeDetectionStrategy, Component, Input, OnInit, ViewChild} from "@angular/core"
import {InputValue} from "../_base/InputValue";
import {InputBaseComponent} from "../_base/input-base.component";
import {Observable, of} from "rxjs";
import {debounceTime, map, startWith, switchMap} from "rxjs/operators";
import {ControlContainer, FormControl, FormControlDirective} from "@angular/forms";

@Component({
  selector: 'dsmj-input-autocomplete',
  templateUrl: './autocomplete.component.html',
  styleUrls: ['./autocomplete.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class AutocompleteComponent extends InputBaseComponent implements OnInit {
  @Input() public withSearch: boolean = false
  @Input() public showValues: boolean = true
  @Input() inputValues?: Observable<InputValue[]>;

  @ViewChild('ctrlD', {read: FormControlDirective})
    ctrlD! :FormControlDirective

  filteredOptions!: Observable<InputValue[]>;

  get control(): FormControl {
    return this.formGroup.get(this.nameInput) as FormControl;
  }


  constructor(protected override _parentContainer: ControlContainer) {
    super(_parentContainer);
  }

  ngOnInit(): void {
    this.init();
    this.filteredOptions = this.control?.valueChanges!.pipe(
      debounceTime(500),
      startWith(null),
      switchMap((val) => this.filter(val || ''))
    );
  }

  filter(val: string): Observable<InputValue[]> {
    // console.log('filter() --------------> [', val, ']')
    if (this.inputValues == undefined) return of([]);
    return this.inputValues.pipe(map((response: InputValue[]) => response?.filter((option: InputValue) => {
      return option.label.toLowerCase().indexOf(val.toLowerCase()) === 0
    })));
  }

  selectOption(op: any): void {
    this.ctrlD?.valueAccessor?.writeValue(op.label)
    this.ctrlD?.control?.setValue(op.value, {
      emitModelToViewChange: false
    })
  }
}
