import {ComponentFixture, fakeAsync, TestBed, tick, waitForAsync} from '@angular/core/testing';

import {InputComponent} from './input.component';
import {
  ControlContainer,
  FormControl,
  FormGroup,
  Validators,
  FormsModule,
  ReactiveFormsModule,
} from "@angular/forms";
import {fakeTyping, getMockedControlContainer} from "../../../helper/spec-helper";
import {NO_ERRORS_SCHEMA} from "@angular/core";

const field = 'field';

describe('InputComponent', () => {
  let component: InputComponent;
  let fixture: ComponentFixture<InputComponent>;
  let element: HTMLElement;

  let fg: FormGroup = new FormGroup({
    [field]: new FormControl(undefined, Validators.required),
  });

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ InputComponent ],
      imports: [ReactiveFormsModule, FormsModule],
      providers: [
        { provide: ControlContainer, useValue: getMockedControlContainer(fg) }
      ],
      schemas: [ NO_ERRORS_SCHEMA ]
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(InputComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    component.nameInput = field;
    fixture.detectChanges();
  });

  it('input component should be created', () => {
    expect(component).toBeTruthy();
  });

  it('initial input value', () => {
    fixture.detectChanges()
    expect(component.formGroup?.valid).toBeFalsy();
  });

  it('input value after user has clicked', fakeAsync(() => {
    component.ngOnInit();
    const input = fixture.nativeElement.querySelector('input');
    fakeTyping(fixture, 'archi', input)
    expect(input.value).toBe('archi')
  }));

  // TODO test others input type (date, number, password, time)
});
