import {ChangeDetectionStrategy, Component, Input, OnInit} from '@angular/core';
import { InputBaseComponent } from '../_base/input-base.component';
import {InputType} from "./model/input-type.model";
import {ControlContainer} from "@angular/forms";

const defaultDatePattern = "\\d{4}-\\d{2}-\\d{2}";
const defaultNumberPattern = "[0-9]*";
const defaultTimePattern = "\\d{2}:\\d{2}";

/**
 * Composant input text
 */
@Component({
  selector: 'dsmj-input',
  changeDetection: ChangeDetectionStrategy.OnPush,
  templateUrl: './input.component.html'
})
export class InputComponent extends InputBaseComponent implements OnInit {
  /** generic inputs */
  @Input() type: InputType = 'text'
  @Input() pattern?: any

  /** only for time input */
  @Input() list?: string[] = undefined
  @Input() min?: string = undefined
  @Input() max?: string = undefined
  @Input() step?: string = undefined

  @Input() shouldShowError?: boolean = true
  @Input() shouldShowValid?: boolean = false

  @Input() validationMessage?: string

  /**
   * Texte additionnel permettant d'apporter des détails au champ
   */
  @Input() hintText?: string;
  fieldPattern;

  get keyTime(): string | undefined {
    return this.type === 'time' ? this.id + '-list' : undefined
  }

  get showError(): boolean {
    return this.shouldShowError && this.fieldTouched && this.fieldInvalid;
  }
  get showValid(): boolean {
    return this.shouldShowValid && this.fieldTouched && this.fieldValid;
  }

  constructor(protected override _parentContainer: ControlContainer) {
    super(_parentContainer);
  }

  ngOnInit(): void {

    this.init();
    if (this.type === 'date') {
      this.fieldPattern = this.pattern ? this.pattern : defaultDatePattern;
    }
    if (this.type === 'number') {
      this.fieldPattern = this.pattern ? this.pattern : defaultNumberPattern;
    }
    if (this.type === 'time') {
      this.fieldPattern = this.pattern ? this.pattern : defaultTimePattern;
    }
  }
}
