import {
  ChangeDetectorRef,
  Component,
  ElementRef, forwardRef,
  Input,
  OnDestroy,
  OnInit,
  Optional,
  Renderer2,
  Self
} from '@angular/core';
import {RadioGroupComponent} from "../dsmj-radio-group/radio-group.component";
import {DsfrRadioButton} from "../dsfr-radio-button";
import {ControlContainer, ControlValueAccessor, NG_VALUE_ACCESSOR, NgControl} from "@angular/forms";

@Component({
  selector: 'dsmj-radio',
  templateUrl: './radio.component.html',
  styleUrls: ['./radio.component.scss'],
})
export class RadioComponent extends DsfrRadioButton implements ControlValueAccessor, OnInit, OnDestroy{

  static ngAcceptInputType_disabled: boolean | '';

  model: any;

  /**
   * The form control value when current radio button is checked.
   */
  @Input()
  set value(value: any) {
    this._value = value;
    const stringValue = value ? value.toString() : '';
    this._renderer.setProperty(this._element.nativeElement, 'value', stringValue);
    this._group?.onRadioValueUpdate();
  }
  get value() { return this._value; }

  /**
   * If `true`, current radio button will be disabled.
   */
  @Input()
  set disabled(isDisabled: boolean) {
    this._disabled = isDisabled;
  }
  get disabled() { return this._group?.disabled || this._disabled; }

  set focused(isFocused: boolean) {
    if (!isFocused && this._group) {
      this._group.onTouched();
    }
  }

  get nameAttr() { return this.name || this._group?.name; }
  get getID() { return this.id }

  @Input() isSmall?:boolean = false;

  constructor(
    private _renderer: Renderer2,
    private _element: ElementRef<HTMLInputElement>, private _cd: ChangeDetectorRef,
    @Optional() private _group: RadioGroupComponent,
    @Optional() @Self() private ngControl: NgControl) {

    super();

    if (_group) {
      this._group.register(this);
    }

    if (ngControl) {
      ngControl.valueAccessor = this
    }
  }

  ngOnInit() {
    if (this.ngControl) {
      this.ngControl.control.valueChanges.subscribe(value => {
        // Check to ensure the value wasn't already set (Template driven forms)
        if (this.model === value) return;
        this.writeValue(value);
      });
    }
  }

  /** A callback method invoked immediately instance is destroyed. **/
  ngOnDestroy() {
    if (this._group) {
      this._group.unregister(this);
    }
  }

  updateValue(value: any) {
    if (this.value !== value) {
      this._cd.markForCheck();
    }

    this._checked = this.value === value;
  }

  onChange() {
    this._group?.onRadioChange(this);
  }

  onTouched = () => {};

  registerOnChange(fn: any): void {
    this.onChange = fn;
  }

  registerOnTouched(fn: any): void {
    this.onTouched = fn;
  }

  writeValue(value: any) {
    this.value = value;
  }

}
