import { ComponentFixture, TestBed } from '@angular/core/testing';

import { OldRadioComponent } from './radio.component';
import {ControlContainer, FormsModule, ReactiveFormsModule} from "@angular/forms";
import {getElements, getMockedControlContainerForField, TESTING_PROPERTY} from "../../../helper/spec-helper";

describe('RadioComponent', () => {
  let component: OldRadioComponent;
  let fixture: ComponentFixture<OldRadioComponent>;
  let element: HTMLElement;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ OldRadioComponent ],
      imports: [ReactiveFormsModule, FormsModule],
      providers: [
        { provide: ControlContainer, useValue: getMockedControlContainerForField(false) }
      ]
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(OldRadioComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    component.nameInput = TESTING_PROPERTY;
    fixture.detectChanges();
  });

  it('radio component should be created', () => {
    expect(component).toBeTruthy();
  });

  it('initial radio value', () => {
    expect(component.formGroup.get(TESTING_PROPERTY)?.value).toBeFalsy();
  });

  it('radio value after user has clicked', () => {
    const input = fixture.nativeElement.querySelector('input');
    input.click()
    fixture.detectChanges()

    expect(input.checked).toBeTruthy();
    expect(component.formGroup.get(TESTING_PROPERTY)?.value).toBeTruthy();
  });

  it('radio value after user has clicked on false button', () => {
    const input = getElements(element, 'input')[1];
    input.click()
    fixture.detectChanges()

    expect(input.checked).toBeTruthy();
    expect(component.formGroup.get(TESTING_PROPERTY)?.value).toBeFalsy();
  });
});
