import {ComponentFixture, fakeAsync, TestBed, tick, waitForAsync} from '@angular/core/testing';

import { SelectDynamicComponent } from './select-dynamic.component';

import {
  ControlContainer,
  FormControl,
  FormGroup,
  Validators,
  FormsModule,
  ReactiveFormsModule,
} from "@angular/forms";
import {getElements, getMockedControlContainer} from "../../../helper/spec-helper";
import {BehaviorSubject} from "rxjs";
import {InputValue} from "../_base/InputValue";
import {NO_ERRORS_SCHEMA} from "@angular/core";

const field = 'select-dynamic';

describe('SelectDynamicComponent', () => {
  let component: SelectDynamicComponent;
  let fixture: ComponentFixture<SelectDynamicComponent>;
  let element: HTMLElement;

  let fg: FormGroup = new FormGroup({
    [field]: new FormControl(undefined, Validators.required),
  });

  let found = new BehaviorSubject<InputValue[]>([
    { value: 'Art1', label: 'architecture' },
  ])

  let options = new BehaviorSubject<InputValue[]>([
    { value: 'Art1', label: 'architecture' },
    { value: 'Art2', label: 'sculpture' },
    { value: 'Art3', label: 'arts visuels (peinture, dessin, etc.)' },
    { value: 'Art4', label: 'musique' },
    { value: 'Art5', label: 'littérature (poésie ou dramaturgie)' },
    { value: 'Art6', label: 'arts de la scène (théâtre, danse, mime, cirque, humour)' },
    { value: 'Art7', label: 'cinéma' },
  ])

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ SelectDynamicComponent ],
      imports: [ReactiveFormsModule, FormsModule],
      providers: [
        { provide: ControlContainer, useValue: getMockedControlContainer(fg) }
      ],
      schemas: [ NO_ERRORS_SCHEMA ]
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(SelectDynamicComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    component.nameInput = field;
    component.inputValues = options.getValue()
    fixture.detectChanges();
  });

  afterEach(() => {
    component.ngOnDestroy()
    fixture.destroy()
  })

  it('select dynamic component should be created', () => {
    expect(component).toBeTruthy();
  });

  it('initial select dynamic value', () => {
    fixture.detectChanges()
    expect(component.formGroup?.valid).toBeFalsy();
  });

  // TODO : add an test that click in one select item
});
