import {Component, ElementRef, Input, OnInit} from "@angular/core"
import {SelectComponent} from "../select/select.component"
import {AbstractControl, ControlContainer, FormArray, FormBuilder, FormGroup} from "@angular/forms"
import {InputValue} from "../_base/InputValue"
import {BehaviorSubject} from "rxjs"
import {DomClickService} from "../_base/dom-click.service";
import {takeUntil} from "rxjs/operators";

/**
 * Composant select multiple
 */
@Component({
  selector: 'dsmj-input-select-multiple',
  templateUrl: './select-multiple.component.html',
  styleUrls: ['./select-multiple.component.scss']
})
export class SelectMultipleComponent extends SelectComponent implements OnInit {
  @Input() public searchPlaceholder: string = "Rechercher un élément";
  @Input() public withSearch: boolean = false
  @Input() public showValues: boolean = true
  expanded: boolean = false;
  _formGroup = this.fb.group({checkboxes: this.fb.array([]), search: ''})
  _columnFG = (inputName: string, value?: boolean): FormGroup => this.fb.group({
    value: value ?? false,
    name: inputName
  })
  data = {valueShowed: '', search: ''}

  @Input()
  override set value(value: string[] | undefined) {
    if (!value) {
      value = []
    }
    this._value.next(value)
  }

  override get value(): string[] {
    return this._value.value
  }

  _value = new BehaviorSubject<string[]>([])

  get subInputs(): FormArray {
    return this._formGroup.get('checkboxes') as FormArray
  }

  constructor(protected override _parentContainer: ControlContainer,
              protected fb: FormBuilder,
              protected domClickService: DomClickService,
              protected elRef: ElementRef) {
    super(_parentContainer);
  }

  ngOnInit(): void {
    this.init();
    this.loadData();

    this._formGroup.get('search')?.valueChanges!.pipe(takeUntil(this._destroy)).subscribe((v: any) => {
      this.data.search = v
    })

    this.domClickService.onClickOut(this.elRef.nativeElement).pipe(takeUntil(this._destroy)).subscribe(el => {
      this.expanded = false
    })
  }

  loadData(): void {
    let values = this.formGroup.get(this.nameInput)?.value
    // todo a revoir
    if (!this.nameInput) {
      values = this.value
    }
    if (!values || !Array.isArray(values)) {
      values = []
    }
    this.inputValues?.forEach(col => this.subInputs.push(this._columnFG(col.value, values?.filter((v: any) => v == col.value)?.length > 0)));

    // todo a revoir
    if (this.nameInput) {
      this.subInputs.valueChanges.pipe(takeUntil(this._destroy)).subscribe(
        v => this.formGroup.get(this.nameInput)?.setValue(v.filter((checkbox: any) => checkbox.value).map((c: any) => c.name)))
    }
    const fun = (v: any): void => {
      if (!this.showValues) {
        this.data.valueShowed = this.emptyLabel
        return
      }
      //todo WARNING A VIRER DE LA
      if (Array.isArray(v)) {
        const vs: any[] = []
        v.forEach((val: any) => {
          const tmp = this.inputValues.find((iv: InputValue) => iv.value == val)
          if (tmp) {
            const r = /([0-9]*) -/gi.exec(tmp.label)
            if (r !== null) {
              vs.push(r[1])
            } else {
              vs.push(tmp.label.slice(0, 8))
            }
          }
        })
        this.data.valueShowed = vs.join(', ')
        return
      }
      this.data.valueShowed = v?.length > 0 ? v.length + ' Element(s) sélectionné(s)' : this.emptyLabel
    }
    // todo a revoir
    if (this.nameInput) {
      this.formGroup.get(this.nameInput)?.valueChanges!.pipe(takeUntil(this._destroy)).subscribe(fun)
    } else {
      this._value.pipe(takeUntil(this._destroy)).subscribe(fun)
    }
    fun(values)
  }

  filter(inputLabel: string): boolean {
    if (!this.data?.search || this.data.search == '') {
      return true
    }
    return inputLabel!.toLowerCase().includes(this.data.search?.toLowerCase());
  }

  showCheckboxes(): void {
    this.expanded = (!this.expanded)
  }

  uncheck(input: AbstractControl): void {
    input.value.value = false
    input.patchValue(input.value)
  }
}
