import {ComponentFixture, fakeAsync, TestBed, tick, waitForAsync} from '@angular/core/testing';

import { SelectComponent } from './select.component';

import {
  ControlContainer,
  FormControl,
  FormGroup,
  Validators,
  FormsModule,
  ReactiveFormsModule,
} from "@angular/forms";
import {fakeTyping, getMockedControlContainer} from "../../../helper/spec-helper";
import {BehaviorSubject} from "rxjs";
import {InputValue} from "../_base/InputValue";

const field = 'select';

describe('SelectComponent', () => {
  let component: SelectComponent;
  let fixture: ComponentFixture<SelectComponent>;
  let element: HTMLElement;

  let fg: FormGroup = new FormGroup({
    [field]: new FormControl(undefined, Validators.required),
  });

  let found = new BehaviorSubject<InputValue[]>([
    { value: 'Art1', label: 'architecture' },
  ])

  let options = new BehaviorSubject<InputValue[]>([
    { value: 'Art1', label: 'architecture' },
    { value: 'Art2', label: 'sculpture' },
    { value: 'Art3', label: 'arts visuels (peinture, dessin, etc.)' },
    { value: 'Art4', label: 'musique' },
    { value: 'Art5', label: 'littérature (poésie ou dramaturgie)' },
    { value: 'Art6', label: 'arts de la scène (théâtre, danse, mime, cirque, humour)' },
    { value: 'Art7', label: 'cinéma' },
  ])

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ SelectComponent ],
      imports: [ReactiveFormsModule, FormsModule],
      providers: [
        { provide: ControlContainer, useValue: getMockedControlContainer(fg) }
      ]
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(SelectComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    component.nameInput = field;
    component.inputValues = options.getValue()
    fixture.detectChanges();
  });

  afterEach(() => {
    component.ngOnDestroy()
    fixture.destroy()
  })

  it('select component should be created', () => {
    expect(component).toBeTruthy();
  });

  it('initial select value', () => {
    fixture.detectChanges()
    expect(component.formGroup?.valid).toBeFalsy();
  });

  it('select value after user has clicked', fakeAsync(() => {
    component.ngOnInit();
    const select = fixture.nativeElement.querySelector('select');
    select.value = select.options[3].value; // select Art3
    select.dispatchEvent(new Event('change'));
    fixture.detectChanges()
    expect(component.input.value).toBe(options.getValue()[2].value)
  }));
});
