import {ComponentFixture, fakeAsync, TestBed} from '@angular/core/testing';

import {TextareaComponent} from './textarea.component';
import {ControlContainer, FormControl, FormGroup, FormsModule, ReactiveFormsModule, Validators,} from "@angular/forms";
import {fakeTyping, getMockedControlContainer} from "../../../helper/spec-helper";
import {NO_ERRORS_SCHEMA} from "@angular/core";

const field = 'textarea';

describe('TextareaComponent', () => {
  let component: TextareaComponent;
  let fixture: ComponentFixture<TextareaComponent>;
  let element: HTMLElement;

  let fg: FormGroup = new FormGroup({
    [field]: new FormControl(undefined, Validators.required),
  });

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ TextareaComponent ],
      imports: [ReactiveFormsModule, FormsModule],
      providers: [
        { provide: ControlContainer, useValue: getMockedControlContainer(fg) }
      ],
      schemas: [ NO_ERRORS_SCHEMA ]
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(TextareaComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    component.nameInput = field;
    fixture.detectChanges();
  });

  it('textarea component should be created', () => {
    expect(component).toBeTruthy();
  });

  it('initial textarea value', () => {
    component.autoSized = true
    fixture.detectChanges()
    expect(component.formGroup?.valid).toBeFalsy();
  });

  it('textarea value after user has clicked', fakeAsync(() => {
    component.ngOnInit();
    const textarea = fixture.nativeElement.querySelector('textarea');
    fakeTyping(fixture, 'archi', textarea)
    expect(textarea.value).toBe('archi')
  }));
});
