import {AfterContentInit, ChangeDetectionStrategy, Component, ElementRef, forwardRef, Input, OnInit} from "@angular/core";
import {ControlContainer, NG_VALUE_ACCESSOR} from "@angular/forms";
import {InputBaseComponent} from "../_base/input-base.component";

/**
 * Composant input textarea
 */
@Component({
  selector: 'dsmj-input-textarea',
  templateUrl: './textarea.component.html',
  providers: [
    {
      provide: NG_VALUE_ACCESSOR,
      useExisting: forwardRef(() => TextareaComponent),
      multi: true
    }
  ],
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class TextareaComponent extends InputBaseComponent implements OnInit, AfterContentInit {
  @Input() autoSized: boolean = false;

  constructor(protected override _parentContainer: ControlContainer, private el: ElementRef) {
    super(_parentContainer)
  }

  ngOnInit(): void {
    this.init();
  }

  ngAfterContentInit(): void {
    if (!this.autoSized) return;

    const textareaEL = this.el.nativeElement.querySelector('textarea')
    if(!textareaEL) {
      return
    }
    // hack pour éviter l'utilisation de AfterContentChecked
    textareaEL.value = this.input?.value
    textareaEL.style.height = textareaEL.scrollHeight + 'px'
    textareaEL.addEventListener('change', () => {
      console.count('change')
      textareaEL.style.height = textareaEL.scrollHeight + 'px'
    })
    textareaEL.addEventListener('input', () => {
      console.count('input')
      textareaEL.style.height = textareaEL.scrollHeight + 'px'
    })
  }
}
