import {
  Directive,
  Output,
  EventEmitter,
  HostBinding,
  HostListener, Input, OnChanges, SimpleChanges
} from '@angular/core';
import {DndErrorType} from "../model/dnd-error.model";

@Directive({
  selector: '[dsmjDnd]'
})
export class DndFileDirective implements OnChanges {
  @Input() disabled = false;
  @Input() allowed_extensions : Array<string> = ['pdf', 'png', 'jpeg', 'jpg', 'bmp'];

  @Output() private filesChangeEmitter : EventEmitter<File[]> = new EventEmitter();
  @Output() private filesInvalidEmitter : EventEmitter<DndErrorType> = new EventEmitter();

  @HostBinding('style.border-image') private borderImage = 'repeating-linear-gradient(45deg, #333333, #333333 13px, transparent 13px, transparent 23px, #333333 23px) .5';
  @HostBinding('style.border-style') private borderStyle = 'solid';
  @HostBinding('style.border-width') private borderWidth = '3px';
  @HostBinding('style.background') private background = 'inherit';
  // @HostBinding('style.cursor') private cursor = 'inherit';
  // @HostBinding('style.opacity') private opacity = '100%';

  constructor() { }

  get backgroundColor() {
    // return this.disabled ? '#929292' : this.background;
    return this.background;
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.disabled) {
      this.background = this.backgroundColor;
    }
  }

  @HostListener('dragover', ['$event']) public onDragOver(evt): void {
    evt.preventDefault();
    evt.stopPropagation();
    if (this.disabled) return;

    this.changeBackgroung('whitesmoke');
  }

  @HostListener('dragleave', ['$event']) public onDragLeave(evt): void {
    evt.preventDefault();
    evt.stopPropagation();
    if (this.disabled) return;

    this.changeBackgroung();
  }

  @HostListener('drop', ['$event']) public onDrop(evt): void {
    evt.preventDefault();
    evt.stopPropagation();
    if (this.disabled) return;

    let valid_files : Array<File> = Array.from(evt.dataTransfer.files);
    if (this.validateFiles(valid_files)) {
      this.filesChangeEmitter.emit(valid_files);
    } else {
      this.filesInvalidEmitter.emit('format');
    }
    this.changeBackgroung();
  }

  private changeBackgroung(bgColor: 'inherit' | 'whitesmoke' = 'inherit'): void {
    this.borderImage = 'repeating-linear-gradient(45deg, #333333, #333333 13px, transparent 13px, transparent 23px, #333333 23px) .5';
    this.borderStyle = 'solid';
    this.borderWidth = '3px';
    this.background = bgColor;
    // this.cursor = this.disabled ? 'not-allowed' : 'inherit';
    // this.opacity = this.disabled ? '50%' : '100%';
  }

  private validateFiles(files: Array<File>): boolean {
    if (this.allowed_extensions == null) return true;
    return files.every(f => this.validateFile(f.name));
  }

  private validateFile(name: String): boolean {
    if (this.allowed_extensions == null) return true;

    const ext = name.substring(name.lastIndexOf('.') + 1)?.toLowerCase();
    return this.allowed_extensions.map(val => val.toLowerCase()).includes(ext);
  }
}
