import {ComponentFixture, TestBed} from '@angular/core/testing';

import {UploadFileComponent} from './upload-file.component';
import {By} from "@angular/platform-browser";
import {DndFileDirective} from "./directive/dnd-file.directive";

describe('UploadFileComponent', () => {
  let component: UploadFileComponent;
  let directive: DndFileDirective;
  let fixture: ComponentFixture<UploadFileComponent>;
  let element: HTMLElement;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ DndFileDirective, UploadFileComponent ],
      schemas: [ ]
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(UploadFileComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    fixture.detectChanges();
  });

  it('file uploader component should be created', () => {
    expect(component).toBeTruthy();
  });

  it('file change event should arrive in handler', () => {
    const element = fixture.nativeElement;
    const input = element.querySelector('input[type="file"]');
    const spyOnChange = jest.spyOn(component, 'onFileChange');
    input.dispatchEvent(new Event('change'));
    fixture.detectChanges();
    expect(spyOnChange).toHaveBeenCalled();
  });

  it('should detect file input change and set uploadedFile  model', async () => {
    // const dataTransfer = DataTransfer()
    // dataTransfer.items.add(new File([''], 'test-file.pdf'))
    // const files = dataTransfer.files;
    const file = getMockedFile()

    const inputDebugEl  = fixture.debugElement.query(By.css('input[type=file]'));
    inputDebugEl.triggerEventHandler('change',  { target: { files: [file] } });

    fixture.detectChanges();
    await fixture.whenStable();

    expect(component.files).toBeTruthy()
    expect(component.files?.size).toBe(1)

  });

  it('should detect file input change and attempt max file size', async () => {
    // const dataTransfer = DataTransfer()
    // dataTransfer.items.add(new File([''], 'test-file.pdf'))
    // const files = dataTransfer.files;
    const file = getMockedFile(15)

    const inputDebugEl  = fixture.debugElement.query(By.css('input[type=file]'));
    inputDebugEl.triggerEventHandler('change',  { target: { files: [file] } });

    fixture.detectChanges();
    await fixture.whenStable();

    expect(component.files?.size).toBe(0)

  });

  it('should detect file input change and attempt max files', async () => {
    // const dataTransfer = DataTransfer()
    // dataTransfer.items.add(new File([''], 'test-file.pdf'))
    // const files = dataTransfer.files;
    const file = getMockedFile()
    const file2 = getMockedFile(3, 'test-file2.jpg')

    component.filesNumberLimit = 1;
    fixture.detectChanges();

    const inputDebugEl  = fixture.debugElement.query(By.css('input[type=file]'));
    inputDebugEl.triggerEventHandler('change',  { target: { files: [file, file2] } });

    fixture.detectChanges();
    await fixture.whenStable();

    expect(component.files?.size).toBe(0)
  });

  // TODO make it work
  it('test directive hostlistener functions', () => {
    const el  = element.querySelector('.add-files-card');

    const dragoverEvent = new Event('dragover', { bubbles: true });
    const dragleaveEvent = new Event('dragleave', { bubbles: true });

    // TODO dropEvent is not define inside jest
    // const dropEvent = new DragEvent('drop', { bubbles: true, dataTransfer: mockDataTransfer() });
    const dropEvent = new Event('drop', { bubbles: true });

    const dragoverSpyOn = jest.spyOn(dragoverEvent, 'preventDefault');
    const dragleaveSpyOn = jest.spyOn(dragleaveEvent, 'preventDefault');
    const dropSpyOn = jest.spyOn(dropEvent, 'preventDefault');

    el.dispatchEvent(dragoverEvent);
    el.dispatchEvent(dragleaveEvent);
    el.dispatchEvent(dropEvent);

    // fixture.detectChanges()

    expect(dragoverSpyOn).toHaveBeenCalled();
    expect(dragleaveSpyOn).toHaveBeenCalled();
    expect(dropSpyOn).toHaveBeenCalled();
  })

});

const getMockedFile = (size = 2, filename = 'test-file.jpg'): File => {
  const file = new File([''], filename, {type: 'image/jpeg'});
  Object.defineProperty(file, 'size', { value: 1024 * 1024 * size })

  return file;
}

interface MockDataTransfer {
  dropEffect: "move" | "link" | "none" | "copy"
  effectAllowed: "move" | "link" | "none" | "copy" | "copyLink" | "copyMove" | "linkMove" | "all" | "uninitialized"
  items: DataTransferItemList
  files: FileList
  types: string[]
  setData: (format?: string) => void
  getData: (format?: string) => string
  clearData: (format?: string) => void
  setDragImage: (image: Element, x: number, y: number) => void
}

const mockFileList = (): any => {
  const file = getMockedFile(1);
  const file2 = getMockedFile();
  const file3 = getMockedFile(3);

  return {
    0: file,
    1: file2,
    2: file3,
    length: 3,
    item: (index: number): File => file
  }

}

// TODO : do not delete this method, it will be use when jest will fix DataTransfer error
const mockDataTransfer = (): MockDataTransfer => {
  const file = getMockedFile(1);
  const file2 = getMockedFile();
  const file3 = getMockedFile(3);

  const files = new DataTransferItemList();
  files.add(file)
  files.add(file2)
  files.add(file3)

  return {
    dropEffect: 'move',
    effectAllowed: 'move',
    items: files,
    types: ['move'],
    setData: jest.fn(),
    getData: jest.fn(),
    clearData: jest.fn(),
    files: mockFileList(),
    setDragImage: jest.fn()
  }
};
