import {ComponentFixture, TestBed} from '@angular/core/testing';

import {ViewerFileComponent} from './viewer-file.component';
import {NO_ERRORS_SCHEMA} from "@angular/core";
import {By} from "@angular/platform-browser";
import {DsmjModalModule} from "../../../modal/modal.module";
import {ModalService} from "../../../modal/service/modal.service";
import {ModalComponent} from "../../../modal/modal.component";

describe('ViewerFileComponent', () => {
  let component: ViewerFileComponent;
  let fixture: ComponentFixture<ViewerFileComponent>;
  let element: HTMLElement;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ ViewerFileComponent, ModalComponent ],
      imports: [DsmjModalModule],
      providers: [ModalService],
      schemas: [ NO_ERRORS_SCHEMA ]
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(ViewerFileComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    fixture.detectChanges();
  });

  it('file viewer component should be created', () => {
    expect(component).toBeTruthy();
  });

  it('table should add one file', () => {
    const file = getMockedFile();
    component.files = new Set().add(file);

    expect(component.files).toContain(file)
  });

  it('table should contain one file and open modal', () => {
    const file = getMockedFile();
    component.files = new Set().add(file);

    fixture.detectChanges();

    const openModalButton: HTMLButtonElement = fixture.debugElement.query(By.css('#fileUploaded > div > table > tbody > tr > td.upload-file_size-and-action > button')).nativeElement;
    openModalButton.click()
    fixture.detectChanges();

    const h1 = window.document.body.querySelector('#fr-modal-title').innerHTML;
    expect(h1.trim()).toBe("Suppression d'un document")
  });

  it('table should add one file, open modal and emit delete file action', () => {
    const file = getMockedFile();
    component.files = new Set().add(file);
    const spyEmit = jest.spyOn(component.filesToDeleteEmitter, 'emit')

    fixture.detectChanges();

    const openModalButton: HTMLButtonElement = fixture.debugElement.query(By.css('#fileUploaded > div > table > tbody > tr > td.upload-file_size-and-action > button')).nativeElement;
    openModalButton.click()
    fixture.detectChanges();

    const deleteFileInModalButton: HTMLButtonElement = window.document.body.querySelector('.fr-modal__footer > ul > li:nth-child(2) > button') as HTMLButtonElement;
    deleteFileInModalButton.click()
    fixture.detectChanges();

    expect(spyEmit).toHaveBeenCalled()
  });
});

const getMockedFile = (size: number = 2): File => {
  const file = new File([''], 'test-file.jpg', {type: 'image/jpeg'});
  Object.defineProperty(file, 'size', { value: 1024 * 1024 * size })

  return file;
}
