import {Component, EventEmitter, Input, OnInit, Output} from '@angular/core';
import {ModalComponent} from "../../../modal/modal.component";
import {ModalService} from "../../../modal/service/modal.service";

@Component({
  selector: 'dsmj-viewer-file',
  templateUrl: './viewer-file.component.html',
  styleUrls: ['./viewer-file.component.scss']
})
export class ViewerFileComponent {

  @Input() files?: Set<File | Object>;
  @Input() needConfirmation: boolean = true;
  @Input() clickable: boolean = false;
  @Input() noFilesLabel: string = 'Aucun fichier sélectionné'
  @Input() nameField?: string;
  @Input() sizeField?: string;
  @Input() disabled: boolean = false;
  @Output() filesToDeleteEmitter = new EventEmitter();

  constructor(protected modalService: ModalService) { }

  filesToDeleteSender(files: (File | Object)[]): void {
    this.filesToDeleteEmitter.emit(files);
  }

  onDeleteAllFiles(): void {
    const files = [...this.files]
    this.onDeleteFile(files)
  }

  onDeleteFile(files: (Object | File)[]): void {
    if (this.needConfirmation) {
      this.openDeleteModal(files);
    } else {
      this.deleteFiles(files);
    }
  }

  deleteFiles(files: (Object | File)[]): void {
    if (files?.length === 0) return;

    this.filesToDeleteSender(files);
  }

  openDeleteModal(elements: (Object | File)[]): void {
    const title = elements.length <= 1 ? "Suppression d'un document" : "Suppression de tous les documents";
    const message = elements.length <= 1
      ? "Etes-vous sûr de vouloir supprimer ce document ?"
      : "Etes-vous sûr de vouloir supprimer tous les documents ?";

    const modalRef = this.modalService.open(ModalComponent, {
      title,
      message,
      buttons: {
        confirm: 'Supprimer',
        cancel: 'Annuler'
      }
    });

    modalRef.onResult().subscribe(
      {
        next: closed => {
          this.deleteFiles(elements);
        },
        error: dismissed => {
        },
        complete: () => {
        }
      }
    );
  }

  public formatBytes(file: Object | File, decimals: number = 2): string {
    if (!(file instanceof File)) return 'Format de fichier invalide'
    if (!file.size || file.size === 0) return '0 MB'

    const k = 1024
    const dm = decimals < 0 ? 0 : decimals
    const sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']

    const i = Math.floor(Math.log(file.size) / Math.log(k))

    // return parseFloat((file.size / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i]
    return parseFloat((file.size / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i]
  }

  public getFilename(file: Object | File): string {
    if (!(file instanceof File)) return 'Format de fichier invalide'
    return file.name;
  }

}
