# Composant `<dsmj-header>`

Ce composant permet d'intégrer l'entête du système de design de l'état (DSFR). notamment en permettant de personnaliser différentes parties de l'entête telle que :

- Le bloc-marque et l'identité du site ou du service
- Le partie droite dit le bloc à outils
- la navigation principale horizontale

## Le bloc-marque et l'identité du site ou du service

### Bloc-marque (obligatoire)

Par défaut, le bloc-marque est configuré pour afficher le nom de l'administration `Ministère de la Justice`, vous pouvez néanmoins modifier le nom en utilisant l'option `logoLabel` (string|string[]), auquel chaque ligne du tableau correspondra à une ligne visuelle du bloc-marque:

```html
<dsmj-header [logoLabel]="['République','Française']">
  (...)
</dsmj-header>
```

### Identité du site ou du service (optionnel)

Vous avez la possibilité d'ajouter une identité au site ou au service, pour cela, le composant `<dsmj-header>` vous propose différents type de personnalisation :

- Le nom du site / service
  - à travers l'option `organisationName` (string)
- La baseline : Courte description de l'organisation
  - à travers l'option `organisationBaseline` (string)
- Un logo
  - spécifier le chemin de l'image à l'aide de l'option `organisationImagePath` (string)
  - définir l'orientation de l'image avec l'option `organisationImagePosition` ('horizontal'|'vertical')
  - définir une description obligatoire à l'image avec l'option `organisationImageDescription` (string)
- Version beta
  - spécifie que le site est en version beta à l'aide de l'option `beta`(boolean)

Le lien intégré au bloc de l'identité du site / service / bloc-marque pointe par défaut vers la racine du site (`/`) mais peut-être rédéfini avec l'option `brandLink` (string), il est également possible de ne pas étendre la zone cliquable sur la largeur du bloc en appliquant l'option `brandLinkEnlarge` (boolean) à `false`, la valeur par défaut étant à `true`.

```html
<dsmj-header 
  organisationName="Mon application"
  organisationBaseline="Demonstration de mon application">
  (...)
</dsmj-header>
```

## Bloc à outils (optionnel)

Le bloc à outils permet d'ajouter des liens rapides, un champs de recherche, le choix de la langue du site, ou encore le profil de l'utilisateur.
Le composant `<dsmj-header>` vous propose :

- soit de gérer vous même le contenu de ce bloc tout en respectant les directifs formulés par le DSFR,

- soit d'utiliser le composant `<dsmj-header-tools>` qui vous aidera à mieux structurer le bloc à outils

Le contenu du bloc à outils se place à l'intérieur du composant `<dsmj-header>` :

```html
<dsmj-header>
  <!-- Contenu personnalisable de mon bloc outil -->
</dsmj-header>

<dsmj-header>
  <dsmj-header-tools></dsmj-header-tools>
</dsmj-header>
```

### Sous-composant `<dsmj-header-tools>` (optionnel)

Le sous-composant `<dsmj-header-tools>` propose de structurer le bloc, notamment pour :

- permettre la gestion des liens rapides
- faciliter l'intégration du champ de recherche global

#### Gestion des liens rapides `<dsmj-btns-group>` (optionnel)

Utilisez le composant `<dsmj-btns-group>` pour intégrer les liens rapides comme suit :

```html
<dsmj-header-tools>
  <dsmj-btns-group>
    <li>
      <button dsmjButton href="#/">Lien rapide</button>
    </li>
    <li>
      <button dsmjButton href="#/">Lien rapide</button>
    </li>
    <li>
      <button dsmjButton href="#/">Lien rapide</button>
    </li>
  </dsmj-btns-group>
</dsmj-header-tools>
```

#### Gestion du champ de recherche `<dsmj-search>` global (optionnel)

Utilisez le composant `<dsmj-search>` pour intégrer le champ de recherche globale :

```html
<dsmj-header-tools>
  <dsmj-search></dsmj-search>
</dsmj-header-tools>
```

## La navigation principale horizontale `<dsmj-nav>` (optionnel)

Le composant `<dsmj-search>` permet l'intégration d'une navigation principale horizontale. (consulter le README.md du composant pour connaître les options proposés) :

```html
<dsmj-header>
  <dsmj-nav>
    <li dsmj-nav-item>
      <a dsmjNavLink href="#">Accès direct</a>
    </li>
    <li dsmj-nav-item>
      <a dsmjNavLink href="#">Accès direct</a>
    </li>
    <li dsmj-nav-item>
      <a dsmjNavLink href="#">Accès direct</a>
    </li>
  </dsmj-nav>
</dsmj-header>
```

## Exemple d'implémentation

```html
<dsmj-header organisationName="Mon application">
  <!-- implémentation du bloc à outils-->
  <dsmj-header-tools>
    <!-- implémentation du groupe de liens rapides -->
    <dsmj-btns-group>
      <li>
        <button dsmjButton href="#/">Lien rapide 1</button>
      </li>
      <li>
        <button dsmjButton href="#/">Lien rapide 2</button>
      </li>
      <li>
        <button dsmjButton href="#/">Lien rapide 3</button>
      </li>
    </dsmj-btns-group>
    <!-- implémentation du bloc de recherche -->
    <dsmj-search></dsmj-search>
  </dsmj-header-tools>
  <!-- implémentation de la navigation principale horizontale -->
  <dsmj-nav>
    <li dsmj-nav-item>
      <a dsmjNavLink href="#">Accès direct</a>
    </li>
    <li dsmj-nav-item>
      <a dsmjNavLink href="#">Accès direct</a>
    </li>
    <li dsmj-nav-item>
      <a dsmjNavLink href="#">Accès direct</a>
    </li>
  </dsmj-nav>
</dsmj-header>
```
