import { ComponentFixture, TestBed } from '@angular/core/testing';
import { HeaderBrandComponent } from './brand.component';
import { DsmjLogoModule } from "../../logo/logo.module";

describe('Quand je fais appel au composant HeaderBrandComponent', () => {
  let component: HeaderBrandComponent;
  let fixture: ComponentFixture<HeaderBrandComponent>;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ HeaderBrandComponent ],
      imports: [ DsmjLogoModule ]
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(HeaderBrandComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('Doit pouvoir s\'instancier', () => {
    expect(component).toBeTruthy();
  });


  describe('Quand je renseigne le nom de mon organisation', () => {

    beforeEach(() => {
      component = new HeaderBrandComponent();
      component.organisationName = "Mon application";
    });

    it('Doit contenir le nom de l\'organisation dans getServiceLinkTitleDescription', () => {
      expect(component.getServiceLinkTitleDescription().search(component.organisationName)).not.toEqual(-1);
    });

    it('Doit pouvoir afficher le bloc conteneur `Brand`', () => {
      expect(component.showBlockBrand()).toBeTruthy();
    });

    it('Doit pouvoir afficher le bloc conteneur `Brand` / name', () => {
      expect(component.showBlockBrandName()).toBeTruthy();
    });
  });

  describe('Quand je renseigne la baseline de mon organisation', () => {
    beforeEach(() => {
      component = new HeaderBrandComponent();
      component.organisationBaseline = "Description de mon application";
    });

    it('Doit contenir la baseline de l\'organisation dans getServiceLinkTitleDescription', () => {
      expect(component.getServiceLinkTitleDescription().search(component.organisationBaseline)).not.toEqual(-1);
    });

    it('Doit pouvoir afficher le bloc conteneur `Brand`', () => {
      expect(component.showBlockBrand()).toBeTruthy();
    });

    it('Doit pouvoir afficher le bloc conteneur `Brand` / description', () => {
      expect(component.showBlockBrandDescription()).toBeTruthy();
    });
  });

  describe('Quand je renseigne une image de mon organisation', () => {
    beforeEach(() => {
      component = new HeaderBrandComponent();
      component.organisationImagePath = "./path/to/nowhere.svg";
    });

    it('Doit pouvoir afficher le bloc conteneur `Brand`', () => {
      expect(component.showBlockBrand()).toBeTruthy();
    });

    it('Doit pouvoir afficher le bloc conteneur `Brand` / image', () => {
      expect(component.showBlockBrandImage()).toBeTruthy();
    });
  });

  describe('Quand je renseigne une description de l\'image de mon organisation', () => {
    beforeEach(() => {
      component = new HeaderBrandComponent();
      component.organisationImageDescription = "Ceci est une image de mon organisation";
    });

    it('Doit pouvoir afficher le bloc conteneur `Brand` / image', () => {
      expect(component.showBlockBrandImage()).toBeTruthy();
    });

    describe('Quand je renseigne une description mais PAS l\'image de mon organisation', () => {

      it('Ne doit pouvoir afficher le bloc conteneur `Brand`', () => {
        expect(component.showBlockBrand()).toBeFalsy();
      });

    });

    describe('Quand je renseigne une description ainsi que l\'image de mon organisation', () => {

      beforeEach(() => {
        component.organisationImagePath = "./path/to/nowhere.svg";
      });

      it('Doit pouvoir afficher le bloc conteneur `Brand`', () => {
        expect(component.showBlockBrand()).toBeTruthy();
      });

    });

  });
});

