import {Component, Input} from '@angular/core';
import { v4 as uuidv4 } from 'uuid';

@Component({
  selector: 'dsmj-header-brand',
  templateUrl: './brand.component.html',
  styleUrls: ['./brand.component.scss']
})
export class HeaderBrandComponent {

  /** identifiant unique de l'objet */
  readonly UUID: string = uuidv4();

  /** identifiant du bouton burger */
  readonly IDNAME_NAV_BTN_BURGER: string = `dsmj-header-brand__btn-burger--${this.UUID}`;

  /** identifiant du bouton de recherche */
  readonly IDNAME_NAV_BTN_SEARCH: string = `dsmj-header-brand__btn-search--${this.UUID}`

  /**
   * Nom de l'administration
   */
  @Input() logoLabel?: string[] | string;

  /**
   * Lien de redirection appliqué au bloc
   */
  @Input() link: string = '/';

  /**
   * Défini si la zone cliquable du lien doit être appliquée à l'ensemble du bloc
   */
  @Input() linkEnlarge: boolean = true;

  /**
   * Nom de la structure, de l'organisation, du service
   */
  @Input() organisationName?: string = '';

  /**
   * Description ou devise de la structure
   */
  @Input() organisationBaseline?: string = '';

  /**
   * Chemin vers l'image ou le logo de la structure
   */
  @Input() organisationImagePath?: string = '';

  /**
   * Disposition de l'image : en mode portail (vertical) ou
   */
  @Input() organisationImagePosition?: 'horizontal'|'vertical';

  /**
   * Description de l'image/logo de la structure
   */
  @Input() organisationImageDescription?: string = '';

  /**
   * Défini si l'application est en phase de beta ou non
   */
  @Input() beta?: boolean;

  /**
   * Identifiant du modal de navigation
   */
  @Input() modalNavId?: string;

  /**
   * Identifiant du modal de recherche globale
   */
  @Input() modalSearchId?: string;

  constructor() { }

  /**
   * Retourne la description associer au lien renvoyant vers
   *  la racine de l'application
   */
  public get serviceLinkTitleDescription(): string {

    /** texte à construire, qui sera retourné à la fin de la fn */
    let description: string = "Accueil"

    if(this.organisationName)
      description += " - " + this.organisationName;

    description += " - " + this.logoLabelString

    return description;
  }

  /**
   * Retourne le nom de l'organisation du logo sous format string
   */
  public get logoLabelString(): string {

    let logoLabel: string;
    // si le label est au format tableau, on le retravail
    if(typeof this.logoLabel === 'object') {
      logoLabel = "";
      this.logoLabel.forEach(str => {
        logoLabel += " " + str;
      });
    // si le label est déjà au format string, on le renvoit tel quel
    } else
      return this.logoLabel;

    return logoLabel;
  }

  /**
   * Retourne vrai, si le bloc organisation doit être affiché, comprenant :
   * - le bloc image
   * - le bloc nom
   * - le bloc description / devise
   */
  showBlockBrand(): boolean {
    return (this.organisationName || this.organisationBaseline || this.organisationImagePath) ? true : false;
  }

  /**
   * Retourne vrai, si le bloc image du service doit être affiché dans l'IHM
   */
  showBlockBrandImage(): boolean {
    return this.showBlockBrand() && this.organisationImageDescription !== undefined || this.organisationImagePath !== undefined;
  }

  /**
   * Retourne vrai, si le bloc nom de l'organisation doit être affiché dans l'IHM
   */
  showBlockBrandName(): boolean {
    return this.showBlockBrand() && this.organisationName !== undefined;
  }

  /**
   * Retourne vrai, si le bloc description / devise de l'organisation doit être affiché dans l'IHM
   */
  showBlockBrandDescription(): boolean {
    return (this.showBlockBrand() && this.organisationBaseline) ? true: false;
  }
}
