import {getDriver} from "../../helper/e2e-helper";
import {By} from "selenium-webdriver";

describe('Quand je me rends sur le composant en-tête', () => {
  let driver;

  beforeAll(async () => {
    jest.setTimeout(10 * 1000)
    driver = await getDriver();
    await driver.get('http://localhost:4200/composants/header');
    driver.manage().window().maximize();
  });

  afterAll(async () => {
    await driver.quit();
  });

  describe('Quand je suis dans la partie `Bloc-marque (obligatoire)`', () => {

    it('Doit comporter le texte Ministère de la Justice dans l\'example `En-tête avec bloc-marque par défaut`', async () => {
      let text: string;
      text = await driver.findElement(By.xpath("//div[@id='doc-header--example-1a']//dsmj-logo/p[@class='fr-logo']")).getText();

      let textClean: string = text.replace(/(\r\n|\n|\r)/gm, "").trim();
      expect(textClean).toEqual('MINISTÈREDE LA JUSTICE');
    });

    it('Doit comporter le texte République Française dans l\'example `En-tête avec bloc-marque personnalisé`', async () => {
      let text: string;
      text = await driver.findElement(By.xpath("//div[@id='doc-header--example-1b']//dsmj-logo/p[@class='fr-logo']")).getText();

      let textClean: string = text.replace(/(\r\n|\n|\r)/gm, "").trim();
      expect(textClean).toEqual('RÉPUBLIQUEFRANÇAISE');
    });
  });


  describe('Quand je suis dans la partie `Identité du site ou du service (optionnel)`', () => {

    it('Doit comporter le texte `Mon application` dans le titre du site', async () => {
      let text: string;
      text = await driver.findElement(By.xpath("//div[@id='doc-header--example-2']//p[contains(@class,'fr-header__service-title')]")).getText();

      let textClean: string = text.replace(/(\r\n|\n|\r)/gm, "").trim();
      expect(textClean).toEqual('Mon application');
    });

    it('Doit comporter le texte `Demonstration de mon application` dans la description du site', async () => {
      let text: string;
      text = await driver.findElement(By.xpath("//div[@id='doc-header--example-2']//p[contains(@class,'fr-header__service-tagline')]")).getText();

      let textClean: string = text.replace(/(\r\n|\n|\r)/gm, "").trim();
      expect(textClean).toEqual('Demonstration de mon application');
    });
  });

  describe('Quand je suis dans la partie `Bloc à outils (optionnel)`', () => {

    describe('Que je suis dans la partie `Contenu du bloc à outils personnalisé`', () => {
      it('Doit comporter le texte `Contenu de mon bloc à outils` dans la partie`', async () => {
        let text: string;
        text = await driver.findElement(By.xpath("//div[@id='doc-header--example-3']//div[contains(@class,'fr-header__tools')]")).getText();

        let textClean: string = text.replace(/(\r\n|\n|\r)/gm, "").trim();
        expect(textClean).toEqual('Contenu de mon bloc à outils');
      });
    });

    describe('Que je suis dans la partie `Sous-composant `dsmj-header-tools` (optionnel)`', () => {
      it('Doit comporter une liste de lien dans la partie `Gestion des liens rapides `dsmj-btns-group` (optionnel)`', async () => {
        let nbrElements: number = 0;
        await driver.findElements(By.xpath("//div[@id='doc-header--example-4']//dsmj-header-tools//dsmj-btns-group/ul/li/button")).then(e => {
          nbrElements = e.length;
        });
        expect(nbrElements).toEqual(3);
      });

      it('Doit comporter un champ de recherche dans la partie `Gestion du champ de recherche `dsmj-search` global (optionnel)`',async () => {
        let nbrElements: number = 0;
        await driver.findElements(By.xpath("//div[@id='doc-header--example-5']//dsmj-header-tools//dsmj-search//input[@type='search']")).then(e => {
          nbrElements = e.length;
          console.log(nbrElements)
        });
        expect(nbrElements).not.toEqual(0);
      });
    });
  });
});
