import {AfterViewInit, Component, ElementRef, Input} from '@angular/core';
import { v4 as uuidv4 } from 'uuid';

@Component({
  selector: 'dsmj-header',
  templateUrl: './header.component.html'
})
export class HeaderComponent implements AfterViewInit {

  /** identifiant unique de l'objet */
  readonly UUID: string = uuidv4();

  /** identifiant du bloc conteneur du menu principal */
  readonly IDNAME_NAV_CONTAINER: string = `dsmj-header__menu--${this.UUID}`;

  /** identifiant du bloc conteneur de la boite à outils */
  readonly IDNAME_DSFR_HEADER_TOOLS_CONTAINER: string = 'fr-header__tools';

  /** identifiant du bloc conteneur de la zone de recherche globale */
  readonly IDNAME_DSFR_HEADER_SEARCH_CONTAINER: string = 'fr-header__search';

  /**
   * Lien du bloc de conteneur brand
   */
  @Input() brandLink?: string = "/";

  /**
   * Défini si la zone cliquable du lien doit être appliquée à l'ensemble du bloc
   */
  @Input() brandLinkEnlarge: boolean = true;

  /**
   * Nom de l'administration
   */
  @Input() logoLabel?: string[] | string = ["République", "Française"];

  /**
   * Nom de la structure, de l'organisation, du service
   */
  @Input() organisationName?: string;

  /**
   * Description ou devise de la structure
   */
  @Input() organisationBaseline?: string;

  /**
   * Chemin vers l'image ou le logo de la structure
   */
  @Input() organisationImagePath?: string;

  /**
   * Description de l'image/logo de la structure
   */
  @Input() organisationImageDescription: string;

  /**
   * Défini si l'application est en phase de beta ou non
   */
  @Input() beta?: boolean = false;

  /**
   * Référence à l'objet DOM deu composant
   */
  private html: HTMLElement;

  /**
   * Valeur de l'identifiant du bloc conteneur du modal de recherche globale
   */
  private _modalSearchId: string;

  /**
   * getter de `_modalSearchId`
   */
  get modalSearchId(): string {
    return this._modalSearchId;
  }

  /**
   * setter de `_modalSearchId`
   */
  set modalSearchId(id: string) {
    this._modalSearchId = id;
  }

  constructor(protected el: ElementRef) {

    this.html = el.nativeElement;
  }

  ngAfterViewInit(): void {
    let headerSearchContainerRef: HTMLElement = this.html.querySelector(`:scope .${this.IDNAME_DSFR_HEADER_TOOLS_CONTAINER} .${this.IDNAME_DSFR_HEADER_SEARCH_CONTAINER}`);
    let headerSearchInputRef: HTMLElement = headerSearchContainerRef ? headerSearchContainerRef.querySelector('input[type=search]') : null;

    // Vérifie que la référence au conteneur de recherche et le champ de recherche soit existante
    if(headerSearchContainerRef && headerSearchInputRef)
      this.modalSearchId = headerSearchContainerRef.id;
  }
}
