import {Component} from '@angular/core'
import {Modal} from "./model/modal.model"
import {Option} from "./model/option.modal";
import * as dsfr from '@gouvfr/dsfr/dist/dsfr.module.js';
declare var dsfr: any;

/** Valeur de configuration des boutons de type objet */
export interface ButtonOptions {
  /** libellé */
  label: string,
  /** callback en cas d'évent click*/
  call: Function,
  /** class custom à appliquer au bouton */
  classes?: string,
  /**
   * option complémentaire
   * - disabled : permet de désactiver le boutton et ça callback
   */
  options?: { disabled?: Function }
}

/**
 * Modal component par défaut
 */
@Component({
  selector: 'dsmj-modal',
  templateUrl: './modal.component.html'
})
export class ModalComponent extends Modal {

  option: Option = {}

  onInjectInputs(inputs: Option & Object): void {
    this.option = inputs;
  }

  /** callback par default du bouton de type 'confirm' */
  confirm(): void {
    this.close('confirming')
  }

  /** callback par default du bouton de type 'cancel' */
  cancel(): void {
    this.dismiss('canceling')
  }

  /**
   * Retourne les classes css par default si aucune n'a été spécifié dans les options,
   * et qu'elle existe
   */
  getDefaultClasses(key: string | 'confirm' | 'cancel'): string {
    return key == 'cancel' ? 'fr-btn--secondary' : ''
  }

  /**
   * Retourne la callback par default si aucune n'a été spécifié,
   * et qu'elle existe
   */
  getDefaultCall(key: string | 'confirm' | 'cancel'): Function {
    const self = this
    return () => key == 'confirm' ? self.confirm() : key == 'cancel' ? self.cancel() : undefined
  }
}
