import {ComponentRef} from '@angular/core'
import {Observable, Subject} from "rxjs"
import {Modal} from "./modal.model";
import {ModalContainerComponent} from "../base/modal-container.component";
import {take} from "rxjs/operators";

/**
 * ModalRef est un object encapsulant le ModalContainerComponent et sa modale component, <br>
 * permettant la gestion du cycle de vie des deux composants et l'écoute de la modale component
 */
export class ModalRef {
  private result$ = new Subject<any>()

  constructor(
    private modalContainer: ComponentRef<ModalContainerComponent>,
    private modal: ComponentRef<Modal>,
  ) {
    this.modal.instance.modalInstance = this
  }

  /**
   * Envoie la réponse en cas de validation dans l'observable
   * et initialise la destruction de la modale
   * @param output
   */
  close(output: any): void {
    this.result$.next(output)
    this.destroy$()
  }

  /**
   * Envoie la réponse en cas d'annulation dans l'observable
   * et initialise la destruction de la modale
   * @param output
   */
  dismiss(output: any): void {
    this.result$.error(output)
    this.destroy$()
  }

  /**
   * Permet l'écoute de la réponse de la modale
   */
  onResult(): Observable<any> {
    return this.result$.asObservable().pipe(take(1))
  }

  /**
   * détruit la modale component et cloture l'observable
   * @private
   */
  private destroy$(): void {
    this.modal.destroy()
    this.result$.complete()
  }
}

