import {ModalRef} from './modal-ref.model'
import {Option} from './option.modal'

/**
 * Class Modal de référence pour la construction d'un composant modale passant par le {ModalService}<br>
 * @see ModalService
 * @see ModalContainerComponent
 */
export abstract class Modal {
  modalInstance!: ModalRef

  /**
   * Permet l'injection des valeurs de configuration passée au ModalService.
   * @param inputs
   */
  abstract onInjectInputs(inputs: Option & Object): void

  /**
   * Methode appelé en cas de validation. Elle provoque un appel de la method close du modalRef instancient la modale.
   * @param {string|any} output Valeur retournée via l'observable
   */
  close(output?: any): void {
    this.modalInstance.close(output)
  }

  /**
   * Methode appelé en cas d'annulation. Elle provoque un appel de la method dismiss du modalRef instancient la modale.
   * @param {string|any} output Valeur retournée via l'observable
   */
  dismiss(output?: any): void {
    this.modalInstance.dismiss(output)
  }
}
