import {ApplicationRef, Injectable, Type} from '@angular/core'
import {Modal} from '../model/modal.model'
import {ModalRef} from '../model/modal-ref.model'
import {ModalContainerComponent} from "../base/modal-container.component";
import {Option} from "../model/option.modal"
import * as dsfr from '@gouvfr/dsfr/dist/dsfr.module.js';
declare var dsfr: any;

//todo move to self module
@Injectable({
  providedIn: 'root'
})
export class ModalService {
  constructor(private appRef: ApplicationRef) {
  }

  open<T extends Modal, Options extends Option & {}>(component: Type<T>, inputs?: Options): ModalRef {
    const modalContainerEl = document.createElement('dsmj-modal-container');
    document.getElementsByTagName('body')[0].appendChild(modalContainerEl);


    const modalContainer = this.appRef.bootstrap(ModalContainerComponent, modalContainerEl)
    const modalComponentRef = modalContainer.instance.createModal(component);

    modalContainer.changeDetectorRef.detectChanges();

    modalComponentRef.onDestroy( () => {
      modalContainerEl.remove()
    })

    if (inputs) {
      modalComponentRef.instance.onInjectInputs(inputs)
    }

    // Patch DSFR-277 : Force l'appel js de l'ouverture du modale après création de l'objet
    setTimeout(() => {
      let el = document.getElementById(inputs.id);
      if(el) {
        dsfr(el).modal.disclose();
      }
    }, 1);

    return new ModalRef(modalContainer, modalComponentRef);
  }
}
