# Composant `<dsmj-nav>`

Ce composant permet d'ajouter une navigation principale horizontale.

Afin de gérer plus simplement les liens et les boutons, `<dsmj-nav>` fourni des directives :

- boutons de navigation `[dsmjNavButton]` et
- lien de navigation `[dsmjNavLink]`

## Les directives Bouton/Lien de navigation

### Bouton de navigation `[dsmjNavButton]`

Le bouton de navigation gère les bouton type menu ou menu géant.

#### Options

##### `expanded` (boolean)

Défini si le bouton active le déroulement du menu

#### Exemple d'intégration

Bouton de menu, actif et déplié

```html
<button dsmjNavButton [current]="true" [expanded]="true">Mon menu</button>
```

### Lien de navigation `[dsmjNavLink]`

Le lien de navigation gère les liens type `accès direct` ou des liens contenu dans les menus.

#### Options

##### `current` (boolean)

Défini si le bouton doit être au statut actif

#### Exemple d'intégration

Lien de navigation, page actif

```html
<a dsmjNavLink aria-current="page" href="#">Lien de navigation</a>
```

## Les objets de navigation `[dsmj-nav-item]`

La navigation principale permet d'afficher différents types de menus, notamment :

- L'accès direct
- Le menu simple
- Le menu géant

Afin de gérer ces différents type, `<dsmj-nav>` propose un composant `[dsmj-nav-item]`, qui s'ajoute dans le balise `<li>` dont il est possible de définir le type de menu à l'aide de l'option `type` (string) qui accepte les valeurs suivants `lien` (par défaut) pour les accès direct, `menu` pour les menus simples et `mega-menu` pour les menus géants :

```html
<dsmj-nav>
  <li dsmj-nav-item> (...) </li>
  <li dsmj-nav-item type="menu"> (...) </li>
  <li dsmj-nav-item type="mega-menu"> (...) </li>
</dsmj-nav>
```

### L'accès direct

L'accès direct est représenté sous forme d'un lien simple qui permet de rediriger l'utilisateur vers une page définie.

#### Exemple d'intégration

```html
<dsmj-nav>
  <li dsmj-nav-item>
    <a dsmjNavLink href="#">accès direct</a>
  </li>
</dsmj-nav>
```

### Le menu simple

Le menu simple déroule une liste de liens permettant d'accéder chacun à un lien qui lui est propre.

#### Exemple d'intégration

```html
<dsmj-nav>
  <li dsmj-nav-item type="menu">
    <button dsmjNavButton>Entrée menu</button>
    <ul>
      <li>
          <a dsmjNavLink href="#">Lien de navigation</a>
      </li>
      <li>
          <a dsmjNavLink href="#">Lien de navigation</a>
      </li>
      <li>
          <a dsmjNavLink href="#">Lien de navigation</a>
      </li>
    </ul>
  </li>
</dsmj-nav>
```

### Le menu géant

Le menu géant permet d'afficher un contenu riche textuel et/ou visuel, et gère un ensemble de groupe de menus.

Vous pouvez ajouter du contenu éditorial dans l'entête du menu, pour cela, vous devez utiliser la classe `dsmj-mega-menu__edito` dans un conteneur pour que le composant puisse le prendre en compte.

Pour gérer les différentes catégories de menu, utiliser la classe `dsmj-mega-menu__categories` dans un conteneur pour qu'il puisse être détecté par le composant.

#### Exemple d'intégration

```html
<dsmj-nav>
  <li dsmj-nav-item type="mega-menu">
    <button dsmjNavButton [current]="true">Mega menu actif</button>
    <div class="dsmj-mega-menu__edito">
      <h4 class="fr-h4 fr-mb-2v">Titre éditorialisé</h4>
      <p class="fr-hidden fr-unhidden-lg">Lorem [...] elit ut.</p>
      <a dsmjLink icon="fr-icon-arrow-right-line" iconPosition="right" href="#">
          Voir toute la rubrique
      </a>
    </div>
    <div class="dsmj-mega-menu__categories">
      <div class="fr-col-12 fr-col-lg-3">
        <h5>
          <a dsmjNavLink href="#">Nom de catégorie</a>
        </h5>
        <ul>
            <li>
                <a dsmjNavLink aria-current="page" href="#">Lien de navigation</a>
            </li>
            <li>
                <a dsmjNavLink href="#">Lien de navigation</a>
            </li>
            <li>
                <a dsmjNavLink href="#">Lien de navigation</a>
            </li>
        </ul>
      </div>
      <div class="fr-col-12 fr-col-lg-3">
        <h5>
          <a dsmjNavLink href="#">Nom de catégorie</a>
        </h5>
        <ul>
            <li>
                <a dsmjNavLink href="#">Lien de navigation</a>
            </li>
            <li>
                <a dsmjNavLink href="#">Lien de navigation</a>
            </li>
            <li>
                <a dsmjNavLink href="#">Lien de navigation</a>
            </li>
        </ul>
      </div>
    </div>
  </li>
</dsmj-nav>
```
