import {Component, Input, ElementRef, AfterViewInit} from "@angular/core";
import { v4 as uuidv4 } from 'uuid';

@Component({
  selector: '[dsmj-nav-item]',
  templateUrl: './item.component.html',
})
export class NavItemComponent implements AfterViewInit {

  /** identifiant unique de l'objet */
  readonly UUID: string = uuidv4();

  /** id du bloc conteneur menu */
  readonly IDNAME_HEADER_MENU_ITEM: string = `dsmj-nav__item--${this.UUID}`;

  /** identifiant du bloc conteneur du (mega-)menu */
  readonly IDNAME_MENU_CONTAINER: string = `dsmj-nav__item__menu--${this.UUID}`;

  /** nom de classe des catégories du mega menu*/
  readonly CLASSNAME_MEGAMENU_CATEGORIES: string = 'dsmj-mega-menu__categories';

  /** nom de classe des objets de liste */
  readonly CLASSNAME_DSFR_NAV_ITEM: string = 'fr-nav__item';

  /** nom de classe des listes de lien du mega menu  */
  readonly CLASSNAME_DSFR_MEGAMENU_LIST: string = 'fr-mega-menu__list';

  /** nom de classe des catégorie de menus du mega menu */
  readonly CLASSNAME_DSFR_MEGAMENU_CATEGORY: string = 'fr-mega-menu__category';

  /** nom de classe du bloc conteneur du menu simple */
  readonly CLASSNAME_DSFR_MENU_CONTAINER: string = 'fr-menu';

  /** nom de classe de la liste de lien du menu simple */
  readonly CLASSNAME_DSFR_MENU_LIST: string = 'fr-menu__list';

  /** nom de classe de grille horizontale */
  readonly CLASSNAME_DSFR_GRID_ROW: string = 'fr-grid-row';

  /** nom de classe des modificateurs de grilles large horizontale, avec gouttière */
  readonly CLASSNAME_DSFR_GRID_ROW_LG_GUTTERS: string = 'fr-grid-row-lg--gutters';

  /**
   * Type de menu : accès direct, menu ou menu enrichi
   */
  @Input() type: 'mega-menu' | 'menu' | 'lien' = 'lien';

  private html: HTMLElement;

  constructor(protected el: ElementRef) {

    this.html = el.nativeElement;

    // Ajoute les éléments de class
    this.html.classList.add(this.CLASSNAME_DSFR_NAV_ITEM);
  }

  ngAfterViewInit(): void {

    /** Référence DOM au objets item */
    let navBtnRef: any = this.html.querySelectorAll(`:scope > button`);
    if(navBtnRef.length > 0)
      navBtnRef.forEach((item: HTMLElement) => item.setAttribute('aria-controls', this.IDNAME_MENU_CONTAINER));

    if(this.type === 'mega-menu') {
      this.addClassToMegaMenuCategory();
      this.addClassToMegaMenuList();
      this.addGridRowToMegaMenuCategories();
    } else if(this.type === 'menu') {
      this.addClassToMenuList();
    }
  }

  /**
   * Ajoute un grid row à la balise du bloc conteneur des listes de menus
   */
  addGridRowToMegaMenuCategories(): void {
    let megaMenuCategoriesRef: HTMLElement = this.html.querySelector(`:scope .${this.CLASSNAME_MEGAMENU_CATEGORIES}`);
    megaMenuCategoriesRef?.classList.add(this.CLASSNAME_DSFR_GRID_ROW, this.CLASSNAME_DSFR_GRID_ROW_LG_GUTTERS)
  }

  /**
   * Ajoute la classe DSFR correspondante à la catégorie des menus
   */
  addClassToMegaMenuCategory(): void {

    // On parcours les différentes balises heading
    for(let n = 1; n <= 6; n++) {
      let headingRef: any = this.html.querySelectorAll(`:scope .${this.CLASSNAME_MEGAMENU_CATEGORIES} h${n}`);
      // Si une balise est trouvée, on lui ajoute la classe correspondante
      if(headingRef.length > 0)
        headingRef.forEach((el: HTMLElement) => el.classList.add(this.CLASSNAME_DSFR_MEGAMENU_CATEGORY));
    };
  }

  /**
   * Ajoute la classe DSFR correspondante a chaque liste du megamenu
   */
  addClassToMegaMenuList(): void {
    let listRef: NodeList = this.html.querySelectorAll(`:scope .${this.CLASSNAME_MEGAMENU_CATEGORIES} ul`);
    if(listRef.length > 0)
      listRef.forEach((el: HTMLElement) => el.classList.add(this.CLASSNAME_DSFR_MEGAMENU_LIST));
  }

  /**
   * Ajoute la classe DSFR correspondante a chaque liste du menu
   */
  addClassToMenuList(): void {
    let listRef: NodeList = this.html.querySelectorAll(`:scope .${this.CLASSNAME_DSFR_MENU_CONTAINER} > ul`);
    if(listRef.length > 0)
      listRef.forEach((el: HTMLElement) => el.classList.add(this.CLASSNAME_DSFR_MENU_LIST));
  }
}
