import {Component, EventEmitter, Input, OnInit, Output} from '@angular/core';

/** type - bouton par défaut de la pagination */
type pagination = 'first' | 'previous' | 'next' | 'last'

/**
 * Composant paginaton
 */
@Component({
  selector: 'dsmj-pagination',
  templateUrl: './pagination.component.html',
  styleUrls: ['./pagination.component.scss']
})
export class PaginationComponent implements OnInit {
  /** nombre de pages */
  @Input() set count(count: number) {
    this._count = count
    this.dataDrawing()
  }

  /** position courante */
  @Input() current: number = 1
  /** émet en cas de changement de page */
  @Output() hasChange = new EventEmitter()
  _data: any[] = []
  /** nombre de pages - valeur flottante */
  _count: number = 10

  /** retourne le nombre de pages à l'arrondi supérieur */
  get count(): number {
    return Math.ceil(this._count)
  }

  /** corrige la valeur du count à l'arrondi supérieur en cas de flottant */
  ngOnInit(): void {
    this.count = Math.ceil(this.count)
  }

  /**
   * initialise la reconstruction de la pagination <br>
   * en cas d'erreur dans le positionnement redirige la 1èr page
   */
  dataDrawing(): void {
    const targetPage = this.current > this.count ? this.current : this.count
    if (targetPage >= 1) {
      this._drawing(targetPage)
    }

    if(this.current > this.count) {
      this.changePage(1)
    }
  }

  /** reconstruit la structure de la pagination */
  _drawing(max: number): void {
    this._data = []
    let hasPoints = false
    let t = this.current - 1
    t = (t < 2) ? 0 : ((max - t < 2) ? t - 2 : t - 1)
    for (let i = t; max > i; ++i) {
      if (i > (t + 2) && max - i > 3) {
        if (!hasPoints) {
          this._data.push('...')
          hasPoints = true
        }
      } else {
        this._data.push(i + 1)
      }
    }
  }

  /** gère le changement de pagination et le retour de l'émetteur */
  changePage(target: number | pagination): void {
    if (typeof target !== "number") {
      switch (target) {
      case "first":
        this.current = 1;
        break
      case "previous":
        if (this.current > 1) {
          this.current--
        } else {
          return
        }
        break
      case "next":
        if (this.current < this.count) {
          this.current++
        } else {
          return
        }
        break
      case "last":
        this.current = this.count;
        break
      }
    } else {
      if (target > 0 && target <= this.count) {
        this.current = target
      }
    }

    this.dataDrawing()
    this.hasChange.emit(this.current)
  }
}
