import { Component, ElementRef, EventEmitter, Input, Output, ViewChild} from "@angular/core";
import { v4 as uuidv4 } from 'uuid';

@Component({
  selector: 'dsmj-search',
  templateUrl: './search.component.html',
})
export class SearchComponent {

  /** Unique id de l'objet */
  readonly UUID: string = uuidv4();

  /** Identifiant du bloc de conteneur de recherche */
  readonly IDNAME_SEARCH_CONTAINER = `dsmj-search--${this.UUID}`;

  /** Identifiant de l'objet de control de la recherche */
  readonly IDNAME_SEARCH_CONTROL = `dsmj-search_control--${this.UUID}`;

  /**
   * Référence de l'objet du bloc de conteneur
   */
  @ViewChild('container') containerRef: ElementRef;

  /**
   * Indique que l'objet de contrôle sera géré par le composant parent
   */
  @Input() customControl: boolean = false;

  /**
   * Indique que le bouton de soumission sera géré le composant parent
   */
  @Input() customButton: boolean = false;

  /**
   * Renseigne l'attribut for du label
   */
  @Input() for: string = this.IDNAME_SEARCH_CONTROL;

  /**
   * Renseigne le placeholder de l'objet de contrôle et du texte de label
   */
  @Input() placeholder?: string = "Rechercher";

  /**
   * Renseigne le texte du bouton
   */
  @Input() btnLabel?: string = "Lancer la rechercher";

  /**
   * Indique si le bouton doit afficher son label ou pas
   */
  @Input() isLarge?: boolean = false;

  /**
   * Retourne la valeur de l'objet de contrôle au click du bouton
   */
  @Output() hasSubmit: EventEmitter<string> = new EventEmitter<string>();

  constructor() {}

  /**
   * Action à la soumission du formulaire de recherche
   */
  onSubmit(): void {

    // get control value
    let control: any = this.containerRef.nativeElement.querySelector('input');
    let controlValue: string = control.value;

    this.hasSubmit.emit(controlValue);
  }
}
