import {Component, Input, ElementRef, AfterViewInit, HostBinding} from "@angular/core";
import { v4 as uuidv4 } from 'uuid';

@Component({
  selector: '[dsmj-sidemenu-item]',
  templateUrl: './item.component.html',
})
export class SidemenuItemComponent {

  /** identifiant unique de l'objet */
  readonly UUID: string = uuidv4();

  /** id du bloc conteneur menu */
  readonly IDNAME_SIDEMENU_ITEM: string = `dsmj-sidemenu__item--${this.UUID}`;

  /** identifiant du bloc conteneur du (mega-)menu */
  readonly IDNAME_SIDEMENU_SUBMENU_CONTAINER: string = `dsmj-nav__item__submenu--${this.UUID}`;

  /** identifiant du bouton de menu */
  readonly IDNAME_SIDEMENU_ITEM_BTN: string = `dsmj-sidemenu__item__btn--${this.UUID}`;

  readonly DOM_BTN_PATH: string = `:scope > li.fr-sidemenu__item > button`

  private html: HTMLElement;

  /** retourne vrai si un bouton a été ajouté */
  public hasBtn: boolean = false;

  constructor(protected el: ElementRef) {

    this.html = el.nativeElement;

    // Ajoute les éléments de class
    this.html.classList.add(this.IDNAME_SIDEMENU_ITEM);
  }

  ngAfterViewInit(): void {

    /** Référence DOM au objets item */
    let sidemenuBtnRef: any = this.html.querySelectorAll(this.DOM_BTN_PATH);
    if(sidemenuBtnRef.length > 0) {
      sidemenuBtnRef.forEach((item: HTMLElement) => item.setAttribute('aria-controls', this.IDNAME_SIDEMENU_SUBMENU_CONTAINER));
    }
  }

  ngAfterContentInit(): void {
    /** Référence DOM au objets item */
    let sidemenuBtnRef: any = this.html.querySelectorAll(this.DOM_BTN_PATH);
    if(sidemenuBtnRef.length > 0) {
      this.hasBtn = true;
    }
  }

}
