import { ElementRef, Directive, HostBinding, OnInit, Input } from '@angular/core';

@Directive({
  selector: '[dsmjSidemenuButton]'
})
export class DsmjSidemenuButtonDirective implements OnInit {

  /** Nom de class DSFR des liens de navigation */
  readonly CLASSNAME_DSFR_NAV_BTN: string = 'fr-sidemenu__btn';

  /**
   * Défini si le bouton active le déroulement du menu
   */
  @HostBinding()
  @Input() expanded: boolean = false;

  /**
   * Défini si le bouton courant est actif
   */
  @Input() current?: boolean;

  /**
   * Objet DOM du controle
   */
  private html: HTMLElement;

  constructor(protected el: ElementRef) {

    this.html = el.nativeElement;

    // Ajoute les éléments de class
    this.html.classList.add(this.CLASSNAME_DSFR_NAV_BTN);
  }

  ngOnInit(): void {

    this.initAttributes();
  }

  /**
   * Ajoute les attributs selon les options passées
   */
  initAttributes(): void {

    let expanded: 'false' | 'true' = this.expanded ? 'true' : 'false';
    this.html.setAttribute('aria-expanded', expanded);

    if(this.current)
      this.html.setAttribute('aria-current', 'true');
  }
}
