import {Component, EventEmitter, Input, OnInit, Output, AfterViewInit, ElementRef} from '@angular/core';
import { v4 as uuidv4 } from 'uuid';

/**
 * Composant sidemenu
 */
@Component({
  selector: 'dsmj-sidemenu',
  templateUrl: './sidemenu.component.html'
})
export class SidemenuComponent implements AfterViewInit {

  /** identifiant unique de l'objet */
  readonly UUID: string = uuidv4();

  /** identifiant du bloc menu latéral */
  readonly IDNAME_WRAPPER: string = `fr-sidemenu-wrapper--${this.UUID}`;

  /** identifiant du bloc titre du menu latéral */
  readonly IDNAME_TITLE: string = `fr-sidemenu__title--${this.UUID}`;

  /** nom de class DSFR d'un sous-menu du menu latéral */
  readonly CLASSNAME_DSFR_SIDEMENU_LIST: string = `fr-sidemenu__list`;

  /**
   * Défini un titre au menu latéral
   */
  @Input() title: string;

  /**
   * Permet de fixer le menu latéral sur son conteneur parent
   */
  @Input() sticky: boolean = false;

  /**
   * Permet de fixer le menu latéral sur toute la hauteur de le page
   */
  @Input() stickyFullHeight: boolean = false;

  /**
   * Défini le positionnement du menu latéral, soit à gauche, soit à droite
   */
  @Input() position: 'left' | 'right' = 'left';

  /**
   * Objet DOM du controle
   */
  public html: HTMLElement;

  constructor(protected el: ElementRef) {

    this.html = el.nativeElement;
  }

  ngAfterViewInit(): void {

    /** Référence DOM au objets item */
    let sidemenuUlRef: any = this.html.querySelectorAll('ul');
    if(sidemenuUlRef.length > 0) {
      sidemenuUlRef.forEach((item: HTMLElement) => item.classList.add(this.CLASSNAME_DSFR_SIDEMENU_LIST));
    }

    this.hasFirstLevelMenuSelected();
  }

  /**
   * Vérifie s'il existe un menu selectionné au niveau 1
   */
  hasFirstLevelMenuSelected(): void {
    let sidemenuN1CurrentLinkRef: any = this.html.querySelectorAll('ul:first-of-type li a[aria-current="true"],ul:first-of-type li button[aria-current="true"]');
    if(sidemenuN1CurrentLinkRef.length == 0 ) {
      console.error(
        '[dsmj-sidemenu/'+this.UUID+'] Vous devez définir un menu actif pour le niveau 1 de votre menu latéral, utilisez le paramètre '+
        ' `[current]="true"` pour rendre actif l\'un de vos boutons/liens'
      )
    }
  }
}
