import {ComponentFixture, TestBed} from '@angular/core/testing';
import { SimpleChange } from '@angular/core';

import { StepperComponent } from "./stepper.component";

describe('StepperComponent', () =>{
  let component: StepperComponent;
  let fixture: ComponentFixture<StepperComponent>;
  let element: HTMLElement;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ StepperComponent ],
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(StepperComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    fixture.detectChanges();
  });

  it("should create component dsmj-stepper", () =>{
    expect(component).toBeTruthy()
  })

  it("should be empty if nothing given", () =>{
    /** Compare if the element div exist */
    expect(element.getElementsByTagName('div').item(0)).toBeNull()
  })

  it("should have a balise h2 as default", () =>{
    component.currentTitle = "Titre 1"
    component.currentNumber = 1
    component.totalNumber = 3
    component.nextTitle = "Titre 2"
    fixture.detectChanges()
    expect(element.getElementsByTagName('h2').item(0)).not.toBeNull()
  })
  
  it("should have the same title as the one given by currentTitle", () =>{
    component.currentTitle = "Titre 1"
    component.currentNumber = 1
    component.totalNumber = 3
    component.nextTitle = "Titre 2"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('h2').item(0).textContent.trim()).toContain("Titre 1")
  })
  
  it("should have the same title as the one given by nextTitle", () =>{
    component.currentTitle = "Titre 1"
    component.currentNumber = 1
    component.totalNumber = 3
    component.nextTitle = "Titre 2"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('p').item(0).textContent.trim()).toContain("Titre 2")
  })
  
  it("should have the same balise as the one given by baliseTitle", () =>{
    component.currentTitle = "Titre 1"
    component.currentNumber = 1
    component.totalNumber = 3
    component.nextTitle = "Titre 2"
    component.baliseTitle = "h4"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('h4').item(0)).not.toBeNull()
  })
  
  /** This test will generate an error in the console */
  it("should be empty if totalNumber exceed 8 and have an error message", () =>{
    component.currentTitle = "Titre 1"
    component.currentNumber = 1
    component.totalNumber = 9
    component.nextTitle = "Titre 2"
    component.ngOnChanges({
      currentNumber: new SimpleChange(undefined, 1, true),
      currentTitle: new SimpleChange(undefined, "Titre 1", true),
      totalNumber: new SimpleChange(undefined, 9, true),
      nextTitle: new SimpleChange(undefined, "Titre 2", true)
    })
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0)).toBeNull()
  })
  
  /** This test will generate an error in the console */
  it("should be empty if currentNumber exceed 8 and have an error message", () =>{
    component.currentTitle = "Titre 1"
    component.currentNumber = 9
    component.totalNumber = 9
    component.nextTitle = "Titre 2"
    component.ngOnChanges({
      currentNumber: new SimpleChange(undefined, 9, true),
      currentTitle: new SimpleChange(undefined, "Titre 1", true),
      totalNumber: new SimpleChange(undefined, 9, true),
      nextTitle: new SimpleChange(undefined, "Titre 2", true)
    })
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0)).toBeNull()
  })
  
  /** This test will generate an error in the console */
  it("should be empty if currentNumber exceed totalNumber and have an error message", () =>{
    component.currentTitle = "Titre 1"
    component.currentNumber = 4
    component.totalNumber = 3
    component.nextTitle = "Titre 2"
    component.ngOnChanges({
      currentNumber: new SimpleChange(undefined, 4, true),
      currentTitle: new SimpleChange(undefined, "Titre 1", true),
      totalNumber: new SimpleChange(undefined, 3, true),
      nextTitle: new SimpleChange(undefined, "Titre 2", true)
    })
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0)).toBeNull()
  })
})