import { Component, Input, SimpleChanges, OnChanges } from '@angular/core';

@Component({
  selector: 'dsmj-stepper',
  templateUrl: './stepper.component.html',
})

export class StepperComponent implements OnChanges{
  /** Récupération par le composant du nombre total d'étape */
  @Input() public totalNumber: number;

  /** Récupération par le composant du numéro de l'étape actuelle */
  @Input() public currentNumber: number;

  /** Récupération par le composant du titre de l'étape actuelle */
  @Input() public currentTitle: string;

  /** Récupération par le composant du titre de l'étape suivante */
  @Input() public nextTitle: string;

  /** Balise du titre de l'étape : h2 | h3 | h4 | h5 | h6 */
  @Input() public baliseTitle: 'h2' | 'h3' | 'h4' | 'h5' | 'h6' = 'h2'

  /** Nombre maximum d'étape */
  private maximumStep: number = 8

  ngOnChanges(changes: SimpleChanges): void {
    if(changes.currentNumber.currentValue) {

    }
    /** Test si le numéro d'étape actuelle ne dépasse pas le nombre total d'étape */
    else if (changes.currentNumber.currentValue > changes.totalNumber.currentValue) {
      console.error("ERROR: dsmj-stepper: Le numéro d'étape actuelle ne peut être supérieur au nombre totale d'étapes")
      this.totalNumber = undefined
      this.currentNumber = undefined
    }
    /** Test si le numéro d'étape actuelle ou le nombre total d'étape ne dépasse pas le nombre 8 */
    else if (changes.totalNumber.currentValue > this.maximumStep) {
      console.error("ERROR: dsmj-stepper: Le nombre d'étape ne peut être supérieur a 8")
      this.totalNumber = undefined
      this.currentNumber = undefined
    }
  }
}
