import { Component, Input } from '@angular/core';
import { DsmjSummaryItem } from './summary.model';
import { v4 as uuidv4 } from 'uuid';

@Component({
  selector: 'dsmj-summary',
  templateUrl: './summary.component.html',
})

export class SummaryComponent{
  /** Identifiant unique de l'objet */
  readonly UUID: string = uuidv4();

  /** Identifiant du titre du sommaire généré */
  readonly IDNAME_NAV_CONTAINER:string = "dsmj-summary__title--" + this.UUID;

  /**
   * Récupération par le composant de l'id à affiché dans le sommaire
   */
  @Input() public containerTitleId: string = "";

  /**
   * Récupération par le composant de la liste à affiché dans le sommaire
   */
  @Input() public list: DsmjSummaryItem[];

  /**
   * Génération de l'id basé sur celui donné ou création d'un id unique
   */
  get id(): string {
    return this.containerTitleId ? this.containerTitleId : this.IDNAME_NAV_CONTAINER;
  }
  
  /**
   * Fonction permettant le déplacement à une balise donné
   */
  public gotoAnchor(anchor: string): void
  {
    let element: HTMLElement = (document.getElementById(anchor) as HTMLElement);
    if(element) {
      element.scrollIntoView({ behavior: 'smooth' })
    } else {
      console.warn("[dsmj-summary]","l'ancre \"" + anchor + "\" dans le sommaire \"" + this.id + "\" n'a pas été trouvé")
    }
  }
}
