import {Component, Input, OnInit} from '@angular/core';
import {TabComponent} from "../single-tab/tab.component";

let nextId = 0;

@Component({
  selector: 'dsmj-tab-group',
  templateUrl: './tab-group.component.html',
  styleUrls: ['./tab-group.component.css'],
  providers: []
})
export class TabGroupComponent implements OnInit {

  /** Animation lors du changement d&apos;onglet */
  @Input() animation: boolean = false;
  /** Attribut aria-label associé à la liste des onglets **/
  @Input("aria-label") ariaLabel: string = "[A modifier | nom du système d'onglet]";

  /** Liste des onglets */
  private _tabs: Set<TabComponent>;

  /** ID de l&apos;onglet en cours de visualisation */
  private _selected : number = 0;

  /** Prefix pour distinguer les onglets */
  private _prefixId = `tabpanel-${nextId++}`;

  constructor() {
    this._tabs = new Set<TabComponent>();
  }

  ngOnInit(): void {
    if(this.tabs.size > 0){
      let tab : TabComponent = this.tabs.values().next().value;
      this._selected = tab.index
    }
  }
  /** Supprime un onglet existant */
  unregister(tab: TabComponent) { this.tabs.delete(tab); }
  /** Enregistre un nouvel onglet */
  register(tab: TabComponent) { this.tabs.add(tab); }


  /**
   * Retourne l&apos;ID de l'onglet actif
   * @returns ID
   */
  get selected(){
    return this._selected;
  }
  /** Retourne la liste des onglets */
  get tabs(){
    return this._tabs;
  }

  /** Rtourne le prefix des onglets */
  get prefixId(){
    return this._prefixId;
  }

  /** Notifie au parent un changement d onglet */
  changeOnglet(index: number){
    this._selected = index;
  }

}
