import {Component, ElementRef, Input, OnDestroy, OnInit, ViewEncapsulation, HostBinding} from '@angular/core';
import {TabGroupComponent} from "../group-tab/tab-group.component";

//Incrmental ID to avoid the same id attribute for group
let nextId = 0;

@Component({
  selector: '[dsmj-tab], dsmj-tab',
  templateUrl: './tab.component.html',
  styleUrls: ['./tab.component.css'],
  // encapsulation: ViewEncapsulation.None
})
export class TabComponent implements OnInit, OnDestroy {

  @Input() title: string = 'Titre';
  @Input() icon?: string;
  @Input() index: number = nextId++;

  @HostBinding('attr.aria-labelledby') arialabelledby: any = '';
  @HostBinding('role') role = 'tabpanel';
  @HostBinding('tabindex') tabindex = '0';
  @HostBinding('id') attrId = '';

  /**
   * Constructeur
   * @param _group Le comosant parent contenant l&apos;onglet
   * @param _element Permet d&apos;intéragir avec l&apos;élément natif du DOM
   */
  constructor(private _group: TabGroupComponent, private _element : ElementRef) {
    this._group.register(this);
  }

  /** Fonction appelée juste après l&apos;initialisation du composant */
  ngOnInit(): void {
    this.attrId = this.id;
    this.arialabelledby = this.labelledBy;
  }

  /** Fonction appelée avant la destruction du composant */
  ngOnDestroy() { this._group.unregister(this); }

  /** Retourne l&quot;onglet actuel sélectionné */
  @HostBinding('class')
  get selected(){
    let classNames = 'fr-tabs__panel';

    if (this.animation) {
      classNames += ' fr-tabs--animation-from-right';
    }

    if (this.index === this._group.selected) {
      classNames += ' fr-tabs__panel--selected';
    }
    return classNames;
  }

  /** Retourne la valeur pour l&apos;attribut attr-labelledBy */
  get labelledBy(){
    return `${this._group.prefixId}-${this.index}`;
  }

  /** Retourne l&apos;ID du composant */
  get id(){
    return `${this._group.prefixId}-${this.index}-panel`;
  }

  /** Retourne le choix d&apos;animation du compsant */
  get animation(){
    return this._group.animation;
  }

}
