import {ComponentFixture, TestBed} from '@angular/core/testing';

import { TableComponent } from "./table.component";
import { Component } from '@angular/core';

describe('TableComponent', () =>{
  let component: TableComponent;
  let fixture: ComponentFixture<TableComponent>;
  let element: HTMLElement;

  
  let testComponent: TestComponent;
  let testFixture: ComponentFixture<TestComponent>;
  let testElement: HTMLElement;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ 
        TableComponent,
        TestComponent      
      ],
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(TableComponent);
    testFixture = TestBed.createComponent(TestComponent);

    component = fixture.componentInstance;
    testComponent = testFixture.componentInstance;

    element = fixture.nativeElement
    testElement = testFixture.nativeElement
    fixture.detectChanges();
    testFixture.detectChanges();
  });

  it("should create component dsmj-table", () =>{
    expect(component).toBeTruthy()
  })

  it("should be empty if nothing given", () =>{
    /** Compare if the element div exist */
    expect(element.getElementsByTagName('div').item(0)).toBeNull()
  })

  it("should have the same caption's text as the one given by title", () =>{
    component.title = "Titre du tableau"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('caption').item(0).textContent.trim()).toEqual("Titre du tableau")
  })

  it("should have the base caption wich is empty", () =>{
    component.title = "Titre"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0).className.trim()).not.toContain("caption")
  })

  it("should have the same caption as the one given by caption", () =>{
    component.caption = "bottom"
    component.title = "Titre"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0).className.trim()).toContain("fr-table--caption-bottom")
  })

  it("should have the same border class as the one given by bordered", () =>{
    component.bordered = true
    component.title = "Titre"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0).className.trim()).toContain("fr-table--bordered")
  })

  it("should have the same color class as the one given by color", () =>{
    component.color = "green-emeraude"
    component.title = "Titre"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0).className.trim()).toContain("fr-table--green-emeraude")
  })

  it("should have the opposite scroll class as the one given by noScroll", () =>{
    component.noScroll = true
    component.title = "Titre"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0).className.trim()).toContain("fr-table--no-scroll")
  })

  it("should have the same fixed class as the one given by fixed", () =>{
    component.fixed = true
    component.title = "Titre"
    fixture.detectChanges()
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0).className.trim()).toContain("fr-table--layout-fixed")
  })

  it("should generate the table based on the one given in component", () =>{
    testComponent.title = "Titre"
    testFixture.detectChanges()
    testElement = testFixture.nativeElement
    var htmlResult: string =`<table><caption>Titre</caption><thead><tr><th>colonne 1</th><th>colonne 2</th></tr></thead><tbody><tr><td>ligne 1 colonne 1</td><td>ligne 1 colonne 2</td></tr></tbody></table>`
    expect(testElement.getElementsByTagName('div').item(0).innerHTML.trim()).toEqual(htmlResult.trim())
  })
})

@Component({
  template: `
    <dsmj-table title="{{title}}">
      <th>colonne 1</th>
      <th>colonne 2</th>
      <tr>
        <td>ligne 1 colonne 1</td>
        <td>ligne 1 colonne 2</td>
      </tr>
    </dsmj-table>
  `
})
class TestComponent {
  title: string;
}
