import {Component, Input, Output, EventEmitter, OnChanges} from '@angular/core'
import {DsmjColor} from "../../shared";
import { v4 as uuidv4 } from 'uuid';


/**
 * Composant table
 */
@Component({
  selector: 'dsmj-table',
  templateUrl: './table.component.html',
})
export class TableComponent implements OnChanges {
  /** Identifiant unique de l'objet */
  readonly UUID: string = uuidv4();

  /** Identifiant automatiquement généré */
  readonly IDNAME_NAV_CONTAINER:string = "dsmj-table__" + this.UUID;

  /** Récupération par le composant de l'id à affiché dans le tableau */
  @Input() public tableId: string = "";

  /** Titre du tableau obligatoire */
  @Input() public title: string = "";

  /** Titre du tableau obligatoire */
  @Input() public caption: 'top' | 'bottom' | 'none' = 'top';

  /** Le tableau améliore sa lisibilité du contenu en étant plus dense */
  @Input() public bordered: boolean = false;

  /** Le tableau peut être décliné en plusieurs couleurs différentes */
  @Input() public color?: DsmjColor;

  /** Le tableau peut être décliné en plusieurs couleurs différentes */
  @Input() public noScroll: boolean = false;

  /** Le tableau peut être décliné en plusieurs couleurs différentes */
  @Input() public fixed: boolean = false;

  get colorClass(): string {
    return this.color ? "fr-table--" + this.color : ""
  }

  get captionClass(): string {
    switch(this.caption) {
      case 'bottom': {
        return 'fr-table--caption-bottom'
      }
      case 'none': {
        return 'fr-table--no-caption'
      }
      default: {
        return ''
      }
    }
  }

  /**
   * Génération de l'id basé sur celui donné ou création d'un id unique
   */
  get id(): string {
    return this.tableId ? this.tableId : this.IDNAME_NAV_CONTAINER;
  }

  /** Renvoit les ids au parent */
  @Output() idEvent: EventEmitter<string> = new EventEmitter<string>();
  ngOnChanges(): void {
    this.idEvent.emit(this.id);
  }
  
}
