import {ComponentFixture, TestBed} from '@angular/core/testing';

import { TileComponent } from "./tile.component";
import { By } from '@angular/platform-browser';

describe('TileComponent', () =>{
  let component: TileComponent;
  let fixture: ComponentFixture<TileComponent>;
  let element: HTMLElement;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ TileComponent ],
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(TileComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    fixture.detectChanges();
  });

  it("should create component dsmj-tile", () =>{
    expect(component).toBeTruthy()
  })

  it("should be empty if nothing given", () =>{
    /** Compare if the element div exist */
    expect(element.getElementsByTagName('div').item(0)).toBeNull()
  })
  
  it("should have a balise h2 as default", () =>{
    component.title = "Titre 1"
    fixture.detectChanges()
    expect(element.getElementsByTagName('h2').item(0)).not.toBeNull()
  })
  
  it("should have the same text as the one given by title", () =>{
    component.title = "Titre 1"
    fixture.detectChanges()
    expect(element.getElementsByTagName('h2').item(0).textContent.trim()).toEqual("Titre 1")
  })
  
  it("should have the same balise as the one given by baliseTitle", () =>{
    component.title = "Titre 1"
    component.headingTag = "h4"
    fixture.detectChanges()
    expect(element.getElementsByTagName('h4').item(0)).not.toBeNull()
  })

  it("should have given description in balise p", () =>{
    component.title = "Titre 1"
    component.description = "Ceci est une description"
    fixture.detectChanges()
    expect(element.getElementsByTagName('p').item(0).textContent.trim()).toEqual("Ceci est une description")
  })

  it("should have given imgSrc as source of image", () =>{
    component.title = "Titre 1"
    component.imgSrc = "/assets/image-test.png"
    fixture.detectChanges()
    let src = fixture.debugElement.query(By.css('img')).nativeElement.src;
    expect(src).toContain("/assets/image-test.png")
  })

  it("should have given imgAlt as text alternatif of image", () =>{
    component.title = "Titre 1"
    component.imgSrc = "/assets/image-test.png"
    component.imgAlt = "image-test"
    fixture.detectChanges()
    let alt = fixture.debugElement.query(By.css('img')).nativeElement.alt;
    expect(alt).toEqual("image-test")
  })
})
