import {Component, EventEmitter, Input, Output} from "@angular/core"
import { v4 as uuidv4 } from 'uuid';


/**
 * Component Tile
 */
@Component({
  selector: 'dsmj-tile',
  templateUrl: './tile.component.html'
})
export class TileComponent { 
  /** Identifiant unique de l'objet */
  readonly UUID: string = uuidv4();

  /** Identifiant automatiquement généré */
  readonly IDNAME_NAV_CONTAINER:string = "dsmj-tile__" + this.UUID;

  /**
   * Récupération par le composant de l'id à affiché dans la tuile
   */
  @Input() public tileId: string = "";


  /** Description de la tuile */
  @Input() public description: string | undefined = undefined;

  /** Titre/intitulé de la tuile */
  @Input() public title: string = '';

  /** Source de l'image */
  @Input() public imgSrc: string | undefined = undefined;

  /** Texte alternatif de l'image */
  @Input() public imgAlt: string | undefined = undefined;

  /** Url de redirection - routerLink */
  @Input() public url: string;

  /** Balise du titre de la tuile : h2 | h3 | h4 | h5 | h6 */
  @Input() public headingTag: 'h2' | 'h3' | 'h4' | 'h5' | 'h6' = 'h2';

  /** Orientation de la tuile : 'vertical' | 'horizontal' */
  @Input() public orientation: 'vertical' | 'horizontal' = 'vertical';

  /** Renvois un event en cas de click */
  @Output() hasClick: EventEmitter<Event> = new EventEmitter<Event>();

  /** Renvois le nom de classe pour l'orientation de la tuile */
  get orientationClass(): string {
    return 'fr-tile--' + this.orientation
  }

  /**
   * Génération de l'id basé sur celui donné ou création d'un id unique
   */
  get id(): string {
    return this.tileId ? this.tileId : this.IDNAME_NAV_CONTAINER;
  }
  

  emitClick(event: Event): void {
    this.hasClick.emit(event);
  }
}
