import {ComponentFixture, TestBed} from '@angular/core/testing';

import { ToggleComponent } from "./toggle.component";
import {getElements} from "../../helper/spec-helper";
import {EventEmitter} from "@angular/core";
import spyOn = jest.spyOn;

describe('ToggleComponent', () =>{
  let component: ToggleComponent;
  let fixture: ComponentFixture<ToggleComponent>;
  let element: HTMLElement;

  beforeEach( () => {
    TestBed.configureTestingModule({
      declarations: [ ToggleComponent ],
    })
      .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(ToggleComponent);
    component = fixture.componentInstance;
    element = fixture.nativeElement
    fixture.detectChanges();
  });

  it("should create component dsmj-toggle", () =>{
    expect(component).toBeTruthy()
  })

  it("should not have anything when not given anything", () =>{
    expect(element.getElementsByTagName('div').item(0)).not.toBeTruthy()
  })

  it("should have a div when given label", () =>{
    component.label = "test"
    fixture.detectChanges();
    element = fixture.nativeElement
    expect(element.getElementsByTagName('div').item(0)).toBeTruthy()
  })

  it("should have a label with given label text and have an input created", () =>{
    component.label = "test"
    fixture.detectChanges();
    element = fixture.nativeElement
    var el = element.getElementsByTagName('label').item(0)
    expect(element.getElementsByTagName('input').item(0)).toBeTruthy()
    expect(el).toBeTruthy()
    expect(el.textContent.trim()).toEqual('test')
  })

  it("should have a description with given desc text", () =>{
    component.label = "test"
    component.desc = "Juste un test unitaire"
    fixture.detectChanges();
    element = fixture.nativeElement
    var elLabel = element.getElementsByTagName('label').item(0)
    expect(elLabel).toBeTruthy()
    var el = element.getElementsByTagName('p').item(0)
    expect(el).toBeTruthy()
    expect(el.textContent.trim()).toEqual('Juste un test unitaire')
  })

  it("should have attributes checked and unchecked to be equal checkedText and uncheckedText", () =>{
    component.label = "test"
    component.desc = "Juste un test unitaire"
    component.checkedText = "activé"
    component.uncheckedText = "désactivé"
    fixture.detectChanges();
    element = fixture.nativeElement
    var el = element.getElementsByTagName('label').item(0)
    expect(el).toBeTruthy()
    expect(el.getAttribute('data-fr-checked-label')).toEqual('activé')
    expect(el.getAttribute('data-fr-unchecked-label')).toEqual('désactivé')
  })

  it("should have attribute disabled when disabled is true", () =>{
    component.label = "test"
    component.disabled = true
    fixture.detectChanges();
    element = fixture.nativeElement
    var el = element.getElementsByTagName('input').item(0)
    expect(el).toBeTruthy()
    expect(el.getAttribute('disabled') != null).toBeTruthy()
  })

  it("should have the given ids when given toggleId and descId", () =>{
    component.label = "test"
    component.desc = "Juste un test unitaire"
    component.toggleId = "dsmj-test-toggle"
    component.descId = "dsmj-test-toggle-desc"
    fixture.detectChanges();
    element = fixture.nativeElement
    // test id and attribute pointing to desc id of input
    var elInput = element.getElementsByTagName('input').item(0)
    expect(elInput).toBeTruthy()
    expect(elInput.id).toEqual('dsmj-test-toggle')
    expect(elInput.getAttribute('aria-describedby')).toEqual("dsmj-test-toggle-desc")
    // test attribute pointing toward input id
    var elLabel = element.getElementsByTagName('label').item(0)
    expect(elLabel).toBeTruthy()
    expect(elLabel.getAttribute('for')).toEqual('dsmj-test-toggle')
    // test id of paragraph
    var elPar = element.getElementsByTagName('p').item(0)
    expect(elPar).toBeTruthy()
    expect(elPar.id).toEqual("dsmj-test-toggle-desc")
  })
})