import {Component, Input, Output, EventEmitter, OnChanges} from "@angular/core";
import { v4 as uuidv4 } from 'uuid';

@Component({
  selector: 'dsmj-toggle',
  templateUrl: './toggle.component.html',
})

export class ToggleComponent implements OnChanges {
  /** Récupération du label a afficher */
  @Input() public label: string = "";
  
  /** Récupération de la description a afficher */
  @Input() public hint: string = "";
  
  /** Récupération du coté sur lequel afficher le label */
  @Input() public position: "left" | "right" = "right";
  
  /** Récupération du texte a afficher si l'interrupteur est actif */
  @Input() public checkedText: string = "";
  
  /** Récupération du texte a afficher si l'interrupteur est inactif */
  @Input() public uncheckedText: string = "";
  
  /** Récupération de l'affichage de la bordure */
  @Input() public border: boolean = false;
  
  /** Récupération de l'activation du composant */
  @Input() public disabled: boolean = false;

  /** Renvois de l'état */
  @Output() toggleStateEvent: EventEmitter<boolean> = new EventEmitter<boolean>();

  returnToggleState(event): void {
    this.toggleStateEvent.emit(event.target.checked)
  }

  /** 
   * ####################
   *  Génération de l'id
   * ####################
   */
  /** Identifiant unique de l'objet */
  readonly UUID: string = uuidv4();
  /** Identifiant généré du composant */
  readonly IDNAME_NAV_CONTAINER:string = "dsmj-toggle-" + this.UUID;
  /** Récupération de l'id à affiché dans le composant */
  @Input() public toggleId: string = "";
  /** Génération de l'id basé sur celui donné ou création d'un id unique */
  get containerId(): string {
    return this.toggleId ? this.toggleId : this.IDNAME_NAV_CONTAINER;
  }

  /** Identifiant généré du composant */
  readonly IDNAME_DESCRIPTION:string = "dsmj-toggle__description-" + this.UUID;
  /** Récupération de l'id à affiché dans le composant */
  @Input() public descId: string = "";
  /** Génération de l'id basé sur celui donné ou création d'un id unique */
  get descriptionId(): string {
    return this.descId ? this.descId : this.IDNAME_DESCRIPTION;
  }

  /** Renvoit l'id au parent */
  @Output() idEvent: EventEmitter<{toggle: string, hint: string}> = new EventEmitter<{toggle: string, hint: string}>();
  ngOnChanges(): void {
    this.idEvent.emit({toggle: this.containerId, hint: this.descriptionId});
  }

}
