import {AfterContentChecked, Directive, ElementRef} from '@angular/core'

/**
 * génère un bouton de retour vers le haut associé à un élément
 */
@Directive({
  selector: '[dsmjReturnTop]'
})
export class DsmjReturnTopDirective implements AfterContentChecked {

  constructor(private el: ElementRef) {
  }

  /** construit le bouton de retour vers le haut */
  ngAfterContentChecked(): void {
    if (this.el.nativeElement.querySelector('.return-top')) {
      return;
    }

    const bt = this.buildButton()
    this.addEventListener(bt)
    this.toggleShow(bt)
  }

  /** construit, inject a élément */
  private buildButton(): HTMLButtonElement {
    const bt = document.createElement("button")
    bt.classList.add(...['btn-return-top', 'return-top', 'fr-btn'])
    bt.innerHTML = '<span class="ri-arrow-up-line"></span>'

    this.el.nativeElement.prepend(bt)

    return bt
  }

  /** associe les évents de scrolling et de click */
  private addEventListener(bt: HTMLButtonElement): void {
    window.addEventListener('scroll', () => {
      this.toggleShow(bt)
    })

    bt.addEventListener('click', (): void => {
      this.el.nativeElement.scrollIntoView({behavior: 'smooth', block: 'start'})
    })
  }

  /** switch l'affichage du bouton selon la position de scrolling */
  toggleShow(bt:HTMLElement): void {
    if (document.body.scrollTop > this.el.nativeElement.getBoundingClientRect().top) {
      bt.classList.add('return-top-show')
    } else {
      bt.classList.remove('return-top-show')
    }
  }
}
