import {Observable, SchedulerLike} from 'rxjs'
import {shareReplay} from 'rxjs/operators'


export class SharedReplayTimer<T> {
  private sharedReplay$!: Observable<T>
  private subscriptionTime!: number
  readonly CACHE_EXPIRATION = 1800000; // 1800000 = 30 minutes
  readonly BUFFER_SIZE = 1;

  /**
   * Share source and replay on duration or specified number of emissions on subscription.
   *
   * @param source : observable to cache
   * @param bufferSize : size of buffer
   * @param windowTime : cache duration
   * @param scheduler
   */
  sharedReplay(source: Observable<T>, bufferSize = this.BUFFER_SIZE, windowTime = this.CACHE_EXPIRATION, scheduler?: SchedulerLike): Observable<T> {
    if (this.isTimeOut(windowTime)) {
      this.sharedReplay$ = source.pipe(shareReplay(bufferSize, windowTime, scheduler))
      this.subscriptionTime = new Date().getTime()
    }

    return this.sharedReplay$;
  }

  isTimeOut(windowTime = this.CACHE_EXPIRATION): boolean {
    const currentTime = new Date().getTime()
    return !this.sharedReplay$ || currentTime - this.subscriptionTime > windowTime
  }
}
