import { ElementRef, Input, Directive, HostBinding, AfterViewInit } from '@angular/core';

@Directive({
  selector: '[dsmjButton]'
})
export class DsmjButtonDirective implements AfterViewInit {

  /**
   * Classes associés à l'objet
   */
  @HostBinding() class: string;

  /**
   * Couleur associé au boutton, peut être primaire, secondaire ou tertiaire
   */
  @Input() color: "primary" | "secondary" | "tertiary" | "tertiary-no-outline";

  /**
   * Nom de classe de l'icone. Optionnel
   */
  @Input() icon?: string;

  /**
   * Position de l'icone, gauche ou droite. Si non renseigné, l'icone sera affiché seule.
   */
  @Input() iconPosition?: "left" | "right";

  /**
   * Taille du bouton : petit, moyen ou large. Optionnelle
   */
  @Input() size?: "sm" | "md" | "lg";

  /**
   * Type d'action du bouton
   */
  @Input() action?: "close" | "search";

  /**
   * Objet DOM du controle
   */
  public html: HTMLElement;

  constructor(protected el: ElementRef) {

    this.html = el.nativeElement;

    // Ajoute les éléments de class
    this.html.classList.add('fr-btn');
  }

  ngAfterViewInit(): void {
    this.initClasses();
  }

  /**
   * Initialise les classes à ajouter à l'objet en fonction
   *  des options renseignées
   */
  initClasses(): void {
    if (this.color) {
      this.html.classList.add(`fr-btn--${this.color}`);
    }

    if (this.icon) {
      this.html.classList.add(`fr-fi-${this.icon}`);

      if (this.iconPosition) {
        this.html.classList.add(`fr-btn--icon-${this.iconPosition}`);
      }
    }

    if(this.action && this.action === 'close') {
      this.html.classList.add('fr-btn--close');
    }

    if(this.action && this.action === 'search') {
      this.html.classList.add('fr-btn--close');
    }

    if (this.size) {
      this.html.classList.add(`fr-btn--${this.size}`);
    }
  }
}
