import {Directive, ElementRef, HostBinding, Input, OnInit, Optional, Renderer2} from '@angular/core';
import {ControlContainer, FormGroup} from "@angular/forms";
import {nanoid} from "nanoid";

@Directive({
  selector: '[dsmjInputText]',
  /*host: {
    'class': 'fr-input',
    'type': 'text'
  }*/
})
export class DsmjInputTextDirective implements OnInit {
  @Input() label?: string;
  @Input() id?: string;

  @HostBinding('class') class: string = 'fr-input';
  @HostBinding('type') type: string = 'text';

  formGroup?: FormGroup;
  isCustomId: boolean = false;

  constructor(protected el: ElementRef, protected renderer2: Renderer2, @Optional() protected _parentContainer: ControlContainer) {
  }

  ngOnInit(): void {
    this.formGroup = this._parentContainer?.control as FormGroup
    if (null == this.formGroup) return;
    this.decorateInput();
  }

  initId(): void {
    if(this.id == null) {
      this.id = DsmjInputTextDirective.getUuid();
      this.isCustomId = true
    }
  }

  private decorateInput(): void {
    this.initId();
    const input = this.el.nativeElement;

    const label = this.createLabel(input, this.label);

    this.buildContainer(input, label);
  }

  private buildContainer(input, label): void {
    if (label) {
      this.renderer2.insertBefore(input.parentElement, label, input)
    }
    if (this.isCustomId) {
      input.setAttribute('id', this.id)
    }
  }

  private createLabel(input: any, label?: string): HTMLLabelElement | undefined {
    if (!label) return;

    const formControlName = input.getAttribute('formControlName');
    const isInputRequired = this.formGroup?.get(formControlName)?.['required'] ? 'input-required' : undefined;

    return this.createLabelElement(label, isInputRequired);
  }

  private createLabelElement(text?: string, isRequired?: string): HTMLLabelElement {
    const label = document.createElement('label');
    label.classList.add(...['fr-label', isRequired])
    label.setAttribute('for', this.id)
    label.innerText = text;

    return label;
  }

  /** génère un uuid */
  // private override getUuid() {
  private static getUuid(): string {
    let uuid;
    while (true) {
      uuid = nanoid(8)
      if (/^(.*[a-zA-Z]+.*)$/.test(uuid)) break
    }
    return uuid
  }
}
