import { ElementRef, Input, Directive, HostBinding, AfterViewInit } from '@angular/core';

@Directive({
  selector: '[dsmjLink]'
})
export class DsmjLinkDirective implements AfterViewInit {

  /**
   * Classes associés à l'objet
   */
  @HostBinding() class: string;

  /**
   * Défini la valeur de l'attribut target
   */
  @HostBinding()
  @Input() target: string = "_self";

  /**
   * Nom de classe de l'icone. Optionnel
   */
  @Input() icon?: string;

  /**
   * Position de l'icone, gauche ou droite. Si non renseigné, l'icone sera affiché seule.
   */
  @Input() iconPosition?: "left" | "right";

  /**
   * Taille du bouton : petit, moyen ou large. Optionnelle
   */
  @Input() size: "sm" | "md" | "lg" = "md";

  /**
   * Spécifie si le lien redirige vers l'extérieur
   */
  @Input() external: boolean = false;

  /**
   * Objet DOM du controle
   */
  public html: HTMLElement;

  constructor(protected el: ElementRef) {

    this.html = el.nativeElement;

    // Ajoute les éléments de class
    this.html.classList.add('fr-link');
  }

  ngAfterViewInit(): void {
    this.initClass();
  }

  /**
   * Initialise les classes à ajouter à l'objet en fonction
   *  des options renseignées
   */
  initClass(): void {

    if (this.icon) {
      this.html.classList.add(this.icon);

      if (this.iconPosition) {
        this.html.classList.add(`fr-link--icon-${this.iconPosition}`);
      }
    }

    if (this.size) {
      this.html.classList.add(`fr-link--${this.size}`);
    }

    if(this.external) {
      this.html.setAttribute('rel', 'noopener');
      this.target = "_blank";
    }
  }
}
