import {Directive, ElementRef, Input, OnDestroy, OnInit, Optional, Renderer2} from "@angular/core";
import {AbstractControl, ControlContainer, FormGroup, FormGroupDirective} from "@angular/forms";
import {merge, Observable, of, Subscription} from "rxjs";
import {map} from "rxjs/operators";

@Directive({
  selector: '[dsmjValidMessage]'
})
export class DsmjValidMessageDirective implements OnInit, OnDestroy {
  @Input() validmessage?: string;
  @Input() controlName: string;
  control: AbstractControl;
  controlValue$: Observable<any>;
  controlSubscription: Subscription;
  hasSubmitted: boolean;

  hydratedMesages = [];

  constructor(
    private _el: ElementRef,
    private render: Renderer2,
    @Optional() private _fg: ControlContainer,
  ) { }

  ngOnInit(): void {
    this.initDefault()
    if (null == this.form) return;
    this.control = this.form.get(this.controlName);
    let formSubmit$ = (<FormGroupDirective>this._fg).ngSubmit.pipe(map(()=>{
      this.hasSubmitted = true;
    }));
    this.controlValue$ =  merge(this.control.valueChanges, of(''), formSubmit$ );
    this.controlSubscription = this.controlValue$.subscribe(() => {
      this.setVisible();
    });
  }

  get form(): FormGroup | null { return this._fg?.formDirective ? (this._fg.formDirective as FormGroupDirective).form : null; }

  private setVisible(): void {
    this.removeMessage();
    if (this.control.valid && (this.control.dirty || this.hasSubmitted)) {
      if (this.control.valid) {
        this.showMessage();
      }
    }
  }

  /**
   * <input dsmjValidMessage type="text" name="field"> will not init default messages
   * <input [dsmjValidMessage] type="text" name="field"> will init default messages
   * @private
   */
  private initDefault(): void {
    if (this.validmessage == null)
      this.validmessage = DsmjValidMessageDirective.getDefaultMessages();
  }

  private showMessage(): void {
    const div = this._el.nativeElement;
    const id = this.controlName.concat('-').concat('success');
    this.hydratedMesages.push(id)
    const success = this.createSuccessParagraph(this.validmessage, id)
    this.render.appendChild(div, success)
  }

  private removeMessage(): void {
    const removeOneChild = (id): void => {
      const p = this._el.nativeElement.querySelector('#'.concat(id))
      this.render.removeChild(this._el.nativeElement, p);
    }
    this.hydratedMesages.forEach(id => removeOneChild(id));
    this.hydratedMesages = [];
  }

  private createSuccessParagraph(message, id): HTMLParagraphElement {
    const paragraph = document.createElement('p');
    paragraph.setAttribute('id', id)
    paragraph.classList.add(...['fr-valid-text'])
    paragraph.innerText = message;

    return paragraph;
  }

  private static getDefaultMessages(): string {
    return 'ce champ est correctement saisi';
  }

  ngOnDestroy(): void {
    this.controlSubscription?.unsubscribe();
  }
}
